@@ -21,6 +21,7 @@
 #include <fstream>
 #include <string>
 #include <cstring>
+#include <stdlib.h> // EXIT_FAILURE
 #include "cppcheck.h"
 #include "timer.h"
 #include "settings.h"
@@ -28,8 +29,10 @@
 #include "path.h"
 #include "filelister.h"
 
+#ifdef HAVE_RULES
 // xml is used in rules
-#include "tinyxml/tinyxml.h"
+#include <tinyxml.h>
+#endif
 
 static void AddFilesToList(const std::string& FileList, std::vector<std::string>& PathNames)
 {
@@ -93,6 +96,10 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
         else if (strcmp(argv[i], "-a") == 0 || strcmp(argv[i], "--all") == 0)
             ;
 
+        // Inconclusive checking (still in testing phase)
+        else if (strcmp(argv[i], "--inconclusive") == 0)
+            _settings->inconclusive = true;
+
         // Checking coding style
         else if (strcmp(argv[i], "-s") == 0 || strcmp(argv[i], "--style") == 0)
         {
@@ -195,6 +202,18 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             }
         }
 
+        else if (strncmp(argv[i], "--suppress=", 11) == 0)
+        {
+            std::string suppression = argv[i];
+            suppression = suppression.substr(11);
+            const std::string errmsg(_settings->nomsg.addSuppressionLine(suppression));
+            if (!errmsg.empty())
+            {
+                PrintMessage(errmsg);
+                return false;
+            }
+        }
+
         // Enables inline suppressions.
         else if (strcmp(argv[i], "--inline-suppr") == 0)
             _settings->_inlineSuppressions = true;
@@ -330,6 +349,7 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
                 path = 2 + argv[i];
             }
             path = Path::fromNativeSeparators(path);
+            path = Path::removeQuotationMarks(path);
 
             // If path doesn't end with / or \, add it
             if (path[path.length()-1] != '/')
@@ -371,6 +391,8 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             if (!path.empty())
             {
                 path = Path::fromNativeSeparators(path);
+                path = Path::simplifyPath(path.c_str());
+                path = Path::removeQuotationMarks(path);
 
                 // If not "known" filename extension then assume it is path
                 if (!FileLister::acceptFile(path))
@@ -503,6 +525,7 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
                 _settings->_showtime = SHOWTIME_NONE;
         }
 
+#ifdef HAVE_RULES
         // Rule given at command line
         else if (strncmp(argv[i], "--rule=", 7) == 0)
         {
@@ -549,6 +572,13 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
                 }
             }
         }
+#endif
+
+        // Check configuration
+        else if (strcmp(argv[i], "--check-config") == 0)
+        {
+            _settings->checkConfiguration = true;
+        }
 
         // Print help
         else if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0)
@@ -569,7 +599,11 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
         }
 
         else
-            _pathnames.push_back(Path::fromNativeSeparators(argv[i]));
+        {
+            std::string path = Path::fromNativeSeparators(argv[i]);
+            path = Path::removeQuotationMarks(path);
+            _pathnames.push_back(path);
+        }
     }
 
     if (_settings->isEnabled("unusedFunctions") && _settings->_jobs > 1)
@@ -609,24 +643,33 @@ void CmdLineParser::PrintHelp()
               "Syntax:\n"
               "    cppcheck [OPTIONS] [files or paths]\n"
               "\n"
-              "If path is given instead of filename, *.cpp, *.cxx, *.cc, *.c++ and *.c files\n"
-              "are checked recursively from given directory.\n\n"
+              "If path is given instead of filename, *.cpp, *.cxx, *.cc, *.c++, *.c, *.tpp,\n"
+              "and *.txx are checked recursively from given directory.\n\n"
               "Options:\n"
               "    --append=<file>      This allows you to provide information about\n"
               "                         functions by providing an implementation for these.\n"
+              "    --check-config       Check cppcheck configuration. The normal code\n"
+              "                         analysis is disabled by this flag.\n"
               "    -D<ID>               By default Cppcheck checks all configurations.\n"
               "                         Use -D to limit the checking. When -D is used the\n"
               "                         checking is limited to the given configuration.\n"
               "                         Example: -DDEBUG=1 -D__cplusplus\n"
               "    --enable=<id>        Enable additional checks. The available ids are:\n"
-              "                          * all - enable all checks\n"
-              "                          * style - Check coding style\n"
-              "                          * information - Enable information messages\n"
-              "                          * unusedFunction - check for unused functions\n"
-              "                          * missingInclude - check for missing includes\n"
-              "                         Several ids can be given if you separate them with commas.\n"
+              "                          * all\n"
+              "                                  Enable all checks\n"
+              "                          * style\n"
+              "                                  Check coding style\n"
+              "                          * information\n"
+              "                                  Enable information messages\n"
+              "                          * unusedFunction\n"
+              "                                  Check for unused functions\n"
+              "                          * missingInclude\n"
+              "                                  Warn if there are missing includes.\n"
+              "                                  For detailed information use --check-config\n"
+              "                         Several ids can be given if you separate them with\n"
+              "                         commas.\n"
               "    --error-exitcode=<n> If errors are found, integer [n] is returned instead\n"
-              "                         of default 0. EXIT_FAILURE is returned\n"
+              "                         of default 0. " << EXIT_FAILURE << " is returned\n"
               "                         if arguments are not valid or if no input files are\n"
               "                         provided. Note that your operating system can\n"
               "                         modify this value, e.g. 256 can become 0.\n"
@@ -634,32 +677,36 @@ void CmdLineParser::PrintHelp()
               "    --exitcode-suppressions=<file>\n"
               "                         Used when certain messages should be displayed but\n"
               "                         should not cause a non-zero exitcode.\n"
-              "    --file-list=<file>   Specify the files to check in a text file. One Filename per line.\n"
+              "    --file-list=<file>   Specify the files to check in a text file. One Filename\n"
+              "                         per line.\n"
               "    -f, --force          Force checking on files that have \"too many\"\n"
               "                         configurations.\n"
               "    -h, --help           Print this help.\n"
               "    -I <dir>             Give include path. Give several -I parameters to give\n"
               "                         several paths. First given path is checked first. If\n"
               "                         paths are relative to source files, this is not needed.\n"
-              "    -i <dir>             Give path to ignore. Give several -i parameters to ignore\n"
-              "                         several paths. Give directory name or filename with path\n"
-              "                         as parameter. Directory name is matched to all parts of the\n"
-              "                         path.\n"
+              "    -i <dir>             Give path to ignore. Give several -i parameters to\n"
+              "                         ignore several paths. Give directory name or filename\n"
+              "                         with path as parameter. Directory name is matched to\n"
+              "                         all parts of the path.\n"
               "    --inline-suppr       Enable inline suppressions. Use them by placing one or\n"
               "                         more comments, like: // cppcheck-suppress warningId\n"
               "                         on the lines before the warning to suppress.\n"
               "    -j <jobs>            Start [jobs] threads to do the checking simultaneously.\n"
               "    -q, --quiet          Only print error messages.\n"
               "    --report-progress    Report progress messages while checking a file.\n"
+#ifdef HAVE_RULES
               "    --rule=<rule>        Match regular expression.\n"
               "    --rule-file=<file>   Use given rule file. For more information, see: \n"
               "                         https://sourceforge.net/projects/cppcheck/files/Articles/\n"
+#endif
               "    -s, --style          Deprecated, use --enable=style\n"
-              "    --suppressions-list=<file>\n"
-              "                         Suppress warnings listed in the file. Filename and line\n"
-              "                         are optional in the suppression file. The format of the\n"
-              "                         single line in the suppression file is:\n"
+              "    --suppress=<spec>    Suppress a specific warning. The format of <spec> is:\n"
               "                         [error id]:[filename]:[line]\n"
+              "                         The [filename] and [line] are optional.\n"
+              "    --suppressions-list=<file>\n"
+              "                         Suppress warnings listed in the file. Each suppression\n"
+              "                         is in the same format as <spec> above.\n"
               "    --template '<text>'  Format the error messages. E.g.\n"
               "                         '{file}:{line},{severity},{id},{message}' or\n"
               "                         '{file}({line}):({severity}) {message}'\n"
