@@ -19,6 +19,8 @@
 #include "cppcheckexecutor.h"
 #include "cppcheck.h"
 #include "threadexecutor.h"
+#include "preprocessor.h"
+#include "errorlogger.h"
 #include <fstream>
 #include <iostream>
 #include <cstdlib> // EXIT_SUCCESS and EXIT_FAILURE
@@ -65,29 +67,34 @@ bool CppCheckExecutor::parseFromArgs(CppCheck *cppcheck, int argc, const char* c
 
     // Check that all include paths exist
     {
-        std::list<std::string>::const_iterator iter;
+        std::list<std::string>::iterator iter;
         for (iter = _settings._includePaths.begin();
              iter != _settings._includePaths.end();
-             ++iter)
+            )
         {
             const std::string path(Path::toNativeSeparators(*iter));
-            if (!getFileLister()->isDirectory(path.c_str()))
+            if (FileLister::isDirectory(path))
+                ++iter;
+            else
             {
-                std::cout << "cppcheck: error: Couldn't find path given by -I '" + path + "'" << std::endl;
-                return false;
+                // If the include path is not found, warn user and remove the
+                // non-existing path from the list.
+                std::cout << "cppcheck: warning: Couldn't find path given by -I '" + path + "'" << std::endl;
+                iter = _settings._includePaths.erase(iter);
             }
         }
     }
 
     std::vector<std::string> pathnames = parser.GetPathNames();
     std::vector<std::string> filenames;
+    std::map<std::string, long> filesizes;
 
     if (!pathnames.empty())
     {
         // Execute recursiveAddFiles() to each given file parameter
         std::vector<std::string>::const_iterator iter;
         for (iter = pathnames.begin(); iter != pathnames.end(); ++iter)
-            getFileLister()->recursiveAddFiles(filenames, Path::toNativeSeparators(iter->c_str()));
+            FileLister::recursiveAddFiles(filenames, filesizes, Path::toNativeSeparators(*iter));
     }
 
     if (!filenames.empty())
@@ -96,7 +103,7 @@ bool CppCheckExecutor::parseFromArgs(CppCheck *cppcheck, int argc, const char* c
         std::vector<std::string>::iterator iterBegin = filenames.begin();
         for (int i = (int)filenames.size() - 1; i >= 0; i--)
         {
-            if (matcher.Match(filenames[i]))
+            if (matcher.Match(filenames[(unsigned int)i]))
                 filenames.erase(iterBegin + i);
         }
     }
@@ -110,7 +117,10 @@ bool CppCheckExecutor::parseFromArgs(CppCheck *cppcheck, int argc, const char* c
     {
         std::vector<std::string>::iterator iter;
         for (iter = filenames.begin(); iter != filenames.end(); ++iter)
-            cppcheck->addFile(*iter);
+        {
+            _filenames.push_back(*iter);
+            _filesizes[*iter] = filesizes[*iter];
+        }
 
         return true;
     }
@@ -123,7 +133,9 @@ bool CppCheckExecutor::parseFromArgs(CppCheck *cppcheck, int argc, const char* c
 
 int CppCheckExecutor::check(int argc, const char* const argv[])
 {
-    CppCheck cppCheck(*this);
+    Preprocessor::missingIncludeFlag = false;
+
+    CppCheck cppCheck(*this, true);
     if (!parseFromArgs(&cppCheck, argc, argv))
     {
         return EXIT_FAILURE;
@@ -142,7 +154,24 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
     if (_settings._jobs == 1)
     {
         // Single process
-        returnValue = cppCheck.check();
+
+        long totalfilesize = 0;
+        for (std::map<std::string, long>::const_iterator i = _filesizes.begin(); i != _filesizes.end(); ++i)
+        {
+            totalfilesize += i->second;
+        }
+
+        long processedsize = 0;
+        for (unsigned int c = 0; c < _filenames.size(); c++)
+        {
+            returnValue += cppCheck.check(_filenames[c]);
+            if (_filesizes.find(_filenames[c]) != _filesizes.end())
+            {
+                processedsize += _filesizes[_filenames[c]];
+            }
+            if (!_settings._errorsOnly)
+                reportStatus(c + 1, _filenames.size(), processedsize, totalfilesize);
+        }
     }
     else if (!ThreadExecutor::isEnabled())
     {
@@ -151,12 +180,32 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
     else
     {
         // Multiple processes
-        const std::vector<std::string> &filenames = cppCheck.filenames();
-        Settings settings = cppCheck.settings();
-        ThreadExecutor executor(filenames, settings, *this);
+        Settings &settings = cppCheck.settings();
+        ThreadExecutor executor(_filenames, _filesizes, settings, *this);
         returnValue = executor.check();
     }
 
+    if (!cppCheck.settings().checkConfiguration)
+    {
+        reportUnmatchedSuppressions(cppCheck.settings().nomsg.getUnmatchedGlobalSuppressions());
+
+        if (Preprocessor::missingIncludeFlag)
+        {
+            const std::list<ErrorLogger::ErrorMessage::FileLocation> callStack;
+            ErrorLogger::ErrorMessage msg(callStack,
+                                          Severity::information,
+                                          "Cppcheck cannot find all the include files (use --check-config for details)\n"
+                                          "Cppcheck cannot find all the include files. Cpppcheck can check the code without the "
+                                          "include files found. But the results will probably be more accurate if all the include "
+                                          "files are found. Please check your project's include directories and add all of them "
+                                          "as include directories for Cppcheck. To see what files Cppcheck cannot find use "
+                                          "--check-config.",
+                                          "missingInclude",
+                                          false);
+            reportErr(msg);
+        }
+    }
+
     if (_settings._xml)
     {
         reportErr(ErrorLogger::ErrorMessage::getXMLFooter(_settings._xml_version));
@@ -207,14 +256,14 @@ void CppCheckExecutor::reportProgress(const std::string &filename, const char st
     }
 }
 
-void CppCheckExecutor::reportStatus(unsigned int index, unsigned int max)
+void CppCheckExecutor::reportStatus(unsigned int fileindex, unsigned int filecount, long sizedone, long sizetotal)
 {
-    if (max > 1 && !_settings._errorsOnly)
+    if (filecount > 1)
     {
         std::ostringstream oss;
-        oss << index << "/" << max
+        oss << fileindex << "/" << filecount
             << " files checked " <<
-            static_cast<int>(static_cast<double>(index) / max*100)
+            (sizetotal > 0 ? static_cast<long>(static_cast<double>(sizedone) / sizetotal*100) : 0)
             << "% done";
         std::cout << oss.str() << std::endl;
     }
