@@ -52,11 +52,14 @@ ShowTypes;
 #define SETTINGS_MAINWND_SPLITTER_STATE "Mainwindow/Vertical splitter state"
 #define SETTINGS_CHECK_DIALOG_WIDTH     "Check dialog width"
 #define SETTINGS_CHECK_DIALOG_HEIGHT    "Check dialog height"
+#define SETTINGS_PROJECT_DIALOG_WIDTH   "Project dialog width"
+#define SETTINGS_PROJECT_DIALOG_HEIGHT  "Project dialog height"
 
 // Main window settings
 #define SETTINGS_RESULT_COLUMN_WIDTH    "Result column %1 width"
 #define SETTINGS_TOOLBARS_MAIN_SHOW     "Toolbars/ShowStandard"
 #define SETTINGS_TOOLBARS_VIEW_SHOW     "Toolbars/ShowView"
+#define SETTINGS_TOOLBARS_FILTER_SHOW   "Toolbars/ShowFilter"
 
 // Show * states
 #define SETTINGS_SHOW_STYLE             "Show style"
@@ -77,9 +80,13 @@ ShowTypes;
 #define SETTINGS_SAVE_FULL_PATH         "Save full path"
 #define SETTINGS_APPLICATION_NAMES      "Application names"
 #define SETTINGS_APPLICATION_PATHS      "Application paths"
+#define SETTINGS_APPLICATION_PARAMS     "Application parameters"
+#define SETTINGS_APPLICATION_DEFAULT    "Default Application"
 #define SETTINGS_LANGUAGE               "Application language"
 #define SETTINGS_GLOBAL_INCLUDE_PATHS   "Global include paths"
 #define SETTINGS_INLINE_SUPPRESSIONS    "Inline suppressions"
+#define SETTINGS_INCONCLUSIVE_ERRORS    "Inconclusive errors"
+#define SETTINGS_MRU_PROJECTS           "MRU Projects"
 
 /// @}
 #endif
