@@ -26,7 +26,7 @@ General Public License version 3</translation>
         <translation>Visitez le site Cppcheck : %1</translation>
     </message>
     <message utf8="true">
-        <source>Copyright © 2007-2010 Daniel Marjamäki and cppcheck team.</source>
+        <source>Copyright © 2007-2011 Daniel Marjamäki and cppcheck team.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -36,31 +36,6 @@ General Public License version 3</translation>
         <source>Add an application</source>
         <translation>Ajouter une application</translation>
     </message>
-    <message>
-        <source>Here you can add applications that can open error files.
-Specify a name for the application and the application to execute.
-
-The following texts are replaced with appropriate values when application is executed:
-(file) - Filename containing the error
-(line) - Line number containing the error
-(message) - Error message
-(severity) - Error severity
-
-Example opening a file with Kate and make Kate scroll to the correct line:
-kate -l(line) (file)</source>
-        <translation type="unfinished">Ici vous pouvez ajouter des applications pour ouvir les rapports d&apos;erreur
-Spécifiez le nom de l&apos;application et l&apos;application à exécuter.
-
-Les textes suivants sont remplacés avec les valeurs appropriées lorsque l&apos;application est lancée :
-(file) - Nom du fichier contenant l&apos;erreur
-(line) - Numéro de ligne où est l&apos;erreur
-(message) - Message d&apos;erreur
-(severity) - Séverité de l&apos;erreur
-
-
-Example : ouvrir un fichier avec kate et position l&apos;affichage sur la bonne ligne:
-kate -l(ligne) (fichier)</translation>
-    </message>
     <message>
         <source>Browse</source>
         <translation>Parcourir</translation>
@@ -78,15 +53,33 @@ kate -l(ligne) (fichier)</translation>
         <translation></translation>
     </message>
     <message>
-        <source>You must specify a name and a path for the application!</source>
-        <translation>Vous devez spécifier un nom et un chemin d&apos;accès pour l&apos;application !</translation>
-    </message>
-    <message>
-        <source>Application&apos;s name:</source>
+        <source>&amp;Executable:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Command to execute:</source>
+        <source>&amp;Parameters:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must specify a name, a path and parameters for the application!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Here you can add an application that can open error files. Specify a name for the application, the application executable and command line parameters for the application.
+
+The following texts in parameters are replaced with appropriate values when application is executed:
+(file) - Filename containing the error
+(line) - Line number containing the error
+(message) - Error message
+(severity) - Error severity
+
+Example opening a file with Kate and make Kate scroll to the correct line:
+Executable: kate
+Parameters: -l(line) (file)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Name:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -105,37 +98,6 @@ kate -l(ligne) (fichier)</translation>
         <translation type="unfinished">Ne peut pas lire le fichier : %1</translation>
     </message>
 </context>
-<context>
-    <name>HelpWindow</name>
-    <message>
-        <source>Cppcheck Help</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go back</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Back</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Go forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Home</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>LogView</name>
     <message>
@@ -333,18 +295,6 @@ kate -l(ligne) (fichier)</translation>
         <source>Cppcheck - %1</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to change the language:
-
-%1
-
-</source>
-        <translation type="unfinished">Erreur lors du chargement de la langue :
-
-%1
-
-</translation>
-    </message>
     <message>
         <source>English</source>
         <translation type="unfinished">Anglais</translation>
@@ -527,18 +477,6 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <source>XML files version 2 (*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cppcheck Help</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Failed to load help file (not found)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Failed to load help file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Project files (*.cppcheck);;All files(*.*)</source>
         <translation type="unfinished"></translation>
@@ -563,6 +501,28 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <source>Serbian</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>French</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>There was a problem with loading the editor application settings.
+
+This is probably because the settings were changed between the Cppcheck versions. Please check (and fix) the editor application settings, otherwise the editor program might not start correctly.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change the user interface language:
+
+%1
+
+The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spanish</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -593,18 +553,38 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <source>Paths:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Browse...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Include paths:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Defines:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Project</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Includes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include directories:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProjectFileDialog</name>
@@ -620,13 +600,13 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <source>Select directory to check</source>
         <translation type="unfinished">Sélectionner le répertoire à vérifier</translation>
     </message>
+    <message>
+        <source>Select directory to ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <source>Incorrect language specified!</source>
-        <translation type="unfinished">Langue incorrecte !</translation>
-    </message>
     <message>
         <source>Language file %1 not found!</source>
         <translation type="unfinished">Fichier de langue %1 non trouvé !</translation>
@@ -635,6 +615,10 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <source>Failed to load translation for language %1 from file %2</source>
         <translation type="unfinished">Erreur lors du chargement de la langue %1 depuis le fichier %2</translation>
     </message>
+    <message>
+        <source>Unknown language specified!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResultsTree</name>
@@ -728,6 +712,14 @@ Please select the directory where file is located.</source>
         <source>information</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>debug</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[Inconclusive]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResultsView</name>
@@ -796,22 +788,6 @@ Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</transl
         <source>Applications</source>
         <translation type="unfinished">Applications</translation>
     </message>
-    <message>
-        <source>Add application</source>
-        <translation type="unfinished">Ajouter une application</translation>
-    </message>
-    <message>
-        <source>Delete application</source>
-        <translation type="unfinished">Supprimer l&apos;application</translation>
-    </message>
-    <message>
-        <source>Modify application</source>
-        <translation type="unfinished">Modifier l&apos;application</translation>
-    </message>
-    <message>
-        <source>Set as default application</source>
-        <translation type="unfinished">Définir comme application par défaut</translation>
-    </message>
     <message>
         <source>Reports</source>
         <translation type="unfinished">Rapports</translation>
@@ -856,6 +832,34 @@ Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</transl
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Paths</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set as default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Show inconclusive errors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -875,6 +879,10 @@ Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</transl
         <source>Select include directory</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>[Default]</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatsDialog</name>
@@ -1036,4 +1044,11 @@ Statistics
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TxtReport</name>
+    <message>
+        <source>inconclusive</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
