@@ -20,9 +20,9 @@
     </message>
     <message utf8="true">
         <location filename="about.ui" line="81"/>
-        <source>Copyright © 2007-2010 Daniel Marjamäki and cppcheck team.</source>
-        <oldsource>Copyright (C) 2007-2010 Daniel Marjamäki and cppcheck team.</oldsource>
-        <translation></translation>
+        <source>Copyright © 2007-2011 Daniel Marjamäki and cppcheck team.</source>
+        <oldsource>Copyright © 2007-2010 Daniel Marjamäki and cppcheck team.</oldsource>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="about.ui" line="91"/>
@@ -39,69 +39,64 @@ of the GNU General Public License version 3</source>
 <context>
     <name>ApplicationDialog</name>
     <message>
-        <location filename="application.ui" line="17"/>
+        <location filename="application.ui" line="23"/>
         <source>Add an application</source>
         <translation>アプリケーションの追加</translation>
     </message>
     <message>
-        <location filename="application.ui" line="23"/>
-        <source>Here you can add applications that can open error files.
-Specify a name for the application and the application to execute.
+        <location filename="application.ui" line="41"/>
+        <source>Here you can add an application that can open error files. Specify a name for the application, the application executable and command line parameters for the application.
 
-The following texts are replaced with appropriate values when application is executed:
+The following texts in parameters are replaced with appropriate values when application is executed:
 (file) - Filename containing the error
 (line) - Line number containing the error
 (message) - Error message
 (severity) - Error severity
 
 Example opening a file with Kate and make Kate scroll to the correct line:
-kate -l(line) (file)</source>
-        <translation>エラーファイルを表示するアプリケーションを設定できます。
-アプリケーション名と実行ファイルパスを指定してください。
-
-アプリケーション実行時に以下の文字列は置き換えられます。
-(file) - 警告の発生したファイル名
-(line) - 警告の発生した行数
-(message) - 警告メッセージ
-(severity) - 警告種別
-
-設定例）
-kate -l(line) (file)</translation>
+Executable: kate
+Parameters: -l(line) (file)</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="application.ui" line="47"/>
-        <source>Application&apos;s name:</source>
-        <translation type="unfinished">アプリケーション名：</translation>
+        <location filename="application.ui" line="76"/>
+        <source>&amp;Name:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="application.ui" line="57"/>
-        <source>Command to execute:</source>
-        <translation type="unfinished">実行ファイルパス：</translation>
+        <location filename="application.ui" line="86"/>
+        <source>&amp;Executable:</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="application.ui" line="96"/>
+        <source>&amp;Parameters:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="application.ui" line="138"/>
         <source>Browse</source>
         <translation>参照</translation>
     </message>
     <message>
-        <location filename="applicationdialog.cpp" line="56"/>
+        <location filename="applicationdialog.cpp" line="58"/>
         <source>Executable files (*.exe);;All files(*.*)</source>
         <translation>実行ファイル (*.exe);;All files(*.*)</translation>
     </message>
     <message>
-        <location filename="applicationdialog.cpp" line="59"/>
+        <location filename="applicationdialog.cpp" line="61"/>
         <source>Select viewer application</source>
         <translation>表示アプリケーションの選択</translation>
     </message>
     <message>
-        <location filename="applicationdialog.cpp" line="96"/>
+        <location filename="applicationdialog.cpp" line="87"/>
         <source>Cppcheck</source>
         <translation>Cppcheck</translation>
     </message>
     <message>
-        <location filename="applicationdialog.cpp" line="97"/>
-        <source>You must specify a name and a path for the application!</source>
-        <translation>アプリケーション名と実行ファイルパスを入力してください</translation>
+        <location filename="applicationdialog.cpp" line="88"/>
+        <source>You must specify a name, a path and parameters for the application!</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -123,44 +118,6 @@ kate -l(line) (file)</translation>
         <translation>ファイル：%1 が読み込めません</translation>
     </message>
 </context>
-<context>
-    <name>HelpWindow</name>
-    <message>
-        <location filename="helpwindow.ui" line="14"/>
-        <source>Cppcheck Help</source>
-        <translation>Cppchekc ヘルプ</translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="22"/>
-        <source>Go back</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="25"/>
-        <source>Back</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="42"/>
-        <source>Go forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="45"/>
-        <source>Forward</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="62"/>
-        <source>Start</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="helpwindow.ui" line="65"/>
-        <source>Home</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>LogView</name>
     <message>
@@ -208,12 +165,13 @@ kate -l(line) (file)</translation>
     <name>MainWindow</name>
     <message>
         <location filename="main.ui" line="26"/>
-        <location filename="mainwindow.cpp" line="203"/>
-        <location filename="mainwindow.cpp" line="233"/>
-        <location filename="mainwindow.cpp" line="524"/>
-        <location filename="mainwindow.cpp" line="648"/>
-        <location filename="mainwindow.cpp" line="666"/>
-        <location filename="mainwindow.cpp" line="817"/>
+        <location filename="mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="235"/>
+        <location filename="mainwindow.cpp" line="262"/>
+        <location filename="mainwindow.cpp" line="558"/>
+        <location filename="mainwindow.cpp" line="682"/>
+        <location filename="mainwindow.cpp" line="703"/>
+        <location filename="mainwindow.cpp" line="825"/>
         <source>Cppcheck</source>
         <translation>Cppcheck</translation>
     </message>
@@ -525,44 +483,51 @@ kate -l(line) (file)</translation>
         <translation>ログ表示</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="204"/>
+        <location filename="mainwindow.cpp" line="176"/>
+        <source>There was a problem with loading the editor application settings.
+
+This is probably because the settings were changed between the Cppcheck versions. Please check (and fix) the editor application settings, otherwise the editor program might not start correctly.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="236"/>
         <source>No suitable files found to check!</source>
         <translation>解析可能なファイルではありません</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="234"/>
+        <location filename="mainwindow.cpp" line="263"/>
         <source>You must close the project file before selecting new files or directories!</source>
         <translation>新しいファイル／ディレクトリを解析するには現在のプロジェクトを閉じてください</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="249"/>
+        <location filename="mainwindow.cpp" line="278"/>
         <source>Select files to check</source>
         <translation>チェック対象のファイルを選択</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="263"/>
+        <location filename="mainwindow.cpp" line="292"/>
         <source>Select directory to check</source>
         <translation>チェック対象のディレクトリを選択</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="306"/>
-        <location filename="mainwindow.cpp" line="748"/>
-        <location filename="mainwindow.cpp" line="794"/>
+        <location filename="mainwindow.cpp" line="335"/>
+        <location filename="mainwindow.cpp" line="757"/>
+        <location filename="mainwindow.cpp" line="802"/>
         <source>Project: </source>
         <translation>プロジェクト：</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="443"/>
+        <location filename="mainwindow.cpp" line="480"/>
         <source>XML files (*.xml)</source>
         <translation>XML ファイル (*.xml)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="445"/>
+        <location filename="mainwindow.cpp" line="482"/>
         <source>Open the report file</source>
         <translation>レポートを開く</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="520"/>
+        <location filename="mainwindow.cpp" line="554"/>
         <source>Checking is running.
 
 Do you want to stop the checking and exit Cppcheck?.</source>
@@ -571,103 +536,83 @@ Do you want to stop the checking and exit Cppcheck?.</source>
 解析を停止してCppcheckを終了しますか？.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="567"/>
+        <location filename="mainwindow.cpp" line="601"/>
         <source>License</source>
         <translation>ライセンス</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="574"/>
+        <location filename="mainwindow.cpp" line="608"/>
         <source>Authors</source>
         <translation>作者</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="582"/>
+        <location filename="mainwindow.cpp" line="616"/>
         <source>XML files version 2 (*.xml);;XML files version 1 (*.xml);;Text files (*.txt);;CSV files (*.csv)</source>
         <oldsource>XML files (*.xml);;Text files (*.txt);;CSV files (*.csv)</oldsource>
         <translation type="unfinished">XML ファイル (*.xml);;テキストファイル (*.txt);;CSV形式ファイル (*.csv)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="584"/>
+        <location filename="mainwindow.cpp" line="618"/>
         <source>Save the report file</source>
         <translation>レポートを保存</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="592"/>
+        <location filename="mainwindow.cpp" line="626"/>
         <source>XML files version 1 (*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="598"/>
+        <location filename="mainwindow.cpp" line="632"/>
         <source>XML files version 2 (*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="604"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Text files (*.txt)</source>
         <translation>テキストファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="610"/>
+        <location filename="mainwindow.cpp" line="644"/>
         <source>CSV files (*.csv)</source>
         <translation>CSV形式ファイル (*.csv)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="650"/>
+        <location filename="mainwindow.cpp" line="684"/>
         <source>Cppcheck - %1</source>
         <translation>Cppcheck - %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="667"/>
-        <source>Failed to change the language:
+        <location filename="mainwindow.cpp" line="697"/>
+        <source>Failed to change the user interface language:
 
 %1
 
-</source>
-        <translation>言語の切り替えに失敗:
-
-%1
-
-</translation>
+The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="715"/>
-        <location filename="mainwindow.cpp" line="724"/>
-        <source>Cppcheck Help</source>
-        <translation>Cppcheck ヘルプ</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="715"/>
-        <source>Failed to load help file (not found)</source>
-        <translation>ヘルプファイルが見つかりませんでした</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="724"/>
-        <source>Failed to load help file</source>
-        <translation>ヘルプファイルの読み込みに失敗しました</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="738"/>
-        <location filename="mainwindow.cpp" line="783"/>
+        <location filename="mainwindow.cpp" line="741"/>
+        <location filename="mainwindow.cpp" line="791"/>
         <source>Project files (*.cppcheck);;All files(*.*)</source>
         <translation>プロジェクトファイル (*.cppcheck);;All files(*.*)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="740"/>
+        <location filename="mainwindow.cpp" line="743"/>
         <source>Select Project File</source>
         <translation>プロジェクトファイルを選択</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="785"/>
+        <location filename="mainwindow.cpp" line="793"/>
         <source>Select Project Filename</source>
         <translation>プロジェクトファイル名を選択</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="818"/>
+        <location filename="mainwindow.cpp" line="826"/>
         <source>No project file loaded</source>
         <translation>プロジェクトファイルが読み込まれていません</translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="31"/>
+        <location filename="translationhandler.cpp" line="33"/>
         <source>English</source>
         <translation></translation>
     </message>
@@ -677,38 +622,48 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="33"/>
+        <location filename="translationhandler.cpp" line="34"/>
         <source>Finnish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="34"/>
+        <location filename="translationhandler.cpp" line="35"/>
+        <source>French</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="translationhandler.cpp" line="41"/>
+        <source>Spanish</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="translationhandler.cpp" line="42"/>
         <source>Swedish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="35"/>
+        <location filename="translationhandler.cpp" line="36"/>
         <source>German</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="36"/>
+        <location filename="translationhandler.cpp" line="39"/>
         <source>Russian</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="37"/>
+        <location filename="translationhandler.cpp" line="38"/>
         <source>Polish</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="38"/>
+        <location filename="translationhandler.cpp" line="37"/>
         <source>Japanese</source>
         <oldsource>Japanease</oldsource>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="39"/>
+        <location filename="translationhandler.cpp" line="40"/>
         <source>Serbian</source>
         <translation type="unfinished"></translation>
     </message>
@@ -717,7 +672,7 @@ Do you want to stop the checking and exit Cppcheck?.</source>
     <name>Project</name>
     <message>
         <location filename="project.cpp" line="63"/>
-        <location filename="project.cpp" line="103"/>
+        <location filename="project.cpp" line="109"/>
         <source>Cppcheck</source>
         <translation>Cppcheck</translation>
     </message>
@@ -727,7 +682,7 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <translation type="unfinished">プロジェクトファイルが読み込めませんでした</translation>
     </message>
     <message>
-        <location filename="project.cpp" line="104"/>
+        <location filename="project.cpp" line="110"/>
         <source>Could not write the project file.</source>
         <translation type="unfinished">プロジェクトファイルが保存できませんでした</translation>
     </message>
@@ -740,28 +695,59 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <translation>プロジェクトファイル</translation>
     </message>
     <message>
-        <location filename="projectfile.ui" line="22"/>
+        <location filename="projectfile.ui" line="24"/>
+        <source>Project</source>
+        <translation type="unfinished">プロジェクト</translation>
+    </message>
+    <message>
+        <location filename="projectfile.ui" line="34"/>
         <source>Project:</source>
         <translation>プロジェクト名:</translation>
     </message>
     <message>
-        <location filename="projectfile.ui" line="39"/>
+        <location filename="projectfile.ui" line="70"/>
+        <location filename="projectfile.ui" line="207"/>
         <source>Paths:</source>
         <translation>パス:</translation>
     </message>
     <message>
-        <location filename="projectfile.ui" line="52"/>
-        <location filename="projectfile.ui" line="76"/>
-        <source>Browse...</source>
-        <translation></translation>
+        <location filename="projectfile.ui" line="97"/>
+        <location filename="projectfile.ui" line="162"/>
+        <location filename="projectfile.ui" line="221"/>
+        <source>Add...</source>
+        <translation type="unfinished">追加...</translation>
     </message>
     <message>
-        <location filename="projectfile.ui" line="63"/>
-        <source>Include paths:</source>
-        <translation>Include ディレクトリ:</translation>
+        <location filename="projectfile.ui" line="104"/>
+        <location filename="projectfile.ui" line="169"/>
+        <location filename="projectfile.ui" line="228"/>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="projectfile.ui" line="87"/>
+        <location filename="projectfile.ui" line="111"/>
+        <location filename="projectfile.ui" line="176"/>
+        <location filename="projectfile.ui" line="235"/>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="projectfile.ui" line="138"/>
+        <source>Includes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="projectfile.ui" line="144"/>
+        <source>Include directories:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="projectfile.ui" line="201"/>
+        <source>Ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="projectfile.ui" line="51"/>
         <source>Defines:</source>
         <translation>Defines:</translation>
     </message>
@@ -774,30 +760,35 @@ Do you want to stop the checking and exit Cppcheck?.</source>
         <translation>プロジェクトファイル:%1</translation>
     </message>
     <message>
-        <location filename="projectfiledialog.cpp" line="153"/>
+        <location filename="projectfiledialog.cpp" line="191"/>
         <source>Select include directory</source>
         <translation>includeディレクトリを選択</translation>
     </message>
     <message>
-        <location filename="projectfiledialog.cpp" line="165"/>
+        <location filename="projectfiledialog.cpp" line="203"/>
         <source>Select directory to check</source>
         <translation>チェック対象のディレクトリを選択</translation>
     </message>
+    <message>
+        <location filename="projectfiledialog.cpp" line="241"/>
+        <source>Select directory to ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="translationhandler.cpp" line="96"/>
-        <source>Incorrect language specified!</source>
+        <location filename="translationhandler.cpp" line="90"/>
+        <source>Unknown language specified!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="106"/>
+        <location filename="translationhandler.cpp" line="100"/>
         <source>Language file %1 not found!</source>
         <translation>言語ファイル %1 が見つかりません!</translation>
     </message>
     <message>
-        <location filename="translationhandler.cpp" line="112"/>
+        <location filename="translationhandler.cpp" line="106"/>
         <source>Failed to load translation for language %1 from file %2</source>
         <translation type="unfinished"></translation>
     </message>
@@ -805,71 +796,82 @@ Do you want to stop the checking and exit Cppcheck?.</source>
 <context>
     <name>ResultsTree</name>
     <message>
-        <location filename="resultstree.cpp" line="59"/>
-        <location filename="resultstree.cpp" line="978"/>
+        <location filename="resultstree.cpp" line="60"/>
+        <location filename="resultstree.cpp" line="1068"/>
         <source>File</source>
         <translation>ファイル</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="59"/>
-        <location filename="resultstree.cpp" line="978"/>
+        <location filename="resultstree.cpp" line="60"/>
+        <location filename="resultstree.cpp" line="1068"/>
         <source>Severity</source>
         <translation>警告種別</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="59"/>
-        <location filename="resultstree.cpp" line="978"/>
+        <location filename="resultstree.cpp" line="60"/>
+        <location filename="resultstree.cpp" line="1068"/>
         <source>Line</source>
         <translation>行</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="59"/>
-        <location filename="resultstree.cpp" line="978"/>
+        <location filename="resultstree.cpp" line="60"/>
+        <location filename="resultstree.cpp" line="1068"/>
         <source>Summary</source>
         <translation>内容</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="108"/>
+        <location filename="resultstree.cpp" line="110"/>
         <source>Undefined file</source>
         <translation>未定義ファイル</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="508"/>
+        <location filename="resultstree.cpp" line="205"/>
+        <location filename="resultstree.cpp" line="790"/>
+        <source>[Inconclusive]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="resultstree.cpp" line="356"/>
+        <source>debug</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="resultstree.cpp" line="605"/>
         <source>Copy filename</source>
         <translation>ファイル名をコピー</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="509"/>
+        <location filename="resultstree.cpp" line="606"/>
         <source>Copy full path</source>
         <translation>フルパスをコピー</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="510"/>
+        <location filename="resultstree.cpp" line="607"/>
         <source>Copy message</source>
         <translation>メッセージをコピー</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="511"/>
+        <location filename="resultstree.cpp" line="608"/>
         <source>Hide</source>
         <translation>非表示</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="558"/>
+        <location filename="resultstree.cpp" line="655"/>
         <source>Cppcheck</source>
         <translation>Cppcheck</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="559"/>
+        <location filename="resultstree.cpp" line="656"/>
         <source>Configure the text file viewer program in Cppcheck preferences/Applications.</source>
         <translation>メニューの「編集」→「設定」からテキストファイルを表示するアプリケーションを設定してください。</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="586"/>
+        <location filename="resultstree.cpp" line="684"/>
         <source>Could not find the file!</source>
         <translation type="unfinished">ファイルが見つかりません</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="624"/>
+        <location filename="resultstree.cpp" line="739"/>
         <source>Could not start %1
 
 Please check the application path and parameters are correct.</source>
@@ -878,7 +880,7 @@ Please check the application path and parameters are correct.</source>
 実行ファイルパスや引数の設定を確認してください。</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="638"/>
+        <location filename="resultstree.cpp" line="753"/>
         <source>Could not find file:
 %1
 Please select the directory where file is located.</source>
@@ -887,37 +889,37 @@ Please select the directory where file is located.</source>
 ディレクトリにファイルが存在するか確認してください。</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="645"/>
+        <location filename="resultstree.cpp" line="760"/>
         <source>Select Directory</source>
         <translation>ディレクトリを選択</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="827"/>
+        <location filename="resultstree.cpp" line="332"/>
         <source>style</source>
         <translation>スタイル</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="831"/>
+        <location filename="resultstree.cpp" line="336"/>
         <source>error</source>
         <translation>エラー</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="835"/>
+        <location filename="resultstree.cpp" line="340"/>
         <source>warning</source>
         <translation>警告</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="839"/>
+        <location filename="resultstree.cpp" line="344"/>
         <source>performance</source>
         <translation>パフォーマンス</translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="843"/>
+        <location filename="resultstree.cpp" line="348"/>
         <source>portability</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="resultstree.cpp" line="847"/>
+        <location filename="resultstree.cpp" line="352"/>
         <source>information</source>
         <translation type="unfinished"></translation>
     </message>
@@ -988,121 +990,143 @@ To toggle what kind of errors are shown, open view menu.</source>
         <translation>全般</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="32"/>
+        <location filename="settings.ui" line="169"/>
         <source>Include paths:</source>
         <translation>Include ディレクトリ:</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="45"/>
+        <location filename="settings.ui" line="187"/>
+        <location filename="settings.ui" line="239"/>
         <source>Add...</source>
         <translation>追加...</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="65"/>
+        <location filename="settings.ui" line="41"/>
         <source>Number of threads: </source>
         <translation>解析スレッド数:</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="109"/>
+        <location filename="settings.ui" line="85"/>
         <source>Ideal count:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settings.ui" line="116"/>
+        <location filename="settings.ui" line="92"/>
         <source>TextLabel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settings.ui" line="138"/>
+        <location filename="settings.ui" line="114"/>
         <source>Force checking all #ifdef configurations</source>
         <oldsource>Check all #ifdef configurations</oldsource>
         <translation type="unfinished">すべての #ifdef をチェックする</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="145"/>
+        <location filename="settings.ui" line="121"/>
         <source>Show full path of files</source>
         <translation>ファイルのフルパスを表示</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="152"/>
+        <location filename="settings.ui" line="128"/>
         <source>Show &quot;No errors found&quot; message when no errors found</source>
         <translation>エラーが無いときは&quot;エラーなし&quot;を表示</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="159"/>
+        <location filename="settings.ui" line="135"/>
         <source>Show internal warnings in log</source>
         <translation>cppcheck内部警告をログに表示する</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="166"/>
+        <location filename="settings.ui" line="142"/>
         <source>Enable inline suppressions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settings.ui" line="187"/>
+        <location filename="settings.ui" line="163"/>
+        <source>Paths</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="194"/>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="201"/>
+        <location filename="settings.ui" line="253"/>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="226"/>
         <source>Applications</source>
         <translation>アプリケーション</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="196"/>
-        <source>Add application</source>
-        <translation>アプリケーションを追加</translation>
+        <location filename="settings.ui" line="246"/>
+        <source>Edit...</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settings.ui" line="203"/>
-        <source>Delete application</source>
-        <translation>アプリケーションの削除</translation>
+        <location filename="settings.ui" line="260"/>
+        <source>Set as default</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settings.ui" line="210"/>
-        <source>Modify application</source>
-        <translation>アプリケーション設定の変更</translation>
-    </message>
-    <message>
-        <location filename="settings.ui" line="217"/>
-        <source>Set as default application</source>
-        <translation>デフォルトアプリケーションに設定</translation>
-    </message>
-    <message>
-        <location filename="settings.ui" line="225"/>
+        <location filename="settings.ui" line="285"/>
         <source>Reports</source>
         <translation>レポート</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="231"/>
+        <location filename="settings.ui" line="291"/>
         <source>Save all errors when creating report</source>
         <translation>すべての警告/エラーを保存</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="238"/>
+        <location filename="settings.ui" line="298"/>
         <source>Save full path to files in reports</source>
         <translation>ファイルのフルパスを保存</translation>
     </message>
     <message>
-        <location filename="settings.ui" line="259"/>
+        <location filename="settings.ui" line="319"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="settings.ui" line="333"/>
+        <source>Advanced</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settings.ui" line="339"/>
+        <source>&amp;Show inconclusive errors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="settingsdialog.cpp" line="81"/>
+        <location filename="settingsdialog.cpp" line="85"/>
         <source>N/A</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="161"/>
+        <location filename="settingsdialog.cpp" line="204"/>
         <source>Add a new application</source>
         <translation>新しいアプリケーションの追加</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="194"/>
+        <location filename="settingsdialog.cpp" line="241"/>
         <source>Modify an application</source>
         <translation>アプリケーションの変更</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="259"/>
+        <location filename="settingsdialog.cpp" line="274"/>
+        <source>[Default]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="321"/>
         <source>Select include directory</source>
         <translation>include ディレクトリを選択</translation>
     </message>
@@ -1299,4 +1323,12 @@ Statistics
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TxtReport</name>
+    <message>
+        <location filename="txtreport.cpp" line="81"/>
+        <source>inconclusive</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
