@@ -16,7 +16,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "mainwindow.h"
 #include <QApplication>
 #include <QDebug>
 #include <QMenu>
@@ -27,6 +26,9 @@
 #include <QKeySequence>
 #include <QFileInfo>
 #include <QDir>
+#include <QDesktopServices>
+#include <QUrl>
+#include "mainwindow.h"
 #include "aboutdialog.h"
 #include "threadhandler.h"
 #include "fileviewdialog.h"
@@ -36,15 +38,14 @@
 #include "statsdialog.h"
 #include "logview.h"
 #include "filelist.h"
-#include "helpwindow.h"
+
+static const QString OnlineHelpURL("http://cppcheck.sourceforge.net/manual.html");
 
 MainWindow::MainWindow() :
     mSettings(new QSettings("Cppcheck", "Cppcheck-GUI", this)),
     mApplications(new ApplicationList(this)),
     mTranslation(new TranslationHandler(this)),
-    mLanguages(new QActionGroup(this)),
     mLogView(NULL),
-    mHelpWindow(NULL),
     mProject(NULL),
     mExiting(false)
 {
@@ -52,7 +53,20 @@ MainWindow::MainWindow() :
     mUI.mResults->Initialize(mSettings, mApplications);
 
     mThread = new ThreadHandler(this);
-    mLogView = new LogView(mSettings);
+    mLogView = new LogView;
+
+    // Filter timer to delay filtering results slightly while typing
+    mFilterTimer = new QTimer(this);
+    mFilterTimer->setInterval(500);
+    mFilterTimer->setSingleShot(true);
+    connect(mFilterTimer, SIGNAL(timeout()), this, SLOT(FilterResults()));
+
+    // "Filter" toolbar
+    mLineEditFilter = new QLineEdit(mUI.mToolBarFilter);
+    mLineEditFilter->setPlaceholderText(tr("Quick Filter:"));
+    mUI.mToolBarFilter->addWidget(mLineEditFilter);
+    connect(mLineEditFilter, SIGNAL(textChanged(const QString&)), mFilterTimer, SLOT(start()));
+    connect(mLineEditFilter, SIGNAL(returnPressed()), this, SLOT(FilterResults()));
 
     connect(mUI.mActionQuit, SIGNAL(triggered()), this, SLOT(close()));
     connect(mUI.mActionCheckFiles, SIGNAL(triggered()), this, SLOT(CheckFiles()));
@@ -80,10 +94,14 @@ MainWindow::MainWindow() :
     connect(mUI.mActionStop, SIGNAL(triggered()), this, SLOT(StopChecking()));
     connect(mUI.mActionSave, SIGNAL(triggered()), this, SLOT(Save()));
 
+    // About menu
     connect(mUI.mActionAbout, SIGNAL(triggered()), this, SLOT(About()));
     connect(mUI.mActionLicense, SIGNAL(triggered()), this, SLOT(ShowLicense()));
+
+    // View > Toolbar menu
     connect(mUI.mActionToolBarMain, SIGNAL(toggled(bool)), this, SLOT(ToggleMainToolBar()));
     connect(mUI.mActionToolBarView, SIGNAL(toggled(bool)), this, SLOT(ToggleViewToolBar()));
+    connect(mUI.mActionToolBarFilter, SIGNAL(toggled(bool)), this, SLOT(ToggleFilterToolBar()));
 
     connect(mUI.mActionAuthors, SIGNAL(triggered()), this, SLOT(ShowAuthors()));
     connect(mThread, SIGNAL(Done()), this, SLOT(CheckDone()));
@@ -91,6 +109,7 @@ MainWindow::MainWindow() :
     connect(mUI.mResults, SIGNAL(ResultsHidden(bool)), mUI.mActionShowHidden, SLOT(setEnabled(bool)));
     connect(mUI.mMenuView, SIGNAL(aboutToShow()), this, SLOT(AboutToShowViewMenu()));
 
+    // File menu
     connect(mUI.mActionNewProjectFile, SIGNAL(triggered()), this, SLOT(NewProjectFile()));
     connect(mUI.mActionOpenProjectFile, SIGNAL(triggered()), this, SLOT(OpenProjectFile()));
     connect(mUI.mActionCloseProjectFile, SIGNAL(triggered()), this, SLOT(CloseProjectFile()));
@@ -116,19 +135,44 @@ MainWindow::MainWindow() :
     args.removeFirst();
     if (!args.isEmpty())
     {
-        DoCheckFiles(args);
+        HandleCLIParams(args);
     }
+
+    for (int i = 0; i < MaxRecentProjects; ++i)
+    {
+        mRecentProjectActs[i] = new QAction(this);
+        mRecentProjectActs[i]->setVisible(false);
+        connect(mRecentProjectActs[i], SIGNAL(triggered()),
+                this, SLOT(OpenRecentProject()));
+    }
+    mUI.mActionProjectMRU->setVisible(false);
+    UpdateMRUMenuItems();
 }
 
 MainWindow::~MainWindow()
 {
     delete mLogView;
-    delete mHelpWindow;
     delete mProject;
 }
 
+void MainWindow::HandleCLIParams(const QStringList &params)
+{
+    if (params.contains("-p"))
+    {
+        QString projFile;
+        const int ind = params.indexOf("-p");
+        if ((ind + 1) < params.length())
+            projFile = params[ind + 1];
+
+        LoadProjectFile(projFile);
+    }
+    else
+        DoCheckFiles(params);
+}
+
 void MainWindow::LoadSettings()
 {
+    // Window/dialog sizes
     if (mSettings->value(SETTINGS_WINDOW_MAXIMIZED, false).toBool())
     {
         showMaximized();
@@ -139,6 +183,7 @@ void MainWindow::LoadSettings()
                mSettings->value(SETTINGS_WINDOW_HEIGHT, 600).toInt());
     }
 
+    // Show * states
     mUI.mActionShowStyle->setChecked(mSettings->value(SETTINGS_SHOW_STYLE, true).toBool());
     mUI.mActionShowErrors->setChecked(mSettings->value(SETTINGS_SHOW_ERRORS, true).toBool());
     mUI.mActionShowWarnings->setChecked(mSettings->value(SETTINGS_SHOW_WARNINGS, true).toBool());
@@ -149,13 +194,37 @@ void MainWindow::LoadSettings()
     mUI.mResults->ShowResults(SHOW_ERRORS, mUI.mActionShowErrors->isChecked());
     mUI.mResults->ShowResults(SHOW_STYLE, mUI.mActionShowStyle->isChecked());
 
-    mUI.mActionToolBarMain->setChecked(mSettings->value(SETTINGS_TOOLBARS_MAIN_SHOW, true).toBool());
-    mUI.mToolBarMain->setVisible(mSettings->value(SETTINGS_TOOLBARS_MAIN_SHOW, true).toBool());
-    mUI.mToolBarView->setVisible(mSettings->value(SETTINGS_TOOLBARS_VIEW_SHOW, true).toBool());
+    // Main window settings
+    const bool showMainToolbar = mSettings->value(SETTINGS_TOOLBARS_MAIN_SHOW, true).toBool();
+    mUI.mActionToolBarMain->setChecked(showMainToolbar);
+    mUI.mToolBarMain->setVisible(showMainToolbar);
 
-    mApplications->LoadSettings(mSettings);
+    const bool showViewToolbar = mSettings->value(SETTINGS_TOOLBARS_VIEW_SHOW, true).toBool();
+    mUI.mActionToolBarView->setChecked(showViewToolbar);
+    mUI.mToolBarView->setVisible(showViewToolbar);
+
+    const bool showFilterToolbar = mSettings->value(SETTINGS_TOOLBARS_FILTER_SHOW, true).toBool();
+    mUI.mActionToolBarFilter->setChecked(showFilterToolbar);
+    mUI.mToolBarFilter->setVisible(showFilterToolbar);
+
+    SetLanguage(mSettings->value(SETTINGS_LANGUAGE, mTranslation->SuggestLanguage()).toString());
+
+    bool succeeded = mApplications->LoadSettings(mSettings);
+    if (!succeeded)
+    {
+        QString msg = tr("There was a problem with loading the editor application settings.\n\n"
+                         "This is probably because the settings were changed between the Cppcheck versions. "
+                         "Please check (and fix) the editor application settings, otherwise the editor "
+                         "program might not start correctly.");
+        QMessageBox msgBox(QMessageBox::Warning,
+                           tr("Cppcheck"),
+                           msg,
+                           QMessageBox::Ok,
+                           this);
+        msgBox.exec();
+
+    }
 
-    SetLanguage(mSettings->value(SETTINGS_LANGUAGE, mTranslation->SuggestLanguage()).toInt());
 }
 
 void MainWindow::SaveSettings()
@@ -163,18 +232,23 @@ void MainWindow::SaveSettings()
     //Force toolbar checkbox value to be updated
     AboutToShowViewMenu();
 
+    // Window/dialog sizes
     mSettings->setValue(SETTINGS_WINDOW_WIDTH, size().width());
     mSettings->setValue(SETTINGS_WINDOW_HEIGHT, size().height());
     mSettings->setValue(SETTINGS_WINDOW_MAXIMIZED, isMaximized());
 
+    // Show * states
     mSettings->setValue(SETTINGS_SHOW_STYLE, mUI.mActionShowStyle->isChecked());
     mSettings->setValue(SETTINGS_SHOW_ERRORS, mUI.mActionShowErrors->isChecked());
     mSettings->setValue(SETTINGS_SHOW_WARNINGS, mUI.mActionShowWarnings->isChecked());
     mSettings->setValue(SETTINGS_SHOW_PORTABILITY, mUI.mActionShowPortability->isChecked());
     mSettings->setValue(SETTINGS_SHOW_PERFORMANCE, mUI.mActionShowPerformance->isChecked());
     mSettings->setValue(SETTINGS_SHOW_INFORMATION, mUI.mActionShowInformation->isChecked());
+
+    // Main window settings
     mSettings->setValue(SETTINGS_TOOLBARS_MAIN_SHOW, mUI.mToolBarMain->isVisible());
     mSettings->setValue(SETTINGS_TOOLBARS_VIEW_SHOW, mUI.mToolBarView->isVisible());
+    mSettings->setValue(SETTINGS_TOOLBARS_FILTER_SHOW, mUI.mToolBarFilter->isVisible());
 
     mApplications->SaveSettings(mSettings);
 
@@ -192,6 +266,8 @@ void MainWindow::DoCheckFiles(const QStringList &files)
 
     FileList pathList;
     pathList.AddPathList(files);
+    if (mProject)
+        pathList.AddIngoreList(mProject->GetProjectFile()->GetIgnoredPaths());
     QStringList fileNames = pathList.GetFileList();
 
     mUI.mResults->Clear();
@@ -214,14 +290,15 @@ void MainWindow::DoCheckFiles(const QStringList &files)
     QDir inf(mCurrentDirectory);
     const QString checkPath = inf.canonicalPath();
     mSettings->setValue(SETTINGS_CHECK_PATH, checkPath);
-    EnableCheckButtons(false);
-    mUI.mActionSettings->setEnabled(false);
-    mUI.mActionOpenXML->setEnabled(false);
-    mUI.mResults->SetCheckDirectory(checkPath);
 
+    CheckLockDownUI(); // lock UI while checking
+
+    mUI.mResults->SetCheckDirectory(checkPath);
     Settings checkSettings = GetCppcheckSettings();
-    EnableProjectActions(false);
-    EnableProjectOpenActions(false);
+
+    if (mProject)
+        qDebug() << "Checking project file" << mProject->GetProjectFile()->GetFilename();
+
     mThread->Check(checkSettings, false);
 }
 
@@ -282,32 +359,69 @@ void MainWindow::CheckFiles()
 
 void MainWindow::CheckDirectory()
 {
-    DoCheckFiles(SelectFilesToCheck(QFileDialog::DirectoryOnly));
-}
+    QStringList dir = SelectFilesToCheck(QFileDialog::DirectoryOnly);
+    if (dir.isEmpty())
+        return;
 
-bool MainWindow::GetCheckProject()
-{
-    // We have successfully loaded project earlier and use that project
-    if (mProject)
-        return true;
-
-    if (!mCurrentDirectory.isEmpty())
+    QDir checkDir(dir[0]);
+    QStringList filters;
+    filters << "*.cppcheck";
+    checkDir.setFilter(QDir::Files | QDir::Readable);
+    checkDir.setNameFilters(filters);
+    QStringList projFiles = checkDir.entryList();
+    if (!projFiles.empty())
     {
-        // Format project filename (directory name + .cppcheck) and load
-        // the project file if it is found.
-        QStringList parts = mCurrentDirectory.split("/");
-        const QString filename = parts[parts.count() - 1] + ".cppcheck";;
-        const QString projfile = mCurrentDirectory + "/" + filename;
-        if (QFile::exists(projfile))
+        if (projFiles.size() == 1)
         {
-            qDebug() << "Opening project file: " << projfile;
-            mProject = new Project();
-            mProject->SetFilename(projfile);
-            FormatAndSetTitle(tr("Project: ") + QString(" ") + filename);
-            return mProject->Open();
+            // If one project file found, suggest loading it
+            QMessageBox msgBox(this);
+            msgBox.setWindowTitle(tr("Cppcheck"));
+            const QString msg(tr("Found project file: %1\n\nDo you want to "
+                                 "load this project file instead?").arg(projFiles[0]));
+            msgBox.setText(msg);
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.addButton(QMessageBox::Yes);
+            msgBox.addButton(QMessageBox::No);
+            msgBox.setDefaultButton(QMessageBox::Yes);
+            int dlgResult = msgBox.exec();
+            if (dlgResult == QMessageBox::Yes)
+            {
+                QString path = checkDir.canonicalPath();
+                if (!path.endsWith("/"))
+                    path += "/";
+                path += projFiles[0];
+                LoadProjectFile(path);
+            }
+            else
+            {
+                DoCheckFiles(dir);
+            }
+        }
+        else
+        {
+            // If multiple project files found inform that there are project
+            // files also available.
+            QMessageBox msgBox(this);
+            msgBox.setWindowTitle(tr("Cppcheck"));
+            const QString msg(tr("Found project files from the directory.\n\n"
+                                 "Do you want to proceed checking without "
+                                 "using any of these project files?"));
+            msgBox.setText(msg);
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.addButton(QMessageBox::Yes);
+            msgBox.addButton(QMessageBox::No);
+            msgBox.setDefaultButton(QMessageBox::Yes);
+            int dlgResult = msgBox.exec();
+            if (dlgResult == QMessageBox::Yes)
+            {
+                DoCheckFiles(dir);
+            }
         }
     }
-    return false;
+    else
+    {
+        DoCheckFiles(dir);
+    }
 }
 
 void MainWindow::AddIncludeDirs(const QStringList &includeDirs, Settings &result)
@@ -339,8 +453,8 @@ Settings MainWindow::GetCppcheckSettings()
         AddIncludeDirs(includes, result);
     }
 
-    bool projectRead = GetCheckProject();
-    if (projectRead)
+    // If project file loaded, read settings from it
+    if (mProject)
     {
         ProjectFile *pfile = mProject->GetProjectFile();
         QStringList dirs = pfile->GetIncludeDirs();
@@ -367,6 +481,7 @@ Settings MainWindow::GetCppcheckSettings()
     result._xml = false;
     result._jobs = mSettings->value(SETTINGS_CHECK_THREADS, 1).toInt();
     result._inlineSuppressions = mSettings->value(SETTINGS_INLINE_SUPPRESSIONS, false).toBool();
+    result.inconclusive = mSettings->value(SETTINGS_INCONCLUSIVE_ERRORS, false).toBool();
 
     if (result._jobs <= 0)
     {
@@ -401,9 +516,18 @@ void MainWindow::CheckDone()
     QApplication::alert(this, 3000);
 }
 
+void MainWindow::CheckLockDownUI()
+{
+    EnableCheckButtons(false);
+    mUI.mActionSettings->setEnabled(false);
+    mUI.mActionOpenXML->setEnabled(false);
+    EnableProjectActions(false);
+    EnableProjectOpenActions(false);
+}
+
 void MainWindow::ProgramSettings()
 {
-    SettingsDialog dialog(mSettings, mApplications, mTranslation, this);
+    SettingsDialog dialog(mApplications, mTranslation, this);
     if (dialog.exec() == QDialog::Accepted)
     {
         dialog.SaveSettingValues();
@@ -411,22 +535,23 @@ void MainWindow::ProgramSettings()
                                      dialog.SaveFullPath(),
                                      dialog.SaveAllErrors(),
                                      dialog.ShowNoErrorsMessage());
-        const int currentLang = mTranslation->GetCurrentLanguage();
-        const int newLang = mSettings->value(SETTINGS_LANGUAGE, 0).toInt();
-        if (currentLang != newLang)
-            SetLanguage(newLang);
+        const QString newLang = mSettings->value(SETTINGS_LANGUAGE, "en").toString();
+        SetLanguage(newLang);
     }
 }
 
 void MainWindow::ReCheck()
 {
     ClearResults();
-    EnableCheckButtons(false);
+    CheckLockDownUI(); // lock UI while checking
 
     const int filesCount = mThread->GetPreviousFilesCount();
     Q_ASSERT(filesCount > 0); // If no files should not be able to recheck
     mUI.mResults->CheckingStarted(filesCount);
 
+    if (mProject)
+        qDebug() << "Rechecking project file" << mProject->GetProjectFile()->GetFilename();
+
     mThread->Check(GetCppcheckSettings(), true);
 }
 
@@ -509,9 +634,6 @@ void MainWindow::closeEvent(QCloseEvent *event)
     // Check that we aren't checking files
     if (!mThread->IsChecking())
     {
-        delete mHelpWindow;
-        mHelpWindow = NULL;
-
         SaveSettings();
         event->accept();
     }
@@ -641,6 +763,12 @@ void MainWindow::ToggleViewToolBar()
     mUI.mToolBarView->setVisible(mUI.mActionToolBarView->isChecked());
 }
 
+void MainWindow::ToggleFilterToolBar()
+{
+    mUI.mToolBarFilter->setVisible(mUI.mActionToolBarFilter->isChecked());
+    mLineEditFilter->clear(); // Clearing the filter also disables filtering
+}
+
 void MainWindow::FormatAndSetTitle(const QString &text)
 {
     QString title;
@@ -651,40 +779,32 @@ void MainWindow::FormatAndSetTitle(const QString &text)
     setWindowTitle(title);
 }
 
-
-void MainWindow::SetLanguage(int index)
+void MainWindow::SetLanguage(const QString &code)
 {
-    if (mTranslation->GetCurrentLanguage() == index)
-    {
+    const QString currentLang = mTranslation->GetCurrentLanguage();
+    if (currentLang == code)
         return;
-    }
 
     QString error;
-    if (!mTranslation->SetLanguage(index, error))
+    if (!mTranslation->SetLanguage(code, error))
     {
-        QMessageBox msg(QMessageBox::Critical,
-                        tr("Cppcheck"),
-                        QString(tr("Failed to change the language:\n\n%1\n\n")).arg(error),
-                        QMessageBox::Ok,
-                        this);
-
-        msg.exec();
+        const QString msg(tr("Failed to change the user interface language:"
+                             "\n\n%1\n\n"
+                             "The user interface language has been reset to English. Open "
+                             "the Preferences-dialog to select any of the available "
+                             "languages.").arg(error));
+        QMessageBox msgBox(QMessageBox::Warning,
+                           tr("Cppcheck"),
+                           msg,
+                           QMessageBox::Ok,
+                           this);
+        msgBox.exec();
     }
     else
     {
         //Translate everything that is visible here
         mUI.retranslateUi(this);
         mUI.mResults->Translate();
-        QStringList languages = mTranslation->GetNames();
-        QList<QAction *> actions = mLanguages->actions();
-
-        if (languages.size() <= actions.size())
-        {
-            for (int i = 0; i < languages.size(); i++)
-            {
-                actions[i]->setText(tr(languages[i].toLatin1()));
-            }
-        }
     }
 }
 
@@ -702,39 +822,16 @@ void MainWindow::StopChecking()
 
 void MainWindow::OpenHelpContents()
 {
-    OpenHtmlHelpContents();
+    OpenOnlineHelp();
 }
 
-void MainWindow::OpenHtmlHelpContents()
+void MainWindow::OpenOnlineHelp()
 {
-    if (mHelpWindow == NULL)
-    {
-        const QString fname = qApp->applicationDirPath() + "/online-help.qhc";
-        if (!QFileInfo(fname).exists())
-        {
-            QMessageBox::warning(this, tr("Cppcheck Help"), tr("Failed to load help file (not found)"));
-            return;
-        }
-
-        mHelpWindow = new HelpWindow;
-        if (!mHelpWindow->load(fname))
-        {
-            delete mHelpWindow;
-            mHelpWindow = NULL;
-            QMessageBox::warning(this, tr("Cppcheck Help"), tr("Failed to load help file"));
-            return;
-        }
-    }
-
-    mHelpWindow->show();
-    if (!mHelpWindow->isActiveWindow())
-        mHelpWindow->activateWindow();
+    QDesktopServices::openUrl(QUrl(OnlineHelpURL));
 }
 
 void MainWindow::OpenProjectFile()
 {
-    delete mProject;
-
     const QString filter = tr("Project files (*.cppcheck);;All files(*.*)");
     QString filepath = QFileDialog::getOpenFileName(this,
                        tr("Select Project File"),
@@ -743,39 +840,53 @@ void MainWindow::OpenProjectFile()
 
     if (!filepath.isEmpty())
     {
-        QFileInfo inf(filepath);
-        const QString filename = inf.fileName();
-        FormatAndSetTitle(tr("Project: ") + QString(" ") + filename);
+        LoadProjectFile(filepath);
+    }
+}
 
-        mUI.mActionCloseProjectFile->setEnabled(true);
-        mUI.mActionEditProjectFile->setEnabled(true);
-        mProject = new Project(filepath, this);
-        mProject->Open();
-        QString rootpath = mProject->GetProjectFile()->GetRootPath();
+void MainWindow::LoadProjectFile(const QString &filePath)
+{
+    QFileInfo inf(filePath);
+    const QString filename = inf.fileName();
+    FormatAndSetTitle(tr("Project:") + QString(" ") + filename);
+    AddProjectMRU(filePath);
 
-        // If root path not give or "current dir" then use project file's directory
-        // as check path
-        if (rootpath.isEmpty() || rootpath == ".")
-            mCurrentDirectory = inf.canonicalPath();
-        else
-            mCurrentDirectory = rootpath;
+    mUI.mActionCloseProjectFile->setEnabled(true);
+    mUI.mActionEditProjectFile->setEnabled(true);
+    delete mProject;
+    mProject = new Project(filePath, this);
+    mProject->Open();
+    QString rootpath = mProject->GetProjectFile()->GetRootPath();
 
-        QStringList paths = mProject->GetProjectFile()->GetCheckPaths();
-        if (!paths.isEmpty())
+    // If the root path is not given or is not "current dir", use project
+    // file's location directory as root path
+    if (rootpath.isEmpty() || rootpath == ".")
+        mCurrentDirectory = inf.canonicalPath();
+    else
+        mCurrentDirectory = rootpath;
+
+    QStringList paths = mProject->GetProjectFile()->GetCheckPaths();
+
+    // If paths not given then check the root path (which may be the project
+    // file's location, see above). This is to keep the compatibility with
+    // old "silent" project file loading when we checked the director where the
+    // project file was located.
+    if (paths.isEmpty())
+    {
+        paths << mCurrentDirectory;
+    }
+
+    // Convert relative paths to absolute paths
+    for (int i = 0; i < paths.size(); i++)
+    {
+        if (!QDir::isAbsolutePath(paths[i]))
         {
-            for (int i = 0; i < paths.size(); i++)
-            {
-                if (!QDir::isAbsolutePath(paths[i]))
-                {
-                    QString path = mCurrentDirectory + "/";
-                    path += paths[i];
-                    paths[i] = QDir::cleanPath(path);
-                }
-            }
-
-            DoCheckFiles(paths);
+            QString path = mCurrentDirectory + "/";
+            path += paths[i];
+            paths[i] = QDir::cleanPath(path);
         }
     }
+    DoCheckFiles(paths);
 }
 
 void MainWindow::NewProjectFile()
@@ -791,13 +902,14 @@ void MainWindow::NewProjectFile()
         EnableProjectActions(true);
         QFileInfo inf(filepath);
         const QString filename = inf.fileName();
-        FormatAndSetTitle(tr("Project: ") + QString(" ") + filename);
+        FormatAndSetTitle(tr("Project:") + QString(" ") + filename);
 
         delete mProject;
         mProject = new Project(filepath, this);
         mProject->Create();
         mProject->Edit();
     }
+    AddProjectMRU(filepath);
 }
 
 void MainWindow::CloseProjectFile()
@@ -827,7 +939,7 @@ void MainWindow::EditProjectFile()
 void MainWindow::ShowLogView()
 {
     if (mLogView == NULL)
-        mLogView = new LogView(mSettings);
+        mLogView = new LogView;
 
     mLogView->show();
     if (!mLogView->isActiveWindow())
@@ -867,6 +979,11 @@ void MainWindow::DebugError(const ErrorItem &item)
     }
 }
 
+void MainWindow::FilterResults()
+{
+    mUI.mResults->FilterResults(mLineEditFilter->text());
+}
+
 void MainWindow::EnableProjectActions(bool enable)
 {
     mUI.mActionCloseProjectFile->setEnabled(enable);
@@ -878,3 +995,82 @@ void MainWindow::EnableProjectOpenActions(bool enable)
     mUI.mActionNewProjectFile->setEnabled(enable);
     mUI.mActionOpenProjectFile->setEnabled(enable);
 }
+
+void MainWindow::OpenRecentProject()
+{
+    QAction *action = qobject_cast<QAction *>(sender());
+    if (action)
+    {
+        const QString project = action->data().toString();
+        QFileInfo inf(project);
+        if (inf.exists())
+        {
+            LoadProjectFile(project);
+        }
+        else
+        {
+            QString text(tr("The project file\n\n%1\n\n could not be found!\n\n"
+                            "Do you want to remove the file from the recently "
+                            "used projects -list?").arg(project));
+
+            QMessageBox msg(QMessageBox::Warning,
+                            tr("Cppcheck"),
+                            text,
+                            QMessageBox::Yes | QMessageBox::No,
+                            this);
+
+            msg.setDefaultButton(QMessageBox::No);
+            int rv = msg.exec();
+            if (rv == QMessageBox::Yes)
+            {
+                RemoveProjectMRU(project);
+            }
+
+        }
+    }
+}
+
+void MainWindow::UpdateMRUMenuItems()
+{
+    for (int i = 0; i < MaxRecentProjects; i++)
+    {
+        if (mRecentProjectActs[i] != NULL)
+            mUI.mMenuFile->removeAction(mRecentProjectActs[i]);
+    }
+
+    QStringList projects = mSettings->value(SETTINGS_MRU_PROJECTS).toStringList();
+    const int numRecentProjects = qMin(projects.size(), (int)MaxRecentProjects);
+    for (int i = 0; i < numRecentProjects; i++)
+    {
+        const QString filename = QFileInfo(projects[i]).fileName();
+        const QString text = QString("&%1 %2").arg(i + 1).arg(filename);
+        mRecentProjectActs[i]->setText(text);
+        mRecentProjectActs[i]->setData(projects[i]);
+        mRecentProjectActs[i]->setVisible(true);
+        mUI.mMenuFile->insertAction(mUI.mActionProjectMRU, mRecentProjectActs[i]);
+    }
+
+    if (numRecentProjects > 1)
+        mUI.mMenuFile->insertSeparator(mUI.mActionProjectMRU);
+}
+
+void MainWindow::AddProjectMRU(const QString &project)
+{
+    QStringList files = mSettings->value(SETTINGS_MRU_PROJECTS).toStringList();
+    files.removeAll(project);
+    files.prepend(project);
+    while (files.size() > MaxRecentProjects)
+        files.removeLast();
+
+    mSettings->setValue(SETTINGS_MRU_PROJECTS, files);
+    UpdateMRUMenuItems();
+}
+
+void MainWindow::RemoveProjectMRU(const QString &project)
+{
+    QStringList files = mSettings->value(SETTINGS_MRU_PROJECTS).toStringList();
+    files.removeAll(project);
+
+    mSettings->setValue(SETTINGS_MRU_PROJECTS, files);
+    UpdateMRUMenuItems();
+}
