@@ -24,6 +24,7 @@
 #include <QFileDialog>
 #include <QSignalMapper>
 #include <QActionGroup>
+#include <QTimer>
 #include <QToolBar>
 #include <QStringList>
 
@@ -35,10 +36,10 @@
 
 class ThreadHandler;
 class LogView;
-class HelpWindow;
 class Project;
 class ErrorItem;
 class StatsDialog;
+class QAction;
 
 /// @addtogroup GUI
 /// @{
@@ -51,6 +52,12 @@ class MainWindow : public QMainWindow
 {
     Q_OBJECT
 public:
+
+    /**
+    * @brief Maximum number of MRU project items in File-menu.
+    */
+    enum { MaxRecentProjects = 5 };
+
     MainWindow();
     virtual ~MainWindow();
 
@@ -228,6 +235,11 @@ protected slots:
     */
     void ToggleViewToolBar();
 
+    /**
+    * @brief Slot for showing/hiding Filter toolbar
+    */
+    void ToggleFilterToolBar();
+
     /**
     * @brief Slot for updating View-menu before it is shown.
     */
@@ -257,6 +269,16 @@ protected slots:
     */
     void DebugError(const ErrorItem &item);
 
+    /**
+    * @brief Filters the results in the result list.
+    */
+    void FilterResults();
+
+    /**
+    * @brief Opens recently opened project file.
+    */
+    void OpenRecentProject();
+
 protected:
 
     /**
@@ -299,15 +321,6 @@ protected:
     */
     void DoCheckFiles(const QStringList &files);
 
-    /**
-    * @brief Check if we have a project for the checked directory.
-    * This method checks if there is open project for the directory. If no open
-    * project then we check if there is project file in the directory and load
-    * it.
-    * @return true if we have project, false if no project.
-    */
-    bool GetCheckProject();
-
     /**
     * @brief Get our default cppcheck settings and read project file.
     *
@@ -372,6 +385,23 @@ protected:
     */
     void LoadProjectFile(const QString &filePath);
 
+    /**
+    * @brief Update project MRU items in File-menu.
+    */
+    void UpdateMRUMenuItems();
+
+    /**
+    * @brief Add project file (path) to the MRU list.
+    * @param project Full path to the project file to add.
+    */
+    void AddProjectMRU(const QString &project);
+
+    /**
+    * @brief Remove project file (path) from the MRU list.
+    * @param project Full path of the project file to remove.
+    */
+    void RemoveProjectMRU(const QString &project);
+
     /**
     * @brief Program settings
     *
@@ -417,6 +447,16 @@ protected:
     */
     Project *mProject;
 
+    /**
+    * @brief Filter field in the Filter toolbar.
+    */
+    QLineEdit* mLineEditFilter;
+
+    /**
+    * @brief Timer to delay filtering while typing.
+    */
+    QTimer* mFilterTimer;
+
 private:
 
     /**
@@ -426,6 +466,10 @@ private:
     */
     bool mExiting;
 
+    /**
+    * @brief Project MRU menu actions.
+    */
+    QAction *mRecentProjectActs[MaxRecentProjects];
 };
 /// @}
 #endif // MAINWINDOW_H
