@@ -44,6 +44,7 @@
 #include "resultstree.h"
 #include "report.h"
 #include "xmlreport.h"
+#include "application.h"
 
 ResultsTree::ResultsTree(QWidget * parent) :
     QTreeView(parent),
@@ -87,8 +88,9 @@ QStandardItem *ResultsTree::CreateNormalItem(const QString &name)
 
 QStandardItem *ResultsTree::CreateLineNumberItem(const QString &linenumber)
 {
-    QStandardItem *item = new QStandardItem(linenumber);
-    item->setData(linenumber, Qt::ToolTipRole);
+    QStandardItem *item = new QStandardItem();
+    item->setData(QVariant(linenumber.toULongLong()), Qt::DisplayRole);
+    item->setToolTip(linenumber);
     item->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
     item->setEditable(false);
     return item;
@@ -110,6 +112,18 @@ void ResultsTree::AddErrorItem(const ErrorItem &item)
 
     bool hide = !mShowTypes[SeverityToShowType(item.severity)];
 
+    //If specified, filter on summary, message, filename, and id
+    if (!hide && !mFilter.isEmpty())
+    {
+        if (!item.summary.contains(mFilter, Qt::CaseInsensitive) &&
+            !item.message.contains(mFilter, Qt::CaseInsensitive) &&
+            !item.file.contains(mFilter, Qt::CaseInsensitive) &&
+            !item.id.contains(mFilter, Qt::CaseInsensitive))
+        {
+            hide = true;
+        }
+    }
+
     //if there is at least one error that is not hidden, we have a visible error
     if (!hide)
     {
@@ -119,6 +133,7 @@ void ResultsTree::AddErrorItem(const ErrorItem &item)
     ErrorLine line;
     line.file = realfile;
     line.id = item.id;
+    line.inconclusive = item.inconclusive;
     line.line = item.lines[0];
     line.summary = item.summary;
     line.message = item.message;
@@ -142,6 +157,7 @@ void ResultsTree::AddErrorItem(const ErrorItem &item)
     data["file"]  = item.files[0];
     data["line"]  = item.lines[0];
     data["id"]  = item.id;
+    data["inconclusive"] = item.inconclusive;
     stditem->setData(QVariant(data));
 
     //Add backtrace files as children
@@ -163,6 +179,7 @@ void ResultsTree::AddErrorItem(const ErrorItem &item)
         child_data["file"]  = item.files[i];
         child_data["line"]  = line.line;
         child_data["id"]  = line.id;
+        child_data["inconclusive"] = line.inconclusive;
         child_item->setData(QVariant(child_data));
     }
 
@@ -189,11 +206,19 @@ QStandardItem *ResultsTree::AddBacktraceFiles(QStandardItem *parent,
     // Ensure shown path is with native separators
     const QString file = QDir::toNativeSeparators(item.file);
     list << CreateNormalItem(file);
-    list << CreateNormalItem(tr(item.severity.toLatin1()));
+    const QString severity = GuiSeverity::toString(item.severity);
+    list << CreateNormalItem(severity.toLatin1());
     list << CreateLineNumberItem(QString("%1").arg(item.line));
     //TODO message has parameter names so we'll need changes to the core
     //cppcheck so we can get proper translations
-    list << CreateNormalItem(tr(item.summary.toLatin1()));
+    QString summary;
+    if (item.inconclusive)
+    {
+        summary = tr("[Inconclusive]");
+        summary += " ";
+    }
+    summary += item.summary.toLatin1();
+    list << CreateNormalItem(summary);
 
     // Check for duplicate rows and don't add them if found
     for (int i = 0; i < parent->rowCount(); i++)
@@ -250,24 +275,107 @@ ShowTypes ResultsTree::VariantToShowType(const QVariant &data)
     return (ShowTypes)value;
 }
 
-ShowTypes ResultsTree::SeverityToShowType(const QString & severity)
+ShowTypes ResultsTree::SeverityToShowType(Severity::SeverityType severity)
 {
-    if (severity == "error")
+    switch (severity)
+    {
+    case Severity::none:
+        return SHOW_NONE;
+    case Severity::error:
         return SHOW_ERRORS;
-    if (severity == "style")
+    case Severity::style:
         return SHOW_STYLE;
-    if (severity == "warning")
+    case Severity::warning:
         return SHOW_WARNINGS;
-    if (severity == "performance")
+    case Severity::performance:
         return SHOW_PERFORMANCE;
-    if (severity == "portability")
+    case Severity::portability:
         return SHOW_PORTABILITY;
-    if (severity == "information")
+    case Severity::information:
         return SHOW_INFORMATION;
+    default:
+        return SHOW_NONE;
+    }
 
     return SHOW_NONE;
 }
 
+Severity::SeverityType ResultsTree::ShowTypeToSeverity(ShowTypes type)
+{
+    switch (type)
+    {
+    case SHOW_STYLE:
+        return Severity::style;
+        break;
+
+    case SHOW_ERRORS:
+        return Severity::error;
+        break;
+
+    case SHOW_WARNINGS:
+        return Severity::warning;
+        break;
+
+    case SHOW_PERFORMANCE:
+        return Severity::performance;
+        break;
+
+    case SHOW_PORTABILITY:
+        return Severity::portability;
+        break;
+
+    case SHOW_INFORMATION:
+        return Severity::information;
+        break;
+
+    case SHOW_NONE:
+        return Severity::none;
+        break;
+    }
+
+    return Severity::none;
+}
+
+QString ResultsTree::SeverityToTranslatedString(Severity::SeverityType severity)
+{
+    switch (severity)
+    {
+    case Severity::style:
+        return tr("style");
+        break;
+
+    case Severity::error:
+        return tr("error");
+        break;
+
+    case Severity::warning:
+        return tr("warning");
+        break;
+
+    case Severity::performance:
+        return tr("performance");
+        break;
+
+    case Severity::portability:
+        return tr("portability");
+        break;
+
+    case Severity::information:
+        return tr("information");
+        break;
+
+    case Severity::debug:
+        return tr("debug");
+        break;
+
+    case Severity::none:
+        return "";
+        break;
+    }
+
+    return "";
+}
+
 QStandardItem *ResultsTree::FindFileItem(const QString &name)
 {
     QList<QStandardItem *> list = mModel.findItems(name);
@@ -315,6 +423,12 @@ void ResultsTree::ShowResults(ShowTypes type, bool show)
     }
 }
 
+void ResultsTree::FilterResults(const QString& filter)
+{
+    mFilter = filter;
+    RefreshTree();
+}
+
 void ResultsTree::ShowHiddenResults()
 {
     //Clear the "hide" flag for each item
@@ -384,6 +498,18 @@ void ResultsTree::RefreshTree()
             //Check if this error should be hidden
             bool hide = (data["hide"].toBool() || !mShowTypes[VariantToShowType(data["severity"])]);
 
+            //If specified, filter on summary, message, filename, and id
+            if (!hide && !mFilter.isEmpty())
+            {
+                if (!data["summary"].toString().contains(mFilter, Qt::CaseInsensitive) &&
+                    !data["message"].toString().contains(mFilter, Qt::CaseInsensitive) &&
+                    !data["file"].toString().contains(mFilter, Qt::CaseInsensitive) &&
+                    !data["id"].toString().contains(mFilter, Qt::CaseInsensitive))
+                {
+                    hide = true;
+                }
+            }
+
             if (!hide)
             {
                 mVisibleErrors = true;
@@ -475,7 +601,8 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             for (int i = 0; i < mApplications->GetApplicationCount(); i++)
             {
                 //Create an action for the application
-                QAction *start = new QAction(mApplications->GetApplicationName(i), &menu);
+                const Application app = mApplications->GetApplication(i);
+                QAction *start = new QAction(app.getName(), &menu);
                 if (multipleSelection)
                     start->setDisabled(true);
 
@@ -563,6 +690,9 @@ void ResultsTree::StartApplication(QStandardItem *target, int application)
         return;
     }
 
+    if (application == -1)
+        application = mApplications->GetDefaultApplication();
+
     if (target && application >= 0 && application < mApplications->GetApplicationCount() && target->parent())
     {
         // Make sure we are working with the first column
@@ -571,8 +701,6 @@ void ResultsTree::StartApplication(QStandardItem *target, int application)
 
         QVariantMap data = target->data().toMap();
 
-        QString program = mApplications->GetApplicationPath(application);
-
         //Replace (file) with filename
         QString file = data["file"].toString();
 
@@ -609,19 +737,36 @@ void ResultsTree::StartApplication(QStandardItem *target, int application)
             file.append("\"");
         }
 
-        program.replace("(file)", file, Qt::CaseInsensitive);
+        const Application app = mApplications->GetApplication(application);
+        QString params = app.getParameters();
+        params.replace("(file)", file, Qt::CaseInsensitive);
 
         QVariant line = data["line"];
-        program.replace("(line)", QString("%1").arg(line.toInt()), Qt::CaseInsensitive);
+        params.replace("(line)", QString("%1").arg(line.toInt()), Qt::CaseInsensitive);
 
-        program.replace("(message)", data["message"].toString(), Qt::CaseInsensitive);
-        program.replace("(severity)", data["severity"].toString(), Qt::CaseInsensitive);
+        params.replace("(message)", data["message"].toString(), Qt::CaseInsensitive);
+        params.replace("(severity)", data["severity"].toString(), Qt::CaseInsensitive);
 
-        bool success = QProcess::startDetached(program);
+        QString program = app.getPath();
+
+        // In Windows we must surround paths including spaces with quotation marks.
+#ifdef Q_WS_WIN
+        if (program.indexOf(" ") > -1)
+        {
+            if (!program.startsWith('"') && !program.endsWith('"'))
+            {
+                program.insert(0, "\"");
+                program.append("\"");
+            }
+        }
+#endif // Q_WS_WIN
+
+        const QString cmdLine = QString("%1 %2").arg(program).arg(params);
+
+        bool success = QProcess::startDetached(cmdLine);
         if (!success)
         {
-            QString app = mApplications->GetApplicationName(application);
-            QString text = tr("Could not start %1\n\nPlease check the application path and parameters are correct.").arg(app);
+            QString text = tr("Could not start %1\n\nPlease check the application path and parameters are correct.").arg(program);
 
             QMessageBox msgbox(this);
             msgbox.setWindowTitle("Cppcheck");
@@ -669,7 +814,13 @@ void ResultsTree::CopyMessage()
 
         QVariantMap data = mContextItem->data().toMap();
 
-        QString message = data["message"].toString();
+        QString message;
+        if (data["inconclusive"].toBool())
+        {
+            message = tr("[Inconclusive]");
+            message += " ";
+        }
+        message += data["message"].toString();
 
         QClipboard *clipboard = QApplication::clipboard();
         clipboard->setText(message);
@@ -703,7 +854,7 @@ void ResultsTree::Context(int application)
 
 void ResultsTree::QuickStartApplication(const QModelIndex &index)
 {
-    StartApplication(mModel.itemFromIndex(index), 0);
+    StartApplication(mModel.itemFromIndex(index));
 }
 
 void ResultsTree::CopyPath(QStandardItem *target, bool fullPath)
@@ -731,21 +882,25 @@ void ResultsTree::CopyPath(QStandardItem *target, bool fullPath)
     }
 }
 
-QString ResultsTree::SeverityToIcon(const QString &severity) const
+QString ResultsTree::SeverityToIcon(Severity::SeverityType severity) const
 {
-    if (severity == "error")
+    switch (severity)
+    {
+    case Severity::error:
         return ":images/dialog-error.png";
-    if (severity == "style")
+    case Severity::style:
         return ":images/applications-development.png";
-    if (severity == "warning")
+    case Severity::warning:
         return ":images/dialog-warning.png";
-    if (severity == "portability")
+    case Severity::portability:
         return ":images/applications-system.png";
-    if (severity == "performance")
+    case Severity::performance:
         return ":images/utilities-system-monitor.png";
-    if (severity == "information")
+    case Severity::information:
         return ":images/dialog-information.png";
-
+    default:
+        return "";
+    }
     return "";
 }
 
@@ -790,10 +945,11 @@ void ResultsTree::SaveErrors(Report *report, QStandardItem *item)
         QVariantMap data = userdata.toMap();
 
         ErrorItem item;
-        item.severity = ShowTypeToString(VariantToShowType(data["severity"]));
+        item.severity = ShowTypeToSeverity(VariantToShowType(data["severity"]));
         item.summary = data["summary"].toString();
         item.message = data["message"].toString();
         item.id = data["id"].toString();
+        item.inconclusive = data["inconclusive"].toBool();
         QString file = StripPath(data["file"].toString(), true);
         unsigned int line = data["line"].toUInt();
 
@@ -819,42 +975,6 @@ void ResultsTree::SaveErrors(Report *report, QStandardItem *item)
     }
 }
 
-QString ResultsTree::ShowTypeToString(ShowTypes type)
-{
-    switch (type)
-    {
-    case SHOW_STYLE:
-        return tr("style");
-        break;
-
-    case SHOW_ERRORS:
-        return tr("error");
-        break;
-
-    case SHOW_WARNINGS:
-        return tr("warning");
-        break;
-
-    case SHOW_PERFORMANCE:
-        return tr("performance");
-        break;
-
-    case SHOW_PORTABILITY:
-        return tr("portability");
-        break;
-
-    case SHOW_INFORMATION:
-        return tr("information");
-        break;
-
-    case SHOW_NONE:
-        return "";
-        break;
-    }
-
-    return "";
-}
-
 void ResultsTree::UpdateSettings(bool showFullPath,
                                  bool saveFullPath,
                                  bool saveAllErrors)
