@@ -40,8 +40,7 @@ class SettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    SettingsDialog(QSettings *programSettings,
-                   ApplicationList *list,
+    SettingsDialog(ApplicationList *list,
                    TranslationHandler *translator,
                    QWidget *parent = 0);
     virtual ~SettingsDialog();
@@ -98,13 +97,13 @@ protected slots:
     * @brief Slot for deleting an application from the list
     *
     */
-    void DeleteApplication();
+    void RemoveApplication();
 
     /**
     * @brief Slot for modifying an application in the list
     *
     */
-    void ModifyApplication();
+    void EditApplication();
 
     /**
     * @brief Slot for making the selected application as the default (first)
@@ -118,19 +117,38 @@ protected slots:
     */
     void AddIncludePath();
 
+    /**
+    * @brief Slot for removing an include path.
+    *
+    */
+    void RemoveIncludePath();
+
+    /**
+    * @brief Slot for editing an include path.
+    *
+    */
+    void EditIncludePath();
+
 protected:
 
+    /**
+    * @brief Add new include path to the list.
+    * @param path Path to add.
+    *
+    */
+    void AddIncludePath(const QString &path);
+
     /**
     * @brief Clear all applications from the list and re insert them from mTempApplications
     *
     */
-    void PopulateListWidget();
+    void PopulateApplicationList();
 
     /**
-        * @brief Load saved values
-        * Loads dialog size and column widths.
-        *
-        */
+    * @brief Load saved values
+    * Loads dialog size and column widths.
+    *
+    */
     void SaveSettings();
 
     /**
@@ -141,13 +159,13 @@ protected:
     void LoadSettings();
 
     /**
-    * @brief Save a single checkboxes value
-    *
-    * @param box checkbox to save
-    * @param name name for QSettings to store the value
-    */
-    void SaveCheckboxValue(QCheckBox *box, const QString &name);
-
+     * @brief Save a single checkboxes value
+     *
+     * @param settings Pointer to Settings.
+     * @param box checkbox to save
+     * @param name name for QSettings to store the value
+     */
+    void SaveCheckboxValue(QSettings *settings, QCheckBox *box, const QString &name);
 
     /**
     * @brief Convert bool to Qt::CheckState
@@ -165,17 +183,16 @@ protected:
     */
     bool CheckStateToBool(Qt::CheckState state) const;
 
+    /**
+    * @brief Populate the include paths-list.
+    */
+    void InitIncludepathsList();
+
     /**
     * @brief Populate the translations list.
     */
     void InitTranslationsList();
 
-    /**
-    * @brief Settings
-    *
-    */
-    QSettings *mSettings;
-
     /**
     * @brief List of applications user has specified
     *
@@ -201,6 +218,7 @@ protected:
     */
     Ui::Settings mUI;
 private:
+    static const int LangCodeRole = Qt::UserRole;
 };
 /// @}
 #endif // SETTINGSDIALOG_H
