@@ -71,7 +71,8 @@ void ThreadResult::reportErr(const ErrorLogger::ErrorMessage &msg)
     item.lines = lines;
     item.summary = QString::fromStdString(msg.shortMessage());
     item.message = QString::fromStdString(msg.verboseMessage());
-    item.severity = QString::fromStdString(Severity::toString(msg._severity));
+    item.severity = msg._severity;
+    item.inconclusive = msg._inconclusive;
 
     if (msg._severity != Severity::debug)
         emit Error(item);
@@ -90,13 +91,6 @@ QString ThreadResult::GetNextFile()
     return mFiles.takeFirst();
 }
 
-
-void ThreadResult::reportStatus(unsigned int index, unsigned int max)
-{
-    Q_UNUSED(index);
-    Q_UNUSED(max);
-}
-
 void ThreadResult::SetFiles(const QStringList &files)
 {
     QMutexLocker locker(&mutex);
