@@ -75,8 +75,13 @@ void TxtReport::WriteError(const ErrorItem &error)
             line += ": ";
         }
     }
-
-    line += QString("(%1) %2").arg(error.severity).arg(error.summary);
+    line += QString("(%1) ").arg(GuiSeverity::toString(error.severity));
+    if (error.inconclusive)
+    {
+        line += tr("inconclusive");
+        line += " ";
+    }
+    line += error.summary;
 
     mTxtWriter << line << endl;
 }
