@@ -42,12 +42,18 @@ public:
         : Check(myName(), tokenizer, settings, errorLogger)
     { }
 
+    /** @brief Run checks against the normal token list */
+    void runChecks(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
+    {
+        CheckAutoVariables checkAutoVariables(tokenizer, settings, errorLogger);
+        checkAutoVariables.returnReference();
+    }
+
     void runSimplifiedChecks(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
     {
         CheckAutoVariables checkAutoVariables(tokenizer, settings, errorLogger);
         checkAutoVariables.autoVariables();
         checkAutoVariables.returnPointerToLocalArray();
-        checkAutoVariables.returnReference();
         checkAutoVariables.returncstr();
     }
 
@@ -64,14 +70,9 @@ public:
     void returncstr();
 
 private:
-    std::set<std::string> fp_list;
-    std::set<unsigned int> vd_list;
-    std::set<unsigned int> vda_list;
     bool errorAv(const Token* left, const Token* right);
     bool isAutoVar(unsigned int varId);
     bool isAutoVarArray(unsigned int varId);
-    void addVD(unsigned int varId);
-    void addVDA(unsigned int varId);
 
     /**
      * Returning a temporary object?
