@@ -707,7 +707,7 @@ void CheckBufferOverrun::checkFunctionParameter(const Token &tok, unsigned int p
                         Token::Match(ftok, "%var% --"))
                         break;
 
-                    if (Token::Match(ftok->previous(), "[=+-*/;{}] %var% [ %num% ]"))
+                    if (Token::Match(ftok->previous(), "=|;|{|}|%op% %var% [ %num% ]"))
                     {
                         const MathLib::bigint index = MathLib::toLongNumber(ftok->strAt(2));
                         if (index >= 0 && arrayInfo.num[0] > 0 && index >= arrayInfo.num[0])
@@ -1043,6 +1043,14 @@ void CheckBufferOverrun::checkScope(const Token *tok, const ArrayInfo &arrayInfo
             --indentlevel;
         }
 
+        // Skip array declarations
+        else if (Token::Match(tok, "[;{}] %type% *| %var% [") &&
+                 tok->strAt(1) != "return")
+        {
+            tok = tok->tokAt(3);
+            continue;
+        }
+
         else if (Token::Match(tok, "%varid% [ %num% ]", arrayInfo.varid))
         {
             std::vector<MathLib::bigint> indexes;
@@ -1122,8 +1130,8 @@ void CheckBufferOverrun::checkScope(const Token *tok, const ArrayInfo &arrayInfo
                         {
                             if (!Token::Match(tok2, "%varid% [ %any% ]  = 0 ;", tok->tokAt(2)->varId()))
                             {
-                                // this is currently inconclusive. See TestBufferOverrun::terminateStrncpy3
-                                if (_settings->inconclusive)
+                                // this is currently 'experimental'. See TestBufferOverrun::terminateStrncpy3
+                                if (_settings->experimental)
                                     terminateStrncpyError(tok);
                             }
 
