@@ -68,12 +68,10 @@ void CheckClass::constructors()
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator i;
+    std::list<Scope>::const_iterator scope;
 
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        const Scope *scope = *i;
-
         // only check classes and structures
         if (!scope->isClassOrStruct())
             continue;
@@ -107,7 +105,7 @@ void CheckClass::constructors()
             clearAllVar(usage);
 
             std::list<std::string> callstack;
-            initializeVarList(*func, callstack, scope, usage);
+            initializeVarList(*func, callstack, &(*scope), usage);
 
             // Check if any variables are uninitialized
             std::list<Variable>::const_iterator var;
@@ -310,7 +308,7 @@ void CheckClass::initializeVarList(const Function &func, std::list<std::string>
             ftok = ftok->next();
 
         // Using the operator= function to initialize all variables..
-        if (Token::simpleMatch(ftok->next(), "* this ="))
+        if (Token::Match(ftok->next(), "return| * this ="))
         {
             assignAllVar(usage);
             break;
@@ -553,7 +551,7 @@ void CheckClass::noConstructorError(const Token *tok, const std::string &classna
 
 void CheckClass::uninitVarError(const Token *tok, const std::string &classname, const std::string &varname)
 {
-    reportError(tok, Severity::warning, "uninitVar", "Member variable '" + classname + "::" + varname + "' is not initialised in the constructor.");
+    reportError(tok, Severity::warning, "uninitVar", "Member variable '" + classname + "::" + varname + "' is not initialized in the constructor.");
 }
 
 void CheckClass::operatorEqVarError(const Token *tok, const std::string &classname, const std::string &varname)
@@ -581,12 +579,10 @@ void CheckClass::privateFunctions()
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator i;
+    std::list<Scope>::const_iterator scope;
 
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        const Scope *scope = *i;
-
         // only check classes and structures
         if (!scope->isClassOrStruct())
             continue;
@@ -610,7 +606,9 @@ void CheckClass::privateFunctions()
             if (!func->hasBody)
             {
                 // empty private copy constructors and assignment operators are OK
-                if ((func->type == Function::eCopyConstructor || func->type == Function::eOperatorEqual) && func->access == Private)
+                if ((func->type == Function::eCopyConstructor ||
+                     func->type == Function::eOperatorEqual) &&
+                    func->access == Private)
                     continue;
 
                 whole = false;
@@ -630,88 +628,28 @@ void CheckClass::privateFunctions()
             for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
             {
                 // Get private functions..
-                if (func->type == Function::eFunction &&
-                    func->access == Private && func->hasBody)
+                if (func->type == Function::eFunction && func->access == Private)
                     FuncList.push_back(func->tokenDef);
             }
         }
 
         // Check that all private functions are used..
-        bool HasFuncImpl = false;
-        bool inclass = false;
-        int indent_level = 0;
-        for (const Token *ftok = _tokenizer->tokens(); ftok; ftok = ftok->next())
+        for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
         {
-            if (ftok->str() == "{")
-                ++indent_level;
-            else if (ftok->str() == "}")
+            const Token *ftok = func->start;
+            if (ftok)
             {
-                if (indent_level > 0)
-                    --indent_level;
-                if (indent_level == 0)
-                    inclass = false;
-            }
+                const Token *etok = ftok->link();
 
-            else if (ftok->str() == "class" &&
-                     ftok->next()->str() == classname &&
-                     Token::Match(ftok->tokAt(2), ":|{"))
-            {
-                indent_level = 0;
-                inclass = true;
-            }
-
-            // Check member class functions to see what functions are used..
-            else if ((inclass && indent_level == 1 && Token::Match(ftok, "%var% (")) ||
-                     (ftok->str() == classname && Token::Match(ftok->next(), ":: ~| %var% (")))
-            {
-                while (ftok && ftok->str() != ")")
-                    ftok = ftok->next();
-                if (!ftok)
-                    break;
-                if (Token::Match(ftok, ") : %var% ("))
+                for (; ftok != etok; ftok = ftok->next())
                 {
-                    while (!Token::Match(ftok->next(), "[{};]"))
-                    {
-                        if (Token::Match(ftok, "::|,|( %var% ,|)"))
-                        {
-                            // Remove function from FuncList
-                            std::list<const Token *>::iterator it = FuncList.begin();
-                            while (it != FuncList.end())
-                            {
-                                if (ftok->next()->str() == (*it)->str())
-                                    FuncList.erase(it++);
-                                else
-                                    ++it;
-                            }
-                        }
-                        ftok = ftok->next();
-                    }
-                }
-                if (!Token::Match(ftok, ") const| {"))
-                    continue;
-
-                if (ftok->fileIndex() == 0)
-                    HasFuncImpl = true;
-
-                // Parse function..
-                int indentlevel2 = 0;
-                for (const Token *tok2 = ftok; tok2; tok2 = tok2->next())
-                {
-                    if (tok2->str() == "{")
-                        ++indentlevel2;
-                    else if (tok2->str() == "}")
-                    {
-                        --indentlevel2;
-                        if (indentlevel2 < 1)
-                            break;
-                    }
-                    else if (Token::Match(tok2, "%var% ("))
+                    if (Token::Match(ftok, "%var% ("))
                     {
                         // Remove function from FuncList
                         std::list<const Token *>::iterator it = FuncList.begin();
                         while (it != FuncList.end())
                         {
-                            if (tok2->str() == (*it)->str())
+                            if (ftok->str() == (*it)->str())
                                 FuncList.erase(it++);
                             else
                                 ++it;
@@ -721,7 +659,7 @@ void CheckClass::privateFunctions()
             }
         }
 
-        while (HasFuncImpl && !FuncList.empty())
+        while (!FuncList.empty())
         {
             // Final check; check if the function pointer is used somewhere..
             const std::string _pattern("return|(|)|,|= " + FuncList.front()->str());
@@ -753,93 +691,104 @@ void CheckClass::unusedPrivateFunctionError(const Token *tok, const std::string
 
 void CheckClass::noMemset()
 {
-    // Locate all 'memset' tokens..
-    for (const Token *tok = _tokenizer->tokens(); tok; tok = tok->next())
+    createSymbolDatabase();
+
+    std::list<Scope>::const_iterator scope;
+
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        if (!Token::Match(tok, "memset|memcpy|memmove"))
-            continue;
+        std::list<Function>::const_iterator func;
 
-        std::string type;
-        if (Token::Match(tok, "memset ( %var% , %num% , sizeof ( %type% ) )"))
-            type = tok->strAt(8);
-        else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( %type% ) )"))
-            type = tok->strAt(9);
-        else if (Token::Match(tok, "memset ( %var% , %num% , sizeof ( struct %type% ) )"))
-            type = tok->strAt(9);
-        else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( struct %type% ) )"))
-            type = tok->strAt(10);
-        else if (Token::Match(tok, "%type% ( %var% , %var% , sizeof ( %type% ) )"))
-            type = tok->strAt(8);
-
-        // No type defined => The tokens didn't match
-        if (type.empty())
-            continue;
-
-        // Warn if type is a class or struct that contains any std::* variables
-        const std::string pattern2(std::string("struct|class ") + type + " {");
-        for (const Token *tstruct = Token::findmatch(_tokenizer->tokens(), pattern2.c_str()); tstruct; tstruct = tstruct->next())
+        for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
         {
-            if (tstruct->str() == "}")
-                break;
+            // only check functions with bodies
+            if (!func->hasBody)
+                continue;
 
-            // struct with function? skip function body..
-            if (Token::simpleMatch(tstruct, ") {"))
+            // Locate all 'memset' tokens..
+            const Token *end = func->start->link();
+            for (const Token *tok = func->start; tok && tok != end; tok = tok->next())
             {
-                tstruct = tstruct->next()->link();
-                if (!tstruct)
-                    break;
-            }
+                if (!Token::Match(tok, "memset|memcpy|memmove"))
+                    continue;
 
-            // before a statement there must be either:
-            // * private:|protected:|public:
-            // * { } ;
-            if (Token::Match(tstruct, "[;{}]") ||
-                tstruct->str().find(":") != std::string::npos)
-            {
-                if (Token::Match(tstruct->next(), "std :: %type% %var% ;"))
-                    memsetStructError(tok, tok->str(), tstruct->strAt(3));
-
-                else if (Token::Match(tstruct->next(), "std :: %type% <"))
+                const Token *typeTok = 0;
+                if (Token::Match(tok, "memset ( %var% , %num% , sizeof ( %type% ) )"))
+                    typeTok = tok->tokAt(8);
+                else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( %type% ) )"))
+                    typeTok = tok->tokAt(9);
+                else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( %type% :: %type% ) )"))
+                    typeTok = tok->tokAt(11);
+                else if (Token::Match(tok, "memset ( %var% , %num% , sizeof ( struct %type% ) )"))
+                    typeTok = tok->tokAt(9);
+                else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( struct %type% ) )"))
+                    typeTok = tok->tokAt(10);
+                else if (Token::Match(tok, "%type% ( %var% , %var% , sizeof ( %type% ) )"))
+                    typeTok = tok->tokAt(8);
+                else if (Token::Match(tok, "memset ( & %var% , %num% , sizeof ( %var% ) )"))
                 {
-                    // backup the type
-                    const std::string typestr(tstruct->strAt(3));
-
-                    // check if it's a pointer variable..
-                    unsigned int level = 0;
-                    while (0 != (tstruct = tstruct->next()))
-                    {
-                        if (tstruct->str() == "<")
-                            ++level;
-                        else if (tstruct->str() == ">")
-                        {
-                            if (level <= 1)
-                                break;
-                            --level;
-                        }
-                        else if (tstruct->str() == "(")
-                            tstruct = tstruct->link();
-                    }
-
-                    if (!tstruct)
-                        break;
-
-                    // found error => report
-                    if (Token::Match(tstruct, "> %var% ;"))
-                        memsetStructError(tok, tok->str(), typestr);
+                    unsigned int varid = tok->tokAt(3)->varId();
+                    const Variable *var = symbolDatabase->getVariableFromVarId(varid);
+                    if (var && (var->typeStartToken() == var->typeEndToken() ||
+                                Token::Match(var->typeStartToken(), "%type% :: %type%")))
+                        typeTok = var->typeEndToken();
                 }
+
+                // No type defined => The tokens didn't match
+                if (!typeTok)
+                    continue;
+
+                const Scope *type = symbolDatabase->findVariableType(&(*scope), typeTok);
+
+                if (type)
+                    checkMemsetType(&(*scope), tok, type);
             }
         }
     }
 }
 
-void CheckClass::memsetClassError(const Token *tok, const std::string &memfunc)
+void CheckClass::checkMemsetType(const Scope *start, const Token *tok, const Scope *type)
 {
-    reportError(tok, Severity::error, "memsetClass", "Using '" + memfunc + "' on class");
+    // recursively check all parent classes
+    for (size_t i = 0; i < type->derivedFrom.size(); i++)
+    {
+        if (type->derivedFrom[i].scope)
+            checkMemsetType(start, tok, type->derivedFrom[i].scope);
+    }
+
+    // Warn if type is a class that contains any virtual functions
+    std::list<Function>::const_iterator func;
+
+    for (func = type->functionList.begin(); func != type->functionList.end(); ++func)
+    {
+        if (func->isVirtual)
+            memsetError(tok, tok->str(), "virtual method", type->classDef->str());
+    }
+
+    // Warn if type is a class or struct that contains any std::* variables
+    std::list<Variable>::const_iterator var;
+
+    for (var = type->varlist.begin(); var != type->varlist.end(); ++var)
+    {
+        // don't warn if variable static or const
+        if (!var->isStatic() && !var->isConst())
+        {
+            const Token *tok1 = var->typeStartToken();
+
+            // check for std:: type that is not a pointer or reference
+            if (Token::simpleMatch(tok1, "std ::") && !Token::Match(var->nameToken()->previous(), "*|&"))
+                memsetError(tok, tok->str(), "'std::" + tok1->strAt(2) + "'", type->classDef->str());
+
+            // check for known type that is not a pointer or reference
+            else if (var->type() && !Token::Match(var->nameToken()->previous(), "*|&"))
+                checkMemsetType(start, tok, var->type());
+        }
+    }
 }
 
-void CheckClass::memsetStructError(const Token *tok, const std::string &memfunc, const std::string &classname)
+void CheckClass::memsetError(const Token *tok, const std::string &memfunc, const std::string &classname, const std::string &type)
 {
-    reportError(tok, Severity::error, "memsetStruct", "Using '" + memfunc + "' on struct that contains a 'std::" + classname + "'");
+    reportError(tok, Severity::error, "memsetClass", "Using '" + memfunc + "' on " + type + " that contains a " + classname);
 }
 
 //---------------------------------------------------------------------------
@@ -853,26 +802,31 @@ void CheckClass::operatorEq()
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator i;
+    std::list<Scope>::const_iterator scope;
 
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        std::list<Function>::const_iterator it;
+        if (!scope->isClassOrStruct())
+            continue;
 
-        for (it = (*i)->functionList.begin(); it != (*i)->functionList.end(); ++it)
+        std::list<Function>::const_iterator func;
+
+        for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
         {
-            if (it->type == Function::eOperatorEqual && it->access != Private)
+            if (func->type == Function::eOperatorEqual && func->access != Private)
             {
-                if (it->token->strAt(-1) == "void")
-                    operatorEqReturnError(it->token->tokAt(-1));
+                // use definition for check so we don't have to deal with qualification
+                if (!(Token::Match(func->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
+                      func->tokenDef->strAt(-2) == scope->className))
+                    operatorEqReturnError(func->tokenDef->tokAt(-1), scope->className);
             }
         }
     }
 }
 
-void CheckClass::operatorEqReturnError(const Token *tok)
+void CheckClass::operatorEqReturnError(const Token *tok, const std::string &className)
 {
-    reportError(tok, Severity::style, "operatorEq", "'operator=' should return something");
+    reportError(tok, Severity::style, "operatorEq", "\'" + className + "::operator=' should return \'" + className + " &\'");
 }
 
 //---------------------------------------------------------------------------
@@ -880,6 +834,41 @@ void CheckClass::operatorEqReturnError(const Token *tok)
 // operator= should return a reference to *this
 //---------------------------------------------------------------------------
 
+void CheckClass::operatorEqRetRefThis()
+{
+    if (!_settings->_checkCodingStyle)
+        return;
+
+    createSymbolDatabase();
+
+    std::list<Scope>::const_iterator scope;
+
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
+    {
+        // only check classes and structures
+        if (scope->isClassOrStruct())
+        {
+            std::list<Function>::const_iterator func;
+
+            for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
+            {
+                if (func->type == Function::eOperatorEqual && func->hasBody)
+                {
+                    // make sure return signature is correct
+                    if (Token::Match(func->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
+                        func->tokenDef->strAt(-2) == scope->className)
+                    {
+                        // find the ')'
+                        const Token *tok = func->token->next()->link();
+
+                        checkReturnPtrThis(&(*scope), &(*func), tok->tokAt(2), tok->next()->link());
+                    }
+                }
+            }
+        }
+    }
+}
+
 void CheckClass::checkReturnPtrThis(const Scope *scope, const Function *func, const Token *tok, const Token *last)
 {
     bool foundReturn = false;
@@ -928,10 +917,13 @@ void CheckClass::checkReturnPtrThis(const Scope *scope, const Function *func, co
                 }
             }
 
-            // check of *this is returned
+            // check if *this is returned
             else if (!(Token::Match(tok->tokAt(1), "(| * this ;|=") ||
                        Token::Match(tok->tokAt(1), "(| * this +=") ||
-                       Token::simpleMatch(tok->tokAt(1), "operator= (")))
+                       Token::simpleMatch(tok->tokAt(1), "operator= (") ||
+                       Token::simpleMatch(tok->tokAt(1), "this . operator= (") ||
+                       (Token::Match(tok->tokAt(1), "%type% :: operator= (") &&
+                        tok->next()->str() == scope->className)))
                 operatorEqRetRefThisError(func->token);
         }
     }
@@ -939,43 +931,6 @@ void CheckClass::checkReturnPtrThis(const Scope *scope, const Function *func, co
         operatorEqRetRefThisError(func->token);
 }
 
-void CheckClass::operatorEqRetRefThis()
-{
-    if (!_settings->_checkCodingStyle)
-        return;
-
-    createSymbolDatabase();
-
-    std::list<Scope *>::const_iterator i;
-
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
-    {
-        const Scope *scope = *i;
-
-        // only check classes and structures
-        if (scope->isClassOrStruct())
-        {
-            std::list<Function>::const_iterator func;
-
-            for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
-            {
-                if (func->type == Function::eOperatorEqual && func->hasBody)
-                {
-                    // make sure return signature is correct
-                    if (Token::Match(func->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
-                        func->tokenDef->strAt(-2) == scope->className)
-                    {
-                        // find the ')'
-                        const Token *tok = func->token->next()->link();
-
-                        checkReturnPtrThis(scope, &(*func), tok->tokAt(2), tok->next()->link());
-                    }
-                }
-            }
-        }
-    }
-}
-
 void CheckClass::operatorEqRetRefThisError(const Token *tok)
 {
     reportError(tok, Severity::style, "operatorEqRetRefThis", "'operator=' should return reference to self");
@@ -1002,51 +957,34 @@ void CheckClass::operatorEqToSelf()
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator i;
+    std::list<Scope>::const_iterator scope;
 
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        const Scope *scope = *i;
-        std::list<Function>::const_iterator it;
+        if (!scope->isClassOrStruct())
+            continue;
+
+        std::list<Function>::const_iterator func;
 
         // skip classes with multiple inheritance
         if (scope->derivedFrom.size() > 1)
             continue;
 
-        for (it = scope->functionList.begin(); it != scope->functionList.end(); ++it)
+        for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
         {
-            if (it->type == Function::eOperatorEqual && it->hasBody)
+            if (func->type == Function::eOperatorEqual && func->hasBody)
             {
                 // make sure return signature is correct
-                if (Token::Match(it->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
-                    it->tokenDef->strAt(-2) == scope->className)
+                if (Token::Match(func->tokenDef->tokAt(-3), ";|}|{|public:|protected:|private: %type% &") &&
+                    func->tokenDef->strAt(-2) == scope->className)
                 {
-                    // check for proper function parameter signature
-                    if ((Token::Match(it->tokenDef->next(), "( const %var% & )") ||
-                         Token::Match(it->tokenDef->next(), "( const %var% & %var% )")) &&
-                        it->tokenDef->strAt(3) == scope->className)
+                    // find the parameter name
+                    const Token *rhs = func->argumentList.begin()->nameToken();
+
+                    if (!hasAssignSelf(&(*func), rhs))
                     {
-                        // find the parameter name
-                        const Token *rhs = it->token;
-                        while (rhs->str() != "&")
-                            rhs = rhs->next();
-                        rhs = rhs->next();
-
-                        // find the ')'
-                        const Token *tok = it->token->next()->link();
-                        const Token *tok1 = tok;
-
-                        if (tok1 && tok1->tokAt(1) && tok1->tokAt(1)->str() == "{" && tok1->tokAt(1)->link())
-                        {
-                            const Token *first = tok1->tokAt(1);
-                            const Token *last = first->link();
-
-                            if (!hasAssignSelf(first, last, rhs))
-                            {
-                                if (hasDeallocation(first, last))
-                                    operatorEqToSelfError(tok);
-                            }
-                        }
+                        if (hasDeallocation(&(*func)))
+                            operatorEqToSelfError(func->token);
                     }
                 }
             }
@@ -1054,7 +992,7 @@ void CheckClass::operatorEqToSelf()
     }
 }
 
-bool CheckClass::hasDeallocation(const Token *first, const Token *last)
+bool CheckClass::hasDeallocation(const Function *func)
 {
     // This function is called when no simple check was found for assignment
     // to self.  We are currently looking for a specific sequence of:
@@ -1063,7 +1001,8 @@ bool CheckClass::hasDeallocation(const Token *first, const Token *last)
     // Unfortunately, this is necessary to prevent false positives.
     // This check needs to do careful analysis someday to get this
     // correct with a high degree of certainty.
-    for (const Token *tok = first; tok && (tok != last); tok = tok->next())
+    const Token *last = func->start->link();
+    for (const Token *tok = func->start; tok && (tok != last); tok = tok->next())
     {
         // check for deallocating memory
         if (Token::Match(tok, "{|;|, free ( %var%"))
@@ -1128,9 +1067,10 @@ bool CheckClass::hasDeallocation(const Token *first, const Token *last)
     return false;
 }
 
-bool CheckClass::hasAssignSelf(const Token *first, const Token *last, const Token *rhs)
+bool CheckClass::hasAssignSelf(const Function *func, const Token *rhs)
 {
-    for (const Token *tok = first; tok && tok != last; tok = tok->next())
+    const Token *last = func->start->link();
+    for (const Token *tok = func->start; tok && tok != last; tok = tok->next())
     {
         if (Token::simpleMatch(tok, "if ("))
         {
@@ -1174,17 +1114,13 @@ void CheckClass::virtualDestructor()
     // * base class doesn't have virtual destructor
     // * derived class has non-empty destructor
     // * base class is deleted
-    if (!_settings->inconclusive)
-        return;
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator i;
+    std::list<Scope>::const_iterator scope;
 
-    for (i = symbolDatabase->scopeList.begin(); i != symbolDatabase->scopeList.end(); ++i)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        const Scope *scope = *i;
-
         // Skip base classes and namespaces
         if (scope->derivedFrom.empty())
             continue;
@@ -1214,6 +1150,57 @@ void CheckClass::virtualDestructor()
                 // Name of base class..
                 const std::string baseName = derivedFrom->className;
 
+                // Check for this pattern:
+                // 1. Base class pointer is given the address of derived class instance
+                // 2. Base class pointer is deleted
+                //
+                // If this pattern is not seen then bailout the checking of these base/derived classes
+                {
+                    // pointer variables of type 'Base *'
+                    std::set<unsigned int> basepointer;
+
+                    // pointer variables of type 'Base *' that should not be deleted
+                    std::set<unsigned int> dontDelete;
+
+                    // No deletion of derived class instance through base class pointer found => the code is ok
+                    bool ok = true;
+
+                    for (const Token *tok = _tokenizer->tokens(); tok; tok = tok->next())
+                    {
+                        // Declaring base class pointer
+                        if (Token::simpleMatch(tok, baseName.c_str()))
+                        {
+                            if (Token::Match(tok->previous(), ("[;{}] " + baseName + " * %var% ;").c_str()))
+                                basepointer.insert(tok->tokAt(2)->varId());
+                        }
+
+                        // Assign base class pointer with pointer to derived class instance
+                        if (Token::Match(tok, "[;{}] %var% =") &&
+                            tok->next()->varId() > 0 &&
+                            basepointer.find(tok->next()->varId()) != basepointer.end())
+                        {
+                            // new derived class..
+                            if (Token::simpleMatch(tok->tokAt(3), ("new " + derivedClass->str()).c_str()))
+                            {
+                                dontDelete.insert(tok->next()->varId());
+                            }
+                        }
+
+                        // Delete base class pointer that might point at derived class
+                        if (Token::Match(tok, "delete %var% ;") &&
+                            tok->next()->varId() &&
+                            dontDelete.find(tok->next()->varId()) != dontDelete.end())
+                        {
+                            ok = false;
+                            break;
+                        }
+                    }
+
+                    // No base class pointer that points at a derived class is deleted
+                    if (ok)
+                        continue;
+                }
+
                 // Find the destructor declaration for the base class.
                 const Function *base_destructor = derivedFrom->getDestructor();
                 const Token *base = 0;
@@ -1298,12 +1285,10 @@ void CheckClass::checkConst()
 
     createSymbolDatabase();
 
-    std::list<Scope *>::const_iterator it;
+    std::list<Scope>::const_iterator scope;
 
-    for (it = symbolDatabase->scopeList.begin(); it != symbolDatabase->scopeList.end(); ++it)
+    for (scope = symbolDatabase->scopeList.begin(); scope != symbolDatabase->scopeList.end(); ++scope)
     {
-        const Scope *scope = *it;
-
         // only check classes and structures
         if (!scope->isClassOrStruct())
             continue;
@@ -1373,12 +1358,12 @@ void CheckClass::checkConst()
                 // check if base class function is virtual
                 if (!scope->derivedFrom.empty())
                 {
-                    if (isVirtualFunc(scope, func->tokenDef))
+                    if (isVirtualFunc(&(*scope), func->tokenDef))
                         continue;
                 }
 
                 // if nothing non-const was found. write error..
-                if (checkConstFunc(scope, paramEnd))
+                if (checkConstFunc(&(*scope), paramEnd))
                 {
                     std::string classname = scope->className;
                     const Scope *nest = scope->nestedIn;
@@ -1408,31 +1393,43 @@ void CheckClass::checkConst()
 
 bool CheckClass::isMemberVar(const Scope *scope, const Token *tok)
 {
-    const Token *tok1 = tok;
+    bool again = false;
 
-    while (tok->previous() && !Token::Match(tok->previous(), "}|{|;|public:|protected:|private:|return|:|?"))
+    // try to find the member variable
+    do
     {
-        if (Token::simpleMatch(tok->previous(),  "* this"))
+        again = false;
+
+        if (tok->str() == "this")
+        {
             return true;
-
-        tok = tok->previous();
+        }
+        else if (Token::Match(tok->tokAt(-2), "%var% . %var%"))
+        {
+            tok = tok->tokAt(-2);
+            again = true;
+        }
+        else if (Token::Match(tok->tokAt(-2), "] . %var%"))
+        {
+            tok = tok->tokAt(-2)->link()->previous();
+            again = true;
+        }
+        else if (tok->str() == "]")
+        {
+            tok = tok->link()->previous();
+            again = true;
+        }
     }
-
-    if (tok->str() == "this")
-        return true;
-
-    if (Token::Match(tok, "( * %var% ) [") || (Token::Match(tok, "( * %var% ) <<") && tok1->next()->str() == "<<"))
-        tok = tok->tokAt(2);
-
-    // ignore class namespace
-    if (tok->str() == scope->className && tok->next()->str() == "::")
-        tok = tok->tokAt(2);
+    while (again);
 
     std::list<Variable>::const_iterator var;
     for (var = scope->varlist.begin(); var != scope->varlist.end(); ++var)
     {
         if (var->name() == tok->str())
         {
+            if (tok->varId() == 0)
+                symbolDatabase->debugMessage(tok, "CheckClass::isMemberVar found used member variable \'" + tok->str() + "\' with varid 0");
+
             return !var->isMutable();
         }
     }
@@ -1458,13 +1455,45 @@ bool CheckClass::isMemberVar(const Scope *scope, const Token *tok)
     return false;
 }
 
+static int countParameters(const Token *tok)
+{
+    if (Token::Match(tok->tokAt(2), "void| )"))
+        return 0;
+
+    int numpar = 1;
+    int parlevel = 0;
+    for (; tok; tok = tok->next())
+    {
+        if (tok->str() == "(")
+            ++parlevel;
+
+        else if (tok->str() == ")")
+        {
+            if (parlevel <= 1)
+                break;
+            --parlevel;
+        }
+
+        else if (parlevel == 1 && tok->str() == ",")
+        {
+            ++numpar;
+        }
+    }
+
+    return numpar;
+}
+
 bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok)
 {
+    unsigned int args = countParameters(tok);
+
     std::list<Function>::const_iterator    func;
 
     for (func = scope->functionList.begin(); func != scope->functionList.end(); ++func)
     {
-        if (func->tokenDef->str() == tok->str() && func->isConst)
+        /** @todo we need to look at the argument types when there are overloaded functions
+          * with the same number of arguments */
+        if (func->tokenDef->str() == tok->str() && func->argCount() == args && func->isConst)
             return true;
     }
 
@@ -1507,11 +1536,9 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
         }
 
         // assignment.. = += |= ..
-        else if (tok1->str() == "=" ||
-                 (tok1->str().find("=") == 1 &&
-                  tok1->str().find_first_of("<!>") == std::string::npos))
+        else if (tok1->isAssignmentOp())
         {
-            if (tok1->previous()->varId() == 0 && !scope->derivedFrom.empty())
+            if (tok1->next()->str() == "this")
             {
                 isconst = false;
                 break;
@@ -1521,25 +1548,6 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
                 isconst = false;
                 break;
             }
-            else if (tok1->previous()->str() == "]")
-            {
-                // TODO: I assume that the assigned variable is a member variable
-                //       don't assume it
-                isconst = false;
-                break;
-            }
-            else if (tok1->next()->str() == "this")
-            {
-                isconst = false;
-                break;
-            }
-
-            // FIXME: I assume that a member union/struct variable is assigned.
-            else if (Token::Match(tok1->tokAt(-2), ". %var%"))
-            {
-                isconst = false;
-                break;
-            }
         }
 
         // streaming: <<
@@ -1548,12 +1556,59 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
             isconst = false;
             break;
         }
+        else if (Token::simpleMatch(tok1->previous(), ") <<") &&
+                 isMemberVar(scope, tok1->tokAt(-2)))
+        {
+            isconst = false;
+            break;
+        }
 
         // increment/decrement (member variable?)..
         else if (Token::Match(tok1, "++|--"))
         {
-            isconst = false;
-            break;
+            // var++ and var--
+            if (Token::Match(tok1->previous(), "%var%") &&
+                tok1->previous()->str() != "return")
+            {
+                if (isMemberVar(scope, tok1->previous()))
+                {
+                    isconst = false;
+                    break;
+                }
+            }
+
+            // var[...]++ and var[...]--
+            else if (tok1->previous()->str() == "]")
+            {
+                if (isMemberVar(scope, tok1->previous()->link()->previous()))
+                {
+                    isconst = false;
+                    break;
+                }
+            }
+
+            // ++var and --var
+            else if (Token::Match(tok1->next(), "%var%"))
+            {
+                if (isMemberVar(scope, tok1->next()))
+                {
+                    isconst = false;
+                    break;
+                }
+            }
+        }
+
+        // std::map variable member
+        else if (Token::Match(tok1, "%var% [") && isMemberVar(scope, tok1))
+        {
+            const Variable *var = symbolDatabase->getVariableFromVarId(tok1->varId());
+
+            if (var && (var->typeStartToken()->str() == "map" ||
+                        Token::simpleMatch(var->typeStartToken(), "std :: map")))
+            {
+                isconst = false;
+                break;
+            }
         }
 
         // function call..
@@ -1583,8 +1638,6 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Token *tok)
     return isconst;
 }
 
-//---------------------------------------------------------------------------
-
 // check if this function is defined virtual in the base classes
 bool CheckClass::isVirtualFunc(const Scope *scope, const Token *functionToken) const
 {
