@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2010 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2011 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,53 +43,37 @@ class CheckExceptionSafety : public Check
 {
 public:
     /** This constructor is used when registering the CheckClass */
-    CheckExceptionSafety() : Check()
+    CheckExceptionSafety() : Check(myName())
     { }
 
     /** This constructor is used when running checks. */
     CheckExceptionSafety(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
-        : Check(tokenizer, settings, errorLogger)
+        : Check(myName(), tokenizer, settings, errorLogger)
     { }
 
+    /** Checks that uses the simplified token list */
     void runSimplifiedChecks(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
     {
         CheckExceptionSafety checkExceptionSafety(tokenizer, settings, errorLogger);
         checkExceptionSafety.destructors();
-        checkExceptionSafety.unsafeNew();
-        checkExceptionSafety.realloc();
         checkExceptionSafety.deallocThrow();
+        checkExceptionSafety.checkRethrowCopy();
     }
 
-
     /** Don't throw exceptions in destructors */
     void destructors();
 
-    /** unsafe use of "new" */
-    void unsafeNew();
-
-    /** Unsafe realloc */
-    void realloc();
-
-    /** deallocating memory and then throw */
+    /** deallocating memory and then throw (dead pointer) */
     void deallocThrow();
 
+    /** Don't rethrow a copy of the caught exception; use a bare throw instead */
+    void checkRethrowCopy();
+
 private:
     /** Don't throw exceptions in destructors */
     void destructorsError(const Token * const tok)
     {
-        reportError(tok, Severity::style, "exceptThrowInDestructor", "Throwing exception in destructor");
-    }
-
-    /** Unsafe use of new */
-    void unsafeNewError(const Token * const tok, const std::string &varname)
-    {
-        reportError(tok, Severity::style, "exceptNew", "Upon exception there is memory leak: " + varname);
-    }
-
-    /** Unsafe reallocation */
-    void reallocError(const Token * const tok, const std::string &varname)
-    {
-        reportError(tok, Severity::style, "exceptRealloc", "Upon exception " + varname + " becomes a dead pointer");
+        reportError(tok, Severity::error, "exceptThrowInDestructor", "Throwing exception in destructor");
     }
 
     void deallocThrowError(const Token * const tok, const std::string &varname)
@@ -97,17 +81,25 @@ private:
         reportError(tok, Severity::error, "exceptDeallocThrow", "Throwing exception in invalid state, " + varname + " points at deallocated memory");
     }
 
-    /** Generate all possible errors (for --errorlist) */
-    void getErrorMessages()
+    void rethrowCopyError(const Token * const tok, const std::string &varname)
     {
-        destructorsError(0);
-        unsafeNewError(0, "p");
-        reallocError(0, "p");
-        deallocThrowError(0, "p");
+        reportError(tok, Severity::style, "exceptRethrowCopy",
+                    "Throwing a copy of the caught exception instead of rethrowing the original exception\n"
+                    "Rethrowing an exception with 'throw " + varname + ";' makes an unnecessary copy of '" + varname + "'.\n"
+                    "To rethrow the caught exception without unnecessary copying or slicing, use a bare 'throw;'.");
+    }
+
+    /** Generate all possible errors (for --errorlist) */
+    void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings)
+    {
+        CheckExceptionSafety c(0, settings, errorLogger);
+        c.destructorsError(0);
+        c.deallocThrowError(0, "p");
+        c.rethrowCopyError(0, "varname");
     }
 
     /** Short description of class (for --doc) */
-    std::string name() const
+    std::string myName() const
     {
         return "Exception Safety";
     }
@@ -117,9 +109,8 @@ private:
     {
         return "Checking exception safety\n"
                "* Throwing exceptions in destructors\n"
-               "* Unsafe use of 'new'\n"
-               "* Unsafe reallocation\n"
-               "* Throwing exception during invalid state";
+               "* Throwing exception during invalid state\n"
+               "* Throwing a copy of a caught exception instead of rethrowing the original exception";
     }
 };
 /// @}
