@@ -21,6 +21,7 @@
 #include "checknullpointer.h"
 #include "executionpath.h"
 #include "mathlib.h"
+#include "symboldatabase.h"
 //---------------------------------------------------------------------------
 
 // Register this check class (by creating a static instance of it)
@@ -132,10 +133,10 @@ bool CheckNullPointer::isPointerDeRef(const Token *tok, bool &unknown)
     unknown = false;
 
     // Dereferencing pointer..
-    if (Token::Match(tok->tokAt(-3), "!!sizeof [;{}=+-/(,] * %var%"))
+    if (Token::Match(tok->tokAt(-3), "!!sizeof [;{}=+-/(,] * %var%") && Token::Match(tok->tokAt(-3), "!!decltype [;{}=+-/(,] * %var%"))
         return true;
 
-    if (!Token::simpleMatch(tok->tokAt(-2), "& (") && tok->strAt(-1) != "&"  && tok->strAt(-1) != "&&" && Token::Match(tok->next(), ". %var%"))
+    if (!Token::simpleMatch(tok->tokAt(-2), "& (") && !Token::Match(tok->tokAt(-2), "sizeof|decltype (") && tok->strAt(-1) != "&"  && tok->strAt(-1) != "&&" && Token::Match(tok->next(), ". %var%"))
         return true;
 
     if (Token::Match(tok->previous(), "[;{}=+-/(,] %var% ["))
@@ -166,8 +167,12 @@ bool CheckNullPointer::isPointerDeRef(const Token *tok, bool &unknown)
 bool CheckNullPointer::isPointer(const unsigned int varid)
 {
     // Check if given variable is a pointer
-    const Token *tok = Token::findmatch(_tokenizer->tokens(), "%varid%", varid);
-    tok = tok->tokAt(-2);
+    const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
+    const Variable *variableInfo = symbolDatabase->getVariableFromVarId(varid);
+    const Token *tok = variableInfo ? variableInfo->typeStartToken() : NULL;
+
+    if (Token::Match(tok, "%type% %type% * %varid% [;)=]", varid))
+        return true;
 
     // maybe not a pointer
     if (!Token::Match(tok, "%type% * %varid% [;)=]", varid))
@@ -202,6 +207,10 @@ void CheckNullPointer::nullPointerAfterLoop()
         if (varid == 0)
             continue;
 
+        // Is variable a pointer?
+        if (!isPointer(varid))
+            continue;
+
         // Get variable name for the loop variable
         const std::string varname(tok->strAt(2));
 
@@ -224,9 +233,7 @@ void CheckNullPointer::nullPointerAfterLoop()
                 // Is the loop variable dereferenced?
                 if (CheckNullPointer::isPointerDeRef(tok2, unknown))
                 {
-                    // Is loop variable a pointer?
-                    if (isPointer(varid))
-                        nullPointerError(tok2, varname);
+                    nullPointerError(tok2, varname, tok->linenr());
                 }
                 break;
             }
@@ -249,7 +256,7 @@ void CheckNullPointer::nullPointerLinkedList()
             continue;
 
         // is there any dereferencing occurring in the for statement
-        // parlevel2 counts the parantheses when using tok2.
+        // parlevel2 counts the parentheses when using tok2.
         unsigned int parlevel2 = 1;
         for (const Token *tok2 = tok1->tokAt(2); tok2; tok2 = tok2->next())
         {
@@ -350,16 +357,27 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
             continue;
         }
 
+        /**
+         * @todo There are lots of false negatives here. A dereference
+         *  is only investigated if a few specific conditions are met.
+         */
+
         // dereference in assignment
-        if (Token::Match(tok1, "[{};] %var% = %var% . %var%"))
+        if (Token::Match(tok1, "[;{}] %var% . %var%"))
+        {
+            tok1 = tok1->next();
+        }
+
+        // dereference in assignment
+        else if (Token::Match(tok1, "[{};] %var% = %var% . %var%"))
         {
             if (std::string(tok1->strAt(1)) == tok1->strAt(3))
                 continue;
             tok1 = tok1->tokAt(3);
         }
 
-        // dereference in function call
-        else if (Token::Match(tok1->tokAt(-2), "%var% ( %var% . %var%") ||
+        // dereference in function call (but not sizeof|decltype)
+        else if ((Token::Match(tok1->tokAt(-2), "%var% ( %var% . %var%") && !Token::Match(tok1->tokAt(-2), "sizeof|decltype ( %var% . %var%")) ||
                  Token::Match(tok1->previous(), ", %var% . %var%"))
         {
             // Is the function return value taken by the pointer?
@@ -396,6 +414,22 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
         // name of struct pointer
         const std::string varname(tok1->str());
 
+        // is pointer local?
+        bool isLocal = false;
+        const Variable * var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(tok1->varId());
+        if (var && (var->isLocal() || var->isArgument()))
+            isLocal = true;
+
+        // member function may or may not nullify the pointer if it's global (#2647)
+        if (!isLocal)
+        {
+            const Token *tok2 = tok1;
+            while (Token::Match(tok2, "%var% ."))
+                tok2 = tok2->tokAt(2);
+            if (Token::Match(tok2,"%var% ("))
+                continue;
+        }
+
         // count { and } using tok2
         unsigned int indentlevel2 = 0;
         for (const Token *tok2 = tok1->tokAt(3); tok2; tok2 = tok2->next())
@@ -410,8 +444,8 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
                 --indentlevel2;
             }
 
-            // label. goto destination..
-            else if (tok2->isName() && Token::simpleMatch(tok2->next(), ":"))
+            // label / ?:
+            else if (tok2->str() == ":")
                 break;
 
             // Reassignment of the struct
@@ -428,13 +462,21 @@ void CheckNullPointer::nullPointerStructByDeRefAndChec()
             else if (tok2->str() == "do")
                 break;
 
-            // return at base level => stop checking
-            else if (indentlevel2 == 0 && tok2->str() == "return")
+            // return/break at base level => stop checking
+            else if (indentlevel2 == 0 && (tok2->str() == "return" || tok2->str() == "break"))
                 break;
 
+            // Function call: If the pointer is not a local variable it
+            // might be changed by the call.
+            else if (Token::Match(tok2, "[;{}] %var% (") &&
+                     Token::simpleMatch(tok2->tokAt(2)->link(), ") ;") && !isLocal)
+            {
+                break;
+            }
+
             // Check if pointer is null.
-            // TODO: false negatives for something like: "if (p &&.."?
-            else if (Token::Match(tok2, "if ( !| %varid% )", varid1))
+            // TODO: false negatives for "if (!p || .."
+            else if (Token::Match(tok2, "if ( !| %varid% )|&&", varid1))
             {
                 // Is this variable a pointer?
                 if (isPointer(varid1))
@@ -552,9 +594,9 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
 
             // If the if-body ends with a unknown macro then bailout
             {
-                // goto the end paranthesis
+                // goto the end parenthesis
                 const Token *endpar = tok->next()->link();
-                const Token *endbody = endpar ? endpar->next()->link() : 0;
+                const Token *endbody = Token::simpleMatch(endpar, ") {") ? endpar->next()->link() : 0;
                 if (endbody &&
                     Token::Match(endbody->tokAt(-3), "[;{}] %var% ;") &&
                     isUpper(endbody->tokAt(-2)->str()))
@@ -563,14 +605,9 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
 
             // vartok : token for the variable
             const Token *vartok = 0;
-            if (Token::Match(tok, "if ( ! %var% ) {"))
+            if (Token::Match(tok, "if ( ! %var% )|&&"))
                 vartok = tok->tokAt(3);
-            else if (Token::Match(tok, "if ( NULL|0 == %var% ) {"))
-                vartok = tok->tokAt(4);
-            else if (Token::Match(tok, "if ( %var% == NULL|0 ) {"))
-                vartok = tok->tokAt(2);
-            else if (Token::Match(tok, "if|while ( %var% ) {") &&
-                     !Token::simpleMatch(tok->tokAt(4)->link(), "} else"))
+            else if (Token::Match(tok, "if|while ( %var% )|&&"))
                 vartok = tok->tokAt(2);
             else
                 continue;
@@ -580,6 +617,8 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
             if (varid == 0)
                 continue;
 
+            const unsigned int linenr = vartok->linenr();
+
             // Check if variable is a pointer. TODO: Use isPointer?
             if (pointerVariables.find(varid) == pointerVariables.end())
                 continue;
@@ -590,20 +629,28 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
             // start token = inside the if-body
             const Token *tok1 = tok->next()->link()->tokAt(2);
 
-            if (Token::Match(tok, "if|while ( %var% )"))
+            // indentlevel inside the if-body is 1
+            unsigned int indentlevel = 1;
+
+            if (Token::Match(tok, "if|while ( %var% )|&&"))
             {
                 // pointer might be null
                 null = false;
 
                 // start token = first token after the if/while body
-                tok1 = tok1->previous()->link()->next();
+                tok1 = tok1->previous()->link();
+                tok1 = tok1 ? tok1->next() : NULL;
+                if (!tok1)
+                    continue;
+
+                // indentlevel at the base level is 0
+                indentlevel = 0;
             }
 
             // Name of the pointer
             const std::string &pointerName = vartok->str();
 
             // Count { and } for tok2
-            unsigned int indentlevel = 1;
             for (const Token *tok2 = tok1; tok2; tok2 = tok2->next())
             {
                 if (tok2->str() == "{")
@@ -613,6 +660,7 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
                     if (indentlevel == 0)
                         break;
                     --indentlevel;
+
                     if (null && indentlevel == 0)
                     {
                         // skip all "else" blocks because they are not executed in this execution path
@@ -625,7 +673,7 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
                 if (Token::Match(tok2, "goto|return|continue|break|throw|if|switch"))
                 {
                     if (Token::Match(tok2, "return * %varid%", varid))
-                        nullPointerError(tok2, tok->strAt(3));
+                        nullPointerError(tok2, tok->strAt(3), linenr);
                     break;
                 }
 
@@ -655,7 +703,7 @@ void CheckNullPointer::nullPointerByCheckAndDeRef()
                         ;
 
                     else if (CheckNullPointer::isPointerDeRef(tok2, unknown))
-                        nullPointerError(tok2, pointerName);
+                        nullPointerError(tok2, pointerName, linenr);
 
                     else
                         break;
@@ -718,8 +766,7 @@ void CheckNullPointer::nullConstantDereference()
 
             else if (Token::simpleMatch(tok, "* 0"))
             {
-                if (Token::Match(tok->previous(), "[<>;{}=+-*/(,]") ||
-                    Token::Match(tok->previous(), "return|<<"))
+                if (Token::Match(tok->previous(), "return|;|{|}|=|(|,|%op%"))
                 {
                     nullPointerError(tok);
                 }
@@ -831,13 +878,16 @@ private:
     /** parse tokens */
     const Token *parse(const Token &tok, std::list<ExecutionPath *> &checks) const
     {
-        if (Token::Match(tok.previous(), "[;{}] const| %type% * %var% ;"))
+        if (Token::Match(tok.previous(), "[;{}] const| struct| %type% * %var% ;"))
         {
             const Token * vartok = tok.tokAt(2);
 
             if (tok.str() == "const")
                 vartok = vartok->next();
 
+            if (tok.str() == "struct")
+                vartok = vartok->next();
+
             if (vartok->varId() != 0)
                 checks.push_back(new Nullpointer(owner, vartok->varId(), vartok->str()));
             return vartok->next();
