@@ -55,7 +55,6 @@ public:
         checkOther.checkUnsignedDivision();
         checkOther.checkCharVariable();
         checkOther.functionVariableUsage();
-        checkOther.checkVariableScope();
         checkOther.checkStructMemberUsage();
         checkOther.strPlusChar();
         checkOther.sizeofsizeof();
@@ -63,7 +62,14 @@ public:
         checkOther.checkRedundantAssignmentInSwitch();
         checkOther.checkAssignmentInAssert();
         checkOther.checkSizeofForArrayParameter();
+        checkOther.checkSizeofForNumericParameter();
         checkOther.checkSelfAssignment();
+        checkOther.checkDuplicateIf();
+        checkOther.checkDuplicateBranch();
+        checkOther.checkDuplicateExpression();
+
+        // information checks
+        checkOther.checkVariableScope();
 
         checkOther.clarifyCondition();   // not simplified because ifAssign
     }
@@ -93,6 +99,7 @@ public:
         checkOther.checkIncrementBoolean();
         checkOther.checkComparisonOfBoolWithInt();
         checkOther.checkSwitchCaseFallThrough();
+        checkOther.checkAlwaysTrueOrFalseStringCompare();
     }
 
     /** @brief Clarify calculation for ".. a * b ? .." */
@@ -193,6 +200,9 @@ public:
     /** @brief %Check for using sizeof with array given as function argument */
     void checkSizeofForArrayParameter();
 
+    /** @brief %Check for using sizeof with numeric given as function argument */
+    void checkSizeofForNumericParameter();
+
     /** @brief %Check for using bad usage of strncmp and substr */
     void checkIncorrectStringCompare();
 
@@ -202,6 +212,18 @@ public:
     /** @brief %Check for suspicious comparison of a bool and a non-zero (and non-one) value (e.g. "if (!x==4)") */
     void checkComparisonOfBoolWithInt();
 
+    /** @brief %Check for suspicious code where multiple if have the same expression (e.g "if (a) { } else if (a) { }") */
+    void checkDuplicateIf();
+
+    /** @brief %Check for suspicious code where if and else branch are the same (e.g "if (a) b = true; else b = true;") */
+    void checkDuplicateBranch();
+
+    /** @brief %Check for suspicious code with the same expression on both sides of operator (e.g "if (a && a)") */
+    void checkDuplicateExpression();
+
+    /** @brief %Check for suspicious code that compares string literals for equality */
+    void checkAlwaysTrueOrFalseStringCompare();
+
     // Error messages..
     void cstyleCastError(const Token *tok);
     void dangerousUsageStrtolError(const Token *tok);
@@ -227,9 +249,14 @@ public:
     void catchExceptionByValueError(const Token *tok);
     void memsetZeroBytesError(const Token *tok, const std::string &varname);
     void sizeofForArrayParameterError(const Token *tok);
+    void sizeofForNumericParameterError(const Token *tok);
     void incorrectStringCompareError(const Token *tok, const std::string& func, const std::string &string, const std::string &len);
     void incrementBooleanError(const Token *tok);
     void comparisonOfBoolWithIntError(const Token *tok, const std::string &varname);
+    void duplicateIfError(const Token *tok1, const Token *tok2);
+    void duplicateBranchError(const Token *tok1, const Token *tok2);
+    void duplicateExpressionError(const Token *tok1, const Token *tok2, const std::string &op);
+    void alwaysTrueFalseStringCompare(const Token *tok, const std::string& str1, const std::string& str2);
 
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings)
     {
@@ -243,6 +270,7 @@ public:
         c.fflushOnInputStreamError(0, "stdin");
         c.misusedScopeObjectError(NULL, "varname");
         c.sizeofForArrayParameterError(0);
+        c.sizeofForNumericParameterError(0);
 
         // style/warning
         c.cstyleCastError(0);
@@ -274,6 +302,10 @@ public:
         c.incorrectStringCompareError(0, "substr", "\"Hello World\"", "12");
         c.incrementBooleanError(0);
         c.comparisonOfBoolWithIntError(0, "varname");
+        c.duplicateIfError(0, 0);
+        c.duplicateBranchError(0, 0);
+        c.duplicateExpressionError(0, 0, "&&");
+        c.alwaysTrueFalseStringCompare(0, "str1", "str2");
     }
 
     std::string myName() const
@@ -292,6 +324,7 @@ public:
                "* scoped object destroyed immediately after construction\n"
                "* assignment in an assert statement\n"
                "* sizeof for array given as function argument\n"
+               "* sizeof for numeric given as function argument\n"
                "* incorrect length arguments for 'substr' and 'strncmp'\n"
 
                // style
@@ -316,7 +349,8 @@ public:
                "* Clarify calculation with parentheses\n"
                "* using increment on boolean\n"
                "* comparison of a boolean with a non-zero integer\n"
-               "* suspicious condition (assignment+comparison)"
+               "* suspicious condition (assignment+comparison)\n"
+               "* suspicious condition (runtime comparison of string literals)\n"
 
                // optimisations
                "* optimisation: detect post increment/decrement\n";
