@@ -17,8 +17,8 @@
  */
 
 #include "checkstl.h"
-#include "token.h"
 #include "executionpath.h"
+#include "symboldatabase.h"
 #include <sstream>
 
 // Register this check class (by creating a static instance of it)
@@ -100,10 +100,11 @@ void CheckStl::iterators()
                     // skip error message if container is a set..
                     if (tok2->varId() > 0)
                     {
-                        const Token *decltok = Token::findmatch(_tokenizer->tokens(), "%varid%", tok2->varId());
-                        while (decltok && !Token::Match(decltok, "[;{},(]"))
-                            decltok = decltok->previous();
-                        if (Token::Match(decltok, "%any% const| std :: set"))
+                        const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
+                        const Variable *variableInfo = symbolDatabase->getVariableFromVarId(tok2->varId());
+                        const Token *decltok = variableInfo ? variableInfo->typeStartToken() : NULL;
+
+                        if (Token::Match(decltok, "const| std :: set"))
                             continue;	// No warning
                     }
 
@@ -438,8 +439,18 @@ void CheckStl::erase()
                 {
                     if (Token::Match(tok2, "; %var% !="))
                     {
-                        const unsigned int varid = tok2->next()->varId();
-                        if (varid > 0 && Token::findmatch(_tokenizer->tokens(), "> :: iterator %varid%", varid))
+                        // Get declaration token for var..
+                        const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
+                        const Variable *variableInfo = symbolDatabase->getVariableFromVarId(tok2->next()->varId());
+                        const Token *decltok = variableInfo ? variableInfo->typeEndToken() : NULL;
+
+                        // Is variable an iterator?
+                        bool isIterator = false;
+                        if (decltok && Token::Match(decltok->tokAt(-2), "> :: iterator %varid%", tok2->next()->varId()))
+                            isIterator = true;
+
+                        // If tok2->next() is an iterator, check scope
+                        if (isIterator)
                             EraseCheckLoop::checkScope(this, tok2->next());
                     }
                     break;
@@ -489,7 +500,7 @@ void CheckStl::pushback()
             if (pointerId == 0 || containerId == 0)
                 continue;
 
-            // Count { , } and parantheses for tok2
+            // Count { , } and parentheses for tok2
             int indent = 0;
             bool invalidPointer = false;
             for (const Token *tok2 = tok; indent >= 0 && tok2; tok2 = tok2->next())
@@ -555,7 +566,7 @@ void CheckStl::pushback()
         // the variable id for the vector
         unsigned int vectorid = 0;
 
-        // count { , } and parantheses for tok2
+        // count { , } and parentheses for tok2
         int indent = 0;
 
         std::string invalidIterator;
@@ -641,7 +652,8 @@ void CheckStl::pushback()
                 tok2 = tok2->tokAt(3)->link();
             }
 
-            else if (tok2->str() == "return" || tok2->str() == "break")
+            // TODO: instead of bail out for 'else' try to check all execution paths.
+            else if (tok2->str() == "return" || tok2->str() == "break" || tok2->str() == "else")
             {
                 invalidIterator.clear();
             }
@@ -793,17 +805,19 @@ void CheckStl::if_findError(const Token *tok, bool str)
 
 
 
-bool CheckStl::isStlContainer(const Token *tok)
+bool CheckStl::isStlContainer(unsigned int varid)
 {
     // check if this token is defined
-    if (tok->varId())
+    if (varid)
     {
         // find where this token is defined
-        const Token *type = Token::findmatch(_tokenizer->tokens(), "%varid%", tok->varId());
+        const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varid);
+
+        if (!var)
+            return false;
 
         // find where this tokens type starts
-        while (type->previous() && !Token::Match(type->previous(), "[;{,(]"))
-            type = type->previous();
+        const Token *type = var->typeStartToken();
 
         // ignore "const"
         if (type->str() == "const")
@@ -829,39 +843,65 @@ bool CheckStl::isStlContainer(const Token *tok)
 
 void CheckStl::size()
 {
-    if (!_settings->_checkCodingStyle || !_settings->inconclusive)
+    if (!_settings->_checkCodingStyle)
         return;
 
     for (const Token *tok = _tokenizer->tokens(); tok; tok = tok->next())
     {
-        if (Token::Match(tok, "%var% . size ( )"))
+        if (Token::Match(tok, "%var% . size ( )") ||
+            Token::Match(tok, "%var% . %var% . size ( )"))
         {
-            if (Token::Match(tok->tokAt(5), "==|!=|> 0"))
+            int offset = 5;
+            const Token *tok1 = tok;
+            unsigned int varid = 0;
+
+            // get the variable id
+            if (tok->strAt(2) != "size")
             {
-                if (isStlContainer(tok))
-                    sizeError(tok);
-            }
-            else if ((tok->tokAt(5)->str() == ")" ||
-                      tok->tokAt(5)->str() == "&&" ||
-                      tok->tokAt(5)->str() == "||" ||
-                      tok->tokAt(5)->str() == "!") &&
-                     (tok->tokAt(-1)->str() == "(" ||
-                      tok->tokAt(-1)->str() == "&&" ||
-                      tok->tokAt(-1)->str() == "||" ||
-                      tok->tokAt(-1)->str() == "!"))
-            {
-                if (tok->tokAt(-1)->str() == "(" &&
-                    tok->tokAt(5)->str() == ")")
+                offset = 7;
+                tok1 = tok1->tokAt(2);
+
+                // found a.b.size(), lookup class/struct variable
+                const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(tok->varId());
+                if (var && var->type())
                 {
-                    // check for passing size to function call
-                    if (Token::Match(tok->tokAt(-2), "if|while"))
+                    // get class/struct variable type
+                    const Scope *type = var->type();
+
+                    // lookup variable member
+                    std::list<Variable>::const_iterator it;
+                    for (it = type->varlist.begin(); it != type->varlist.end(); ++it)
                     {
-                        if (isStlContainer(tok))
-                            sizeError(tok);
+                        if (it->name() == tok1->str())
+                        {
+                            // found member variable, save varid
+                            varid = it->varId();
+                            break;
+                        }
                     }
                 }
-                else if (isStlContainer(tok))
-                    sizeError(tok);
+            }
+            else
+                varid = tok1->varId();
+
+            if (varid)
+            {
+                // check for comparison to zero
+                if (Token::Match(tok->tokAt(offset), "==|!=|> 0") ||
+                    Token::Match(tok->tokAt(-2), "0 ==|!=|<"))
+                {
+                    if (isStlContainer(varid))
+                        sizeError(tok1);
+                }
+
+                // check for using as boolean expression
+                else if ((Token::Match(tok->tokAt(-2), "if|while (") ||
+                          Token::Match(tok->tokAt(-3), "if|while ( !")) &&
+                         tok->strAt(offset) == ")")
+                {
+                    if (isStlContainer(varid))
+                        sizeError(tok1);
+                }
             }
         }
     }
@@ -973,6 +1013,13 @@ void CheckStl::missingComparison()
                         incrementToken = 0;
                     else if (tok3->str() == "break" || tok3->str() == "return")
                         incrementToken = 0;
+                    else if (Token::Match(tok3, "%varid% = %var% . insert ( ++| %varid% ++| ,", iteratorId))
+                    {
+                        // skip insertion..
+                        tok3 = tok3->tokAt(6)->link();
+                        if (!tok3)
+                            break;
+                    }
                 }
                 if (incrementToken)
                     missingComparisonError(incrementToken, tok2->tokAt(16));
