@@ -384,6 +384,7 @@ private:
                 break;
             if (tok2->varId() &&
                 !Token::Match(tok2->previous(), "&|::") &&
+                !Token::simpleMatch(tok2->tokAt(-2), "& (") &&
                 !Token::simpleMatch(tok2->next(), "="))
             {
                 // Multiple assignments..
@@ -481,7 +482,7 @@ private:
             }
 
             // Used..
-            if (Token::Match(tok.previous(), "[[(,+-*/|=] %var% []),;+-*/|]"))
+            if (Token::Match(tok.previous(), "[[(,+-*/|=] %var% ]|)|,|;|%op%"))
             {
                 use(checks, &tok);
                 return &tok;
@@ -507,6 +508,11 @@ private:
                     const Token *tok2 = tok.next();
                     if (tok2->str() == "[" && Token::simpleMatch(tok2->link(), "] ="))
                     {
+                        if (use_dead_pointer(checks, &tok))
+                        {
+                            return &tok;
+                        }
+
                         parserhs(tok2, checks);
                         tok2 = tok2->link()->next();
                     }
@@ -603,7 +609,10 @@ private:
                 std::list<const Token *> var;
                 CheckNullPointer::parseFunctionCall(tok, var, 1);
                 for (std::list<const Token *>::const_iterator it = var.begin(); it != var.end(); ++it)
+                {
                     use_array(checks, *it);
+                    use_dead_pointer(checks, *it);
+                }
 
                 // Using uninitialized pointer is bad if using null pointer is bad
                 std::list<const Token *> var2;
