@@ -23,6 +23,8 @@
 #include <list>
 #include <string>
 
+#include "settings.h"
+
 class Token;
 class Tokenizer;
 
@@ -33,7 +35,62 @@ class Tokenizer;
 class Severity
 {
 public:
-    enum SeverityType { none, error, warning, style, performance, portability, information, debug };
+    /**
+     * Message severities.
+     */
+    enum SeverityType
+    {
+        /**
+         * No severity (default value).
+         */
+        none,
+        /**
+         * Programming error.
+         * This indicates severe error like memory leak etc.
+         * The error is certain.
+         */
+        error,
+        /**
+         * Warning.
+         * Used for dangerous coding style that can cause severe runtime errors.
+         * For example: forgetting to initialize a member variable in a constructor.
+         */
+        warning,
+        /**
+         * Style warning.
+         * Used for general code cleanup recommendations. Fixing these
+         * will not fix any bugs but will make the code easier to maintain.
+         * For example: redundant code, unreachable code, etc.
+         */
+        style,
+        /**
+         * Performance warning.
+         * Not an error as is but suboptimal code and fixing it probably leads
+         * to faster performance of the compiled code.
+         */
+        performance,
+        /**
+         * Portability warning.
+         * This warning indicates the code is not properly portable for
+         * different platforms and bitnesses (32/64 bit). If the code is meant
+         * to compile in different platforms and bitnesses these warnings
+         * should be fixed.
+         */
+        portability,
+        /**
+         * Checking information.
+         * Information message about the checking (process) itself. These
+         * messages inform about header files not found etc issues that are
+         * not errors in the code but something user needs to know.
+         */
+        information,
+        /**
+         * Debug message.
+         * Debug-mode message useful for the developers.
+         */
+        debug
+    };
+
     static std::string toString(SeverityType severity)
     {
         switch (severity)
@@ -108,6 +165,11 @@ public:
                 line = 0;
             }
 
+            FileLocation(const std::string &file, unsigned int aline)
+                : line(aline), _file(file)
+            {
+            }
+
             /**
              * Return the filename.
              * @param convert If true convert path to native separators.
@@ -126,7 +188,7 @@ public:
 
         };
 
-        ErrorMessage(const std::list<FileLocation> &callStack, Severity::SeverityType severity, const std::string &msg, const std::string &id);
+        ErrorMessage(const std::list<FileLocation> &callStack, Severity::SeverityType severity, const std::string &msg, const std::string &id, bool inconclusive);
         ErrorMessage();
 
         /**
@@ -153,6 +215,7 @@ public:
         std::list<FileLocation> _callStack;
         Severity::SeverityType _severity;
         std::string _id;
+        bool _inconclusive;
 
         /** source file (not header) */
         std::string file0;
@@ -209,14 +272,6 @@ public:
      */
     virtual void reportErr(const ErrorLogger::ErrorMessage &msg) = 0;
 
-    /**
-     * Information about how many files have been checked
-     *
-     * @param index This many files have been checked.
-     * @param max This many files there are in total.
-     */
-    virtual void reportStatus(unsigned int index, unsigned int max) = 0;
-
     /**
      * Report progress to client
      * @param filename main file that is checked
@@ -230,6 +285,12 @@ public:
         (void)value;
     }
 
+    /**
+     * Report list of unmatched suppressions
+     * @param unmatched list of unmatched suppressions (from Settings::Suppressions::getUnmatched(Local|Global)Suppressions)
+     */
+    void reportUnmatchedSuppressions(const std::list<Settings::Suppressions::SuppressionEntry> &unmatched);
+
     static std::string callStackToString(const std::list<ErrorLogger::ErrorMessage::FileLocation> &callStack);
 };
 
