@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2010 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2011 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,21 +20,37 @@
 #ifndef mathlibH
 #define mathlibH
 
-#include "token.h"
+#include <string>
+#include <sstream>
 
 /// @addtogroup Core
 /// @{
 
 /** @brief simple math functions that uses operands stored in std::string. useful when performing math on tokens. */
 
+class Tokenizer;
+
 class MathLib
 {
 public:
-    static long toLongNumber(const std::string & str);
+    typedef long long bigint;
+
+    static bigint toLongNumber(const std::string & str);
     static double toDoubleNumber(const std::string & str);
 
     template<typename T>
-    static std::string toString(T d);
+    static std::string toString(const T &d)
+    {
+        std::ostringstream result;
+        result << d;
+        std::string strResult(result.str());
+        if (strResult == "-0"
+            || strResult == "+0"
+            || strResult == "-0."
+            || strResult == "+0.")
+            return std::string("0");
+        return result.str();
+    }
 
     static bool isInt(const std::string & str);
     static bool isFloat(const std::string &str);
@@ -44,7 +60,7 @@ public:
     static std::string subtract(const std::string & first, const std::string & second);
     static std::string multiply(const std::string & first, const std::string & second);
     static std::string divide(const std::string & first, const std::string & second);
-    static std::string calculate(const std::string & first, const std::string & second, char action);
+    static std::string calculate(const std::string & first, const std::string & second, char action, const Tokenizer *tokenizer);
 
     static std::string sin(const std::string & tok);
     static std::string cos(const std::string & tok);
