@@ -35,6 +35,8 @@
 #include <set>
 #include <stack>
 
+bool Preprocessor::missingIncludeFlag;
+
 Preprocessor::Preprocessor(Settings *settings, ErrorLogger *errorLogger) : _settings(settings), _errorLogger(errorLogger)
 {
 
@@ -53,7 +55,8 @@ void Preprocessor::writeError(const std::string &fileName, const unsigned int li
     errorLogger->reportErr(ErrorLogger::ErrorMessage(locationList,
                            Severity::error,
                            errorText,
-                           errorType));
+                           errorType,
+                           false));
 }
 
 static unsigned char readChar(std::istream &istr)
@@ -109,39 +112,19 @@ static std::string join(const std::list<std::string> &list, char separator)
 /** Just read the code into a string. Perform simple cleanup of the code */
 std::string Preprocessor::read(std::istream &istr, const std::string &filename, Settings *settings)
 {
-    // Get filedata from stream..
-    bool ignoreSpace = true;
-
-    // need space.. #if( => #if (
-    bool needSpace = false;
-
+    // ------------------------------------------------------------------------------------------
+    //
     // handling <backspace><newline>
     // when this is encountered the <backspace><newline> will be "skipped".
     // on the next <newline>, extra newlines will be added
-    unsigned int newlines = 0;
-
     std::ostringstream code;
+    unsigned int newlines = 0;
     for (unsigned char ch = readChar(istr); istr.good(); ch = readChar(istr))
     {
         // Replace assorted special chars with spaces..
         if (((ch & 0x80) == 0) && (ch != '\n') && (std::isspace(ch) || std::iscntrl(ch)))
             ch = ' ';
 
-        // Skip spaces after ' ' and after '#'
-        if (ch == ' ' && ignoreSpace)
-            continue;
-        ignoreSpace = bool(ch == ' ' || ch == '#' || ch == '\n');
-
-        if (needSpace)
-        {
-            if (ch == '(' || ch == '!')
-                code << " ";
-            else if (!std::isalpha(ch))
-                needSpace = false;
-        }
-        if (ch == '#')
-            needSpace = true;
-
         // <backspace><newline>..
         // for gcc-compatibility the trailing spaces should be ignored
         // for vs-compatibility the trailing spaces should be kept
@@ -178,8 +161,6 @@ std::string Preprocessor::read(std::istream &istr, const std::string &filename,
             else
                 code << "\\";
         }
-
-        // Just some code..
         else
         {
             code << char(ch);
@@ -192,8 +173,128 @@ std::string Preprocessor::read(std::istream &istr, const std::string &filename,
             }
         }
     }
+    std::string result = code.str();
+    code.str("");
 
-    return removeParantheses(removeComments(code.str(), filename, settings));
+    // ------------------------------------------------------------------------------------------
+    //
+    // Remove all comments..
+    result = removeComments(result, filename, settings);
+
+    // ------------------------------------------------------------------------------------------
+    //
+    // Clean up all preprocessor statements
+    result = preprocessCleanupDirectives(result);
+
+    // ------------------------------------------------------------------------------------------
+    //
+    // Clean up preprocessor #if statements with Parentheses
+    result = removeParentheses(result);
+
+    // Remove '#if 0' blocks
+    if (result.find("#if 0\n") != std::string::npos)
+        result = removeIf0(result);
+
+    return result;
+}
+
+std::string Preprocessor::preprocessCleanupDirectives(const std::string &processedFile) const
+{
+    std::ostringstream code;
+    std::istringstream sstr(processedFile);
+
+    std::string line;
+    while (std::getline(sstr, line))
+    {
+        // Trim lines..
+        if (!line.empty() && line[0] == ' ')
+            line.erase(0, line.find_first_not_of(" "));
+        if (!line.empty() && line[line.size()-1] == ' ')
+            line.erase(line.find_last_not_of(" ") + 1);
+
+        // Preprocessor
+        if (!line.empty() && line[0] == '#')
+        {
+            enum
+            {
+                ESC_NONE,
+                ESC_SINGLE,
+                ESC_DOUBLE
+            } escapeStatus = ESC_NONE;
+
+            char prev = ' '; // hack to make it skip spaces between # and the directive
+            code << "#";
+            std::string::const_iterator i = line.begin();
+            ++i;
+
+            // need space.. #if( => #if (
+            bool needSpace = true;
+            while (i != line.end())
+            {
+                // disable esc-mode
+                if (escapeStatus != ESC_NONE)
+                {
+                    if (prev != '\\' && escapeStatus == ESC_SINGLE && *i == '\'')
+                    {
+                        escapeStatus = ESC_NONE;
+                    }
+                    if (prev != '\\' && escapeStatus == ESC_DOUBLE && *i == '"')
+                    {
+                        escapeStatus = ESC_NONE;
+                    }
+                }
+                else
+                {
+                    // enable esc-mode
+                    if (escapeStatus == ESC_NONE && *i == '"')
+                        escapeStatus = ESC_DOUBLE;
+                    if (escapeStatus == ESC_NONE && *i == '\'')
+                        escapeStatus = ESC_SINGLE;
+                }
+                // skip double whitespace between arguments
+                if (escapeStatus == ESC_NONE && prev == ' ' && *i == ' ')
+                {
+                    ++i;
+                    continue;
+                }
+                // Convert #if( to "#if ("
+                if (escapeStatus == ESC_NONE)
+                {
+                    if (needSpace)
+                    {
+                        if (*i == '(' || *i == '!')
+                            code << " ";
+                        else if (!std::isalpha(*i))
+                            needSpace = false;
+                    }
+                    if (*i == '#')
+                        needSpace = true;
+                }
+                code << *i;
+                if (escapeStatus != ESC_NONE && prev == '\\' && *i == '\\')
+                {
+                    prev = ' ';
+                }
+                else
+                {
+                    prev = *i;
+                }
+                ++i;
+            }
+            if (escapeStatus != ESC_NONE)
+            {
+                // unmatched quotes.. compiler should probably complain about this..
+            }
+        }
+        else
+        {
+            // Do not mess with regular code..
+            code << line;
+        }
+        code << (sstr.eof()?"":"\n");
+    }
+
+    return code.str();
 }
 
 static bool hasbom(const std::string &str)
@@ -205,6 +306,35 @@ static bool hasbom(const std::string &str)
 }
 
 
+// This wrapper exists because Sun's CC does not allow a static_cast
+// from extern "C" int(*)(int) to int(*)(int).
+static int tolowerWrapper(int c)
+{
+    return std::tolower(c);
+}
+
+
+static bool isFallThroughComment(std::string comment)
+{
+    // convert comment to lower case without whitespace
+    std::transform(comment.begin(), comment.end(), comment.begin(), tolowerWrapper);
+    for (std::string::iterator i = comment.begin(); i != comment.end();)
+    {
+        if (::isspace(static_cast<unsigned char>(*i)))
+            i = comment.erase(i);
+        else
+            ++i;
+    }
+
+    return comment.find("fallthr") != std::string::npos ||
+           comment.find("fallsthr") != std::string::npos ||
+           comment.find("fall-thr") != std::string::npos ||
+           comment.find("dropthr") != std::string::npos ||
+           comment.find("passthr") != std::string::npos ||
+           comment.find("nobreak") != std::string::npos ||
+           comment == "fall";
+}
+
 std::string Preprocessor::removeComments(const std::string &str, const std::string &filename, Settings *settings)
 {
     // For the error report
@@ -216,7 +346,9 @@ std::string Preprocessor::removeComments(const std::string &str, const std::stri
     unsigned int newlines = 0;
     std::ostringstream code;
     unsigned char previous = 0;
+    bool inPreprocessorLine = false;
     std::vector<std::string> suppressionIDs;
+    bool fallThroughComment = false;
 
     for (std::string::size_type i = hasbom(str) ? 3U : 0U; i < str.length(); ++i)
     {
@@ -244,20 +376,34 @@ std::string Preprocessor::removeComments(const std::string &str, const std::stri
             continue;
         }
 
-        // We have finished a line that didn't contain any comment
-        // (the '\n' is swallowed when a // comment is detected)
-        if ((ch == '\n' || str.compare(i,2,"//")==0) && !suppressionIDs.empty())
+        // First skip over any whitespace that may be present
+        if (std::isspace(ch))
         {
-            // Add the suppressions.
-            for (size_t j(0); j < suppressionIDs.size(); ++j)
+            if (ch == ' ' && previous == ' ')
             {
-                const std::string errmsg(settings->nomsg.addSuppression(suppressionIDs[j], filename, lineno));
-                if (!errmsg.empty())
+                // Skip double white space
+            }
+            else
+            {
+                code << char(ch);
+                previous = ch;
+            }
+
+            // if there has been <backspace><newline> sequences, add extra newlines..
+            if (ch == '\n')
+            {
+                if (previous != '\\')
+                    inPreprocessorLine = false;
+                ++lineno;
+                if (newlines > 0)
                 {
-                    writeError(filename, lineno, _errorLogger, "cppcheckError", errmsg);
+                    code << std::string(newlines, '\n');
+                    newlines = 0;
+                    previous = '\n';
                 }
             }
-            suppressionIDs.clear();
+
+            continue;
         }
 
         // Remove comments..
@@ -267,10 +413,10 @@ std::string Preprocessor::removeComments(const std::string &str, const std::stri
             i = str.find('\n', i);
             if (i == std::string::npos)
                 break;
+            std::string comment(str, commentStart, i - commentStart);
 
             if (settings && settings->_inlineSuppressions)
             {
-                std::string comment(str, commentStart, i - commentStart);
                 std::istringstream iss(comment);
                 std::string word;
                 iss >> word;
@@ -282,12 +428,18 @@ std::string Preprocessor::removeComments(const std::string &str, const std::stri
                 }
             }
 
+            if (isFallThroughComment(comment))
+            {
+                fallThroughComment = true;
+            }
+
             code << "\n";
             previous = '\n';
             ++lineno;
         }
         else if (str.compare(i, 2, "/*", 0, 2) == 0)
         {
+            size_t commentStart = i + 2;
             unsigned char chPrev = 0;
             ++i;
             while (i < str.length() && (chPrev != '*' || ch != '/'))
@@ -301,134 +453,237 @@ std::string Preprocessor::removeComments(const std::string &str, const std::stri
                     ++lineno;
                 }
             }
-        }
+            std::string comment(str, commentStart, i - commentStart - 1);
 
-        // String or char constants..
-        else if (ch == '\"' || ch == '\'')
-        {
-            code << char(ch);
-            char chNext;
-            do
+            if (isFallThroughComment(comment))
             {
-                ++i;
-                chNext = str[i];
-                if (chNext == '\\')
+                fallThroughComment = true;
+            }
+
+            if (settings && settings->_inlineSuppressions)
+            {
+                std::istringstream iss(comment);
+                std::string word;
+                iss >> word;
+                if (word == "cppcheck-suppress")
+                {
+                    iss >> word;
+                    if (iss)
+                        suppressionIDs.push_back(word);
+                }
+            }
+        }
+        else if (ch == '#' && previous == '\n')
+        {
+            code << ch;
+            previous = ch;
+            inPreprocessorLine = true;
+
+            // Add any pending inline suppressions that have accumulated.
+            if (!suppressionIDs.empty())
+            {
+                if (settings != NULL)
+                {
+                    // Add the suppressions.
+                    for (size_t j(0); j < suppressionIDs.size(); ++j)
+                    {
+                        const std::string errmsg(settings->nomsg.addSuppression(suppressionIDs[j], filename, lineno));
+                        if (!errmsg.empty())
+                        {
+                            writeError(filename, lineno, _errorLogger, "cppcheckError", errmsg);
+                        }
+                    }
+                }
+                suppressionIDs.clear();
+            }
+        }
+        else
+        {
+            if (!inPreprocessorLine)
+            {
+                // Not whitespace, not a comment, and not preprocessor.
+                // Must be code here!
+
+                // First check for a "fall through" comment match, but only
+                // add a suppression if the next token is 'case' or 'default'
+                if (_settings->_checkCodingStyle && _settings->experimental && fallThroughComment)
+                {
+                    std::string::size_type j = str.find_first_not_of("abcdefghijklmnopqrstuvwxyz", i);
+                    std::string tok = str.substr(i, j - i);
+                    if (tok == "case" || tok == "default")
+                        suppressionIDs.push_back("switchCaseFallThrough");
+                    fallThroughComment = false;
+                }
+
+                // Add any pending inline suppressions that have accumulated.
+                if (!suppressionIDs.empty())
+                {
+                    if (settings != NULL)
+                    {
+                        // Add the suppressions.
+                        for (size_t j(0); j < suppressionIDs.size(); ++j)
+                        {
+                            const std::string errmsg(settings->nomsg.addSuppression(suppressionIDs[j], filename, lineno));
+                            if (!errmsg.empty())
+                            {
+                                writeError(filename, lineno, _errorLogger, "cppcheckError", errmsg);
+                            }
+                        }
+                    }
+                    suppressionIDs.clear();
+                }
+            }
+
+            // String or char constants..
+            if (ch == '\"' || ch == '\'')
+            {
+                code << char(ch);
+                char chNext;
+                do
                 {
                     ++i;
-                    char chSeq = str[i];
-                    if (chSeq == '\n')
-                        ++newlines;
+                    chNext = str[i];
+                    if (chNext == '\\')
+                    {
+                        ++i;
+                        char chSeq = str[i];
+                        if (chSeq == '\n')
+                            ++newlines;
+                        else
+                        {
+                            code << chNext;
+                            code << chSeq;
+                            previous = static_cast<unsigned char>(chSeq);
+                        }
+                    }
                     else
                     {
                         code << chNext;
-                        code << chSeq;
-                        previous = static_cast<unsigned char>(chSeq);
+                        previous = static_cast<unsigned char>(chNext);
                     }
                 }
+                while (i < str.length() && chNext != ch && chNext != '\n');
+            }
+
+            // Rawstring..
+            else if (str.compare(i,2,"R\"")==0)
+            {
+                std::string delim;
+                for (std::string::size_type i2 = i+2; i2 < str.length(); ++i2)
+                {
+                    if (i2 > 16 ||
+                        std::isspace(str[i2]) ||
+                        std::iscntrl(str[i2]) ||
+                        str[i2] == ')' ||
+                        str[i2] == '\\')
+                    {
+                        delim = " ";
+                        break;
+                    }
+                    else if (str[i2] == '(')
+                        break;
+
+                    delim += str[i2];
+                }
+                const std::string::size_type endpos = str.find(")" + delim + "\"", i);
+                if (delim != " " && endpos != std::string::npos)
+                {
+                    unsigned int rawstringnewlines = 0;
+                    code << '\"';
+                    for (std::string::size_type p = i + 3 + delim.size(); p < endpos; ++p)
+                    {
+                        if (str[p] == '\n')
+                        {
+                            rawstringnewlines++;
+                            code << "\\n";
+                        }
+                        else if (std::iscntrl((unsigned char)str[p]) ||
+                                 std::isspace((unsigned char)str[p]))
+                        {
+                            code << " ";
+                        }
+                        else if (str[p] == '\\')
+                        {
+                            code << "\\";
+                        }
+                        else if (str[p] == '\"' || str[p] == '\'')
+                        {
+                            code << "\\" << (char)str[p];
+                        }
+                        else
+                        {
+                            code << (char)str[p];
+                        }
+                    }
+                    code << "\"";
+                    if (rawstringnewlines > 0)
+                        code << std::string(rawstringnewlines, '\n');
+                    i = endpos + delim.size() + 2;
+                }
                 else
                 {
-                    code << chNext;
-                    previous = static_cast<unsigned char>(chNext);
+                    code << "R";
+                    previous = 'R';
                 }
             }
-            while (i < str.length() && chNext != ch && chNext != '\n');
-        }
-
-        // Rawstring..
-        else if (str.compare(i,2,"R\"")==0)
-        {
-            std::string delim;
-            for (std::string::size_type i2 = i+2; i2 < str.length(); ++i2)
-            {
-                if (i2 > 16 ||
-                    std::isspace(str[i2]) ||
-                    std::iscntrl(str[i2]) ||
-                    str[i2] == ')' ||
-                    str[i2] == '\\')
-                {
-                    delim = " ";
-                    break;
-                }
-                else if (str[i2] == '(')
-                    break;
-
-                delim += str[i2];
-            }
-            const std::string::size_type endpos = str.find(")" + delim + "\"", i);
-            if (delim != " " && endpos != std::string::npos)
-            {
-                unsigned int rawstringnewlines = 0;
-                code << '\"';
-                for (std::string::size_type p = i + 3 + delim.size(); p < endpos; ++p)
-                {
-                    if (str[p] == '\n')
-                    {
-                        rawstringnewlines++;
-                        code << "\\n";
-                    }
-                    else if (std::iscntrl((unsigned char)str[p]) ||
-                             std::isspace((unsigned char)str[p]))
-                    {
-                        code << " ";
-                    }
-                    else if (str[p] == '\\')
-                    {
-                        code << "\\";
-                    }
-                    else if (str[p] == '\"' || str[p] == '\'')
-                    {
-                        code << "\\" << (char)str[p];
-                    }
-                    else
-                    {
-                        code << (char)str[p];
-                    }
-                }
-                code << "\"";
-                if (rawstringnewlines > 0)
-                    code << std::string(rawstringnewlines, '\n');
-                i = endpos + delim.size() + 2;
-            }
-            else
-            {
-                code << "R";
-                previous = 'R';
-            }
-        }
-
-        // Just some code..
-        else
-        {
-            if (ch == ' ' && previous == ' ')
-            {
-                // Skip double white space
-            }
             else
             {
                 code << char(ch);
                 previous = ch;
             }
-
-
-            // if there has been <backspace><newline> sequences, add extra newlines..
-            if (ch == '\n')
-            {
-                ++lineno;
-                if (newlines > 0)
-                {
-                    code << std::string(newlines, '\n');
-                    newlines = 0;
-                    previous = '\n';
-                }
-            }
         }
     }
 
     return code.str();
 }
 
+std::string Preprocessor::removeIf0(const std::string &code)
+{
+    std::ostringstream ret;
+    std::istringstream istr(code);
+    std::string line;
+    while (std::getline(istr,line))
+    {
+        if (line != "#if 0")
+            ret << line << "\n";
+        else
+        {
+            // replace '#if 0' with empty line
+            ret << line << "\n";
 
-std::string Preprocessor::removeParantheses(const std::string &str)
+            // goto the end of the '#if 0' block
+            unsigned int level = 1;
+            bool in = false;
+            while (level > 0 && std::getline(istr,line))
+            {
+                if (line.compare(0,3,"#if") == 0)
+                    ++level;
+                else if (line == "#endif")
+                    --level;
+                else if (line == "#else")
+                {
+                    if (level == 1)
+                        in = true;
+                }
+                else
+                {
+                    if (in)
+                        ret << line << "\n";
+                    else
+                        // replace code within '#if 0' block with empty lines
+                        ret << "\n";
+                    continue;
+                }
+
+                ret << line << "\n";
+            }
+        }
+    }
+    return ret.str();
+}
+
+
+std::string Preprocessor::removeParentheses(const std::string &str)
 {
     if (str.find("\n#if") == std::string::npos && str.compare(0, 3, "#if") != 0)
         return str;
@@ -454,7 +709,7 @@ std::string Preprocessor::removeParantheses(const std::string &str)
             while ((pos = line.find(") ", pos)) != std::string::npos)
                 line.erase(pos + 1, 1);
 
-            // Remove inner paranthesis "((..))"..
+            // Remove inner parenthesis "((..))"..
             pos = 0;
             while ((pos = line.find("((", pos)) != std::string::npos)
             {
@@ -560,6 +815,37 @@ void Preprocessor::removeAsm(std::string &str)
     pos = 0;
     while ((pos = str.find("\nasm __volatile (", pos)) != std::string::npos)
         _removeAsm(str, pos);
+
+    pos = 0;
+    while ((pos = str.find("#asm\n", pos)) != std::string::npos)
+    {
+        const std::string::size_type pos1 = pos;
+        ++pos;
+
+        if (pos1 > 0 && str[pos1-1] != '\n')
+            continue;
+
+        const std::string::size_type endpos = str.find("\n#endasm", pos1);
+        if (endpos != std::string::npos)
+        {
+            if (endpos + 8U < str.size() && str[endpos+8U] != '\n')
+                break;
+
+            // Remove '#endasm'
+            str.erase(endpos+1, 7);
+
+            // Remove non-newline characters between pos1 and endpos
+            for (std::string::size_type p = endpos; p > pos1; --p)
+            {
+                if (str[p] != '\n')
+                    str.erase(p,1);
+            }
+            str.erase(pos1,1);
+
+            // Insert 'asm();' to make the checks bailout properly
+            str.insert(pos1, ";asm();");
+        }
+    }
 }
 
 
@@ -668,9 +954,6 @@ void Preprocessor::preprocess(std::istream &srcCodeStream, std::string &processe
 
     processedFile = read(srcCodeStream, filename, _settings);
 
-    // normalize the whitespaces of the file
-    preprocessWhitespaces(processedFile);
-
     // Remove asm(...)
     removeAsm(processedFile);
 
@@ -810,7 +1093,18 @@ std::list<std::string> Preprocessor::getcfgs(const std::string &filedata, const
 
         if (line.compare(0, 8, "#define ") == 0)
         {
-            if (line.find(" ", 8) == std::string::npos)
+            bool valid = true;
+            for (std::string::size_type pos = 8; pos < line.size() && line[pos] != ' '; ++pos)
+            {
+                char ch = line[pos];
+                if (ch=='_' || (ch>='a' && ch<='z') || (ch>='A' && ch<='Z') || (pos>8 && ch>='0' && ch<='9'))
+                    continue;
+                valid = false;
+                break;
+            }
+            if (!valid)
+                line.clear();
+            else if (line.find(" ", 8) == std::string::npos)
                 defines.insert(line.substr(8));
             else
             {
@@ -823,7 +1117,7 @@ std::list<std::string> Preprocessor::getcfgs(const std::string &filedata, const
         if (!line.empty() && line.compare(0, 3, "#if") != 0)
             includeguard = false;
 
-        if (line[0] != '#')
+        if (line.empty() || line[0] != '#')
             continue;
 
         if (includeguard)
@@ -908,6 +1202,8 @@ std::list<std::string> Preprocessor::getcfgs(const std::string &filedata, const
                         def += ";";
                     def += *it;
                 }
+
+                /* TODO: Fix TestPreprocessor::test7e (#2552)
                 else
                 {
                     std::ostringstream lineStream;
@@ -918,11 +1214,12 @@ std::list<std::string> Preprocessor::getcfgs(const std::string &filedata, const
                     loc.setfile(filename);
                     loc.line = linenr;
                     errmsg._callStack.push_back(loc);
-                    errmsg._severity = Severity::fromString("error");
+                    errmsg._severity = Severity::error;
                     errmsg.setmsg(*it+" is already guaranteed to be defined");
                     errmsg._id  = "preprocessor" + lineStream.str();
                     _errorLogger->reportErr(errmsg);
                 }
+                */
             }
             if (from_negation)
             {
@@ -1133,7 +1430,7 @@ std::list<std::string> Preprocessor::getcfgs(const std::string &filedata, const
             if (_errorLogger && _settings && _settings->debugwarnings)
             {
                 std::list<ErrorLogger::ErrorMessage::FileLocation> locationList;
-                const ErrorLogger::ErrorMessage errmsg(locationList, Severity::debug, "unhandled configuration: " + *it, "debug");
+                const ErrorLogger::ErrorMessage errmsg(locationList, Severity::debug, "unhandled configuration: " + *it, "debug", false);
                 _errorLogger->reportErr(errmsg);
             }
 
@@ -1158,8 +1455,12 @@ void Preprocessor::simplifyCondition(const std::map<std::string, std::string> &v
 
     if (Token::Match(tokenizer.tokens(), "( %var% )"))
     {
-        if (variables.find(tokenizer.tokens()->strAt(1)) != variables.end())
-            condition = "1";
+        std::map<std::string,std::string>::const_iterator var = variables.find(tokenizer.tokens()->strAt(1));
+        if (var != variables.end())
+        {
+            const std::string &value = (*var).second;
+            condition = (value == "0") ? "0" : "1";
+        }
         else if (match)
             condition = "0";
         return;
@@ -1210,9 +1511,35 @@ void Preprocessor::simplifyCondition(const std::map<std::string, std::string> &v
         if (it != variables.end())
         {
             if (!it->second.empty())
-                tok->str(it->second);
-            else if ((!tok->previous() || tok->strAt(-1) == "||" || tok->strAt(-1) == "&&" || tok->strAt(-1) == "(") &&
-                     (!tok->next() || tok->strAt(1) == "||" || tok->strAt(1) == "&&" || tok->strAt(1) == ")"))
+            {
+                // Tokenize the value
+                Tokenizer tokenizer2(&settings,NULL);
+                std::istringstream istr2(it->second);
+                tokenizer2.tokenize(istr2,"","",true);
+
+                // Copy the value tokens
+                std::stack<Token *> link;
+                for (const Token *tok2 = tokenizer2.tokens(); tok2; tok2 = tok2->next())
+                {
+                    tok->str(tok2->str());
+
+                    if (Token::Match(tok2,"[{([]"))
+                        link.push(tok);
+                    else if (!link.empty() && Token::Match(tok2,"[})]]"))
+                    {
+                        Token::createMutualLinks(link.top(), tok);
+                        link.pop();
+                    }
+
+                    if (tok2->next())
+                    {
+                        tok->insertToken("");
+                        tok = tok->next();
+                    }
+                }
+            }
+            else if ((!tok->previous() || Token::Match(tok->previous(), "&&|%oror%|(")) &&
+                     (!tok->next() || Token::Match(tok->next(), "&&|%oror%|)")))
                 tok->str("1");
             else
                 tok->deleteThis();
@@ -1238,7 +1565,7 @@ void Preprocessor::simplifyCondition(const std::map<std::string, std::string> &v
 
     for (Token *tok = const_cast<Token *>(tokenizer.tokens()); tok; tok = tok->next())
     {
-        while ((tok->str() == "(" || tok->str() == "||") && (Token::simpleMatch(tok->tokAt(2), "|| 1")))
+        while (Token::Match(tok, "(|%oror% %any% %oror% 1"))
         {
             tok->deleteNext();
             tok->deleteNext();
@@ -1457,7 +1784,8 @@ std::string Preprocessor::getcode(const std::string &filedata, std::string cfg,
             return "";
         }
 
-        if (!match && line.compare(0, 8, "#define ") == 0)
+        if (!match && (line.compare(0, 8, "#define ") == 0 ||
+                       line.compare(0, 6, "#undef") == 0))
         {
             // Remove define that is not part of this configuration
             line = "";
@@ -1497,7 +1825,8 @@ void Preprocessor::error(const std::string &filename, unsigned int linenr, const
     _errorLogger->reportErr(ErrorLogger::ErrorMessage(locationList,
                             Severity::error,
                             msg,
-                            "preprocessorErrorDirective"));
+                            "preprocessorErrorDirective",
+                            false));
 }
 
 Preprocessor::HeaderTypes Preprocessor::getHeaderFileName(std::string &str)
@@ -1533,14 +1862,6 @@ Preprocessor::HeaderTypes Preprocessor::getHeaderFileName(std::string &str)
 }
 
 
-// This wrapper exists because Sun's CC does not allow a static_cast
-// from extern "C" int(*)(int) to int(*)(int).
-static int tolowerWrapper(int c)
-{
-    return std::tolower(c);
-}
-
-
 void Preprocessor::handleIncludes(std::string &code, const std::string &filePath, const std::list<std::string> &includePaths)
 {
     std::list<std::string> paths;
@@ -1632,15 +1953,7 @@ void Preprocessor::handleIncludes(std::string &code, const std::string &filePath
 
         if (!processedFile.empty())
         {
-            // Replace all tabs with spaces..
-            std::replace(processedFile.begin(), processedFile.end(), '\t', ' ');
-
-            // Remove all indentation..
-            if (!processedFile.empty() && processedFile[0] == ' ')
-                processedFile.erase(0, processedFile.find_first_not_of(" "));
-
             // Remove space characters that are after or before new line character
-            processedFile = removeSpaceNearNL(processedFile);
             processedFile = "#file \"" + filename + "\"\n" + processedFile + "\n#endfile";
             code.insert(pos, processedFile);
 
@@ -1648,20 +1961,16 @@ void Preprocessor::handleIncludes(std::string &code, const std::string &filePath
             path.erase(1 + path.find_last_of("\\/"));
             paths.push_back(path);
         }
-        else if (!fileOpened)
+        else if (!fileOpened && _settings && (headerType == UserHeader || _settings->debugwarnings))
         {
-            // TODO: Fix the handling of system includes and then
-            // remove the "headerType == UserHeader"
-#ifdef NDEBUG
-            if (headerType == UserHeader && _errorLogger && _settings && _settings->isEnabled("missingInclude"))
-#else
-            if (_errorLogger && _settings && _settings->isEnabled("missingInclude"))
-#endif
+            missingIncludeFlag = true;
+
+            if (_errorLogger && _settings->checkConfiguration)
             {
                 std::string f = filePath;
 
                 // Determine line number of include
-                unsigned int linenr = 0;
+                unsigned int linenr = 1;
                 unsigned int level = 0;
                 for (std::string::size_type p = 1; p <= pos; ++p)
                 {
@@ -1675,6 +1984,7 @@ void Preprocessor::handleIncludes(std::string &code, const std::string &filePath
                     {
                         if (level == 0)
                         {
+                            linenr--;
                             const std::string::size_type pos1 = pos - p + 7;
                             const std::string::size_type pos2 = code.find_first_of("\"\n", pos1);
                             f = code.substr(pos1, (pos2 == std::string::npos) ? pos2 : (pos2 - pos1));
@@ -1684,10 +1994,13 @@ void Preprocessor::handleIncludes(std::string &code, const std::string &filePath
                     }
                 }
 
-                missingInclude(Path::toNativeSeparators(f),
-                               linenr,
-                               filename,
-                               headerType == UserHeader);
+                if (!_settings->nomsg.isSuppressed("missingInclude", f, linenr))
+                {
+                    missingInclude(Path::toNativeSeparators(f),
+                                   linenr,
+                                   filename,
+                                   headerType == UserHeader);
+                }
             }
         }
     }
@@ -1709,7 +2022,7 @@ void Preprocessor::missingInclude(const std::string &filename, unsigned int line
     // currently a debug-message.
     const Severity::SeverityType severity = userheader ? Severity::information : Severity::debug;
     const std::string id = userheader ? "missingInclude" : "debug";
-    ErrorLogger::ErrorMessage errmsg(locationList, severity, "Include file: \"" + header + "\" not found.", id);
+    ErrorLogger::ErrorMessage errmsg(locationList, severity, "Include file: \"" + header + "\" not found.", id, false);
     errmsg.file0 = file0;
     _errorLogger->reportErr(errmsg);
 }
@@ -2045,12 +2358,14 @@ public:
 
         else if (_params.empty())
         {
-            std::string::size_type pos = _macro.find(" ");
+            std::string::size_type pos = _macro.find_first_of(" \"");
             if (pos == std::string::npos)
                 macrocode = "";
             else
             {
-                macrocode = _macro.substr(pos + 1);
+                if (_macro[pos] == ' ')
+                    pos++;
+                macrocode = _macro.substr(pos);
                 if ((pos = macrocode.find_first_of("\r\n")) != std::string::npos)
                     macrocode.erase(pos);
             }
@@ -2122,14 +2437,17 @@ public:
                         }
 
                         // expand nopar macro
-                        const std::map<std::string, PreprocessorMacro *>::const_iterator it = macros.find(str);
-                        if (it != macros.end() && it->second->_macro.find("(") == std::string::npos)
+                        if (tok->strAt(-1) != "##")
                         {
-                            str = it->second->_macro;
-                            if (str.find(" ") != std::string::npos)
-                                str.erase(0, str.find(" "));
-                            else
-                                str = "";
+                            const std::map<std::string, PreprocessorMacro *>::const_iterator it = macros.find(str);
+                            if (it != macros.end() && it->second->_macro.find("(") == std::string::npos)
+                            {
+                                str = it->second->_macro;
+                                if (str.find(" ") != std::string::npos)
+                                    str.erase(0, str.find(" "));
+                                else
+                                    str = "";
+                            }
                         }
                     }
                     if (_variadic && tok->str() == "," && tok->next() && tok->next()->str() == "##")
