@@ -53,6 +53,8 @@ public:
 
     Preprocessor(Settings *settings = 0, ErrorLogger *errorLogger = 0);
 
+    static bool missingIncludeFlag;
+
     /**
      * Extract the code for each configuration
      * @param istr The (file/string) stream to read from.
@@ -106,7 +108,6 @@ public:
      * @param processedFile The data to be processed
      */
     static void preprocessWhitespaces(std::string &processedFile);
-
 protected:
 
     /**
@@ -145,12 +146,25 @@ protected:
      */
     std::string removeComments(const std::string &str, const std::string &filename, Settings *settings);
 
+    /**
+     * Cleanup 'if 0' from the code
+     * @param code Code processed by read().
+     * @return code without 'if 0'
+     */
+    static std::string removeIf0(const std::string &code);
+
     /**
      * Remove redundant parentheses from preprocessor commands. This should only be called from read().
      * @param str Code processed by read().
      * @return code with reduced parentheses
      */
-    static std::string removeParantheses(const std::string &str);
+    static std::string removeParentheses(const std::string &str);
+
+    /**
+     * clean up #-preprocessor lines (only)
+     * @param processedFile The data to be processed
+     */
+    std::string preprocessCleanupDirectives(const std::string &processedFile) const;
 
     /**
      * Returns the string between double quote characters or \< \> characters.
