@@ -23,6 +23,7 @@
 #include <string>
 #include <istream>
 #include <map>
+#include <set>
 
 /// @addtogroup Core
 /// @{
@@ -54,9 +55,17 @@ public:
     /** @brief Is --debug-warnings given? */
     bool debugwarnings;
 
-    /** @brief Inconclusive checks - for debugging of Cppcheck */
+    /** @brief Inconclusive checks */
     bool inconclusive;
 
+    /**
+     * When this flag is false (default) then experimental
+     * heuristics and checks are disabled.
+     *
+     * It should not be possible to enable this from any client.
+     */
+    bool experimental;
+
     /** @brief Is --style given? */
     bool _checkCodingStyle;
 
@@ -135,8 +144,51 @@ public:
     class Suppressions
     {
     private:
+        class FileMatcher
+        {
+            friend class Suppressions;
+        private:
+            /** @brief List of filenames suppressed, bool flag indicates whether suppression matched. */
+            std::map<std::string, std::map<unsigned int, bool> > _files;
+            /** @brief List of globs suppressed, bool flag indicates whether suppression matched. */
+            std::map<std::string, std::map<unsigned int, bool> > _globs;
+
+            /**
+             * @brief Match a name against a glob pattern.
+             * @param pattern The glob pattern to match.
+             * @param name The filename to match against the glob pattern.
+             * @return match success
+             */
+            static bool match(const std::string &pattern, const std::string &name);
+
+        public:
+            /**
+             * @brief Add a file or glob (and line number).
+             * @param name File name or glob pattern
+             * @param line Line number
+             * @return error message. empty upon success
+             */
+            std::string addFile(const std::string &name, unsigned int line);
+
+            /**
+             * @brief Returns true if the file name matches a previously added file or glob pattern.
+             * @param file File name to check
+             * @param line Line number
+             * @return true if this filename/line matches
+             */
+            bool isSuppressed(const std::string &file, unsigned int line);
+
+            /**
+             * @brief Returns true if the file name matches a previously added file (only, not glob pattern).
+             * @param file File name to check
+             * @param line Line number
+             * @return true if this filename/line matches
+             */
+            bool isSuppressedLocal(const std::string &file, unsigned int line);
+        };
+
         /** @brief List of error which the user doesn't want to see. */
-        std::map<std::string, std::map<std::string, std::list<unsigned int> > > _suppressions;
+        std::map<std::string, FileMatcher> _suppressions;
     public:
         /**
          * @brief Don't show errors listed in the file.
@@ -145,6 +197,13 @@ public:
          */
         std::string parseFile(std::istream &istr);
 
+        /**
+         * @brief Don't show the given error.
+         * @param line Description of error to suppress (in id:file:line format).
+         * @return error message. empty upon success
+         */
+        std::string addSuppressionLine(const std::string &line);
+
         /**
          * @brief Don't show this error. If file and/or line are optional. In which case
          * the errorId alone is used for filtering.
@@ -163,6 +222,38 @@ public:
          * @return true if this error is suppressed.
          */
         bool isSuppressed(const std::string &errorId, const std::string &file, unsigned int line);
+
+        /**
+         * @brief Returns true if this message should not be shown to the user (explicit files only, not glob patterns).
+         * @param errorId the id for the error, e.g. "arrayIndexOutOfBounds"
+         * @param file File name with the path, e.g. "src/main.cpp"
+         * @param line number, e.g. "123"
+         * @return true if this error is suppressed.
+         */
+        bool isSuppressedLocal(const std::string &errorId, const std::string &file, unsigned int line);
+
+        struct SuppressionEntry
+        {
+            SuppressionEntry(const std::string &aid, const std::string &afile, const unsigned int &aline)
+                : id(aid), file(afile), line(aline)
+            { }
+
+            std::string id;
+            std::string file;
+            unsigned int line;
+        };
+
+        /**
+         * @brief Returns list of unmatched local (per-file) suppressions.
+         * @return list of unmatched suppressions
+         */
+        std::list<SuppressionEntry> getUnmatchedLocalSuppressions(const std::string &file) const;
+
+        /**
+         * @brief Returns list of unmatched global (glob pattern) suppressions.
+         * @return list of unmatched suppressions
+         */
+        std::list<SuppressionEntry> getUnmatchedGlobalSuppressions() const;
     };
 
     /** @brief suppress message (--suppressions) */
@@ -209,6 +300,9 @@ public:
      * @brief Extra rules
      */
     std::list<Rule> rules;
+
+    /** Is the 'configuration checking' wanted? */
+    bool checkConfiguration;
 };
 
 /// @}
