@@ -57,19 +57,22 @@ void Token::str(const std::string &s)
 {
     _str = s;
 
-    _isName = bool(_str[0] == '_' || std::isalpha(_str[0]));
+    if (!_str.empty())
+    {
+        _isName = bool(_str[0] == '_' || std::isalpha(_str[0]));
 
-    if (std::isdigit(_str[0]))
-        _isNumber = true;
-    else if (_str.length() > 1 && _str[0] == '-' && std::isdigit(_str[1]))
-        _isNumber = true;
-    else
-        _isNumber = false;
+        if (std::isdigit(_str[0]))
+            _isNumber = true;
+        else if (_str.length() > 1 && _str[0] == '-' && std::isdigit(_str[1]))
+            _isNumber = true;
+        else
+            _isNumber = false;
 
-    if (_str == "true" || _str == "false")
-        _isBoolean = true;
-    else
-        _isBoolean = false;
+        if (_str == "true" || _str == "false")
+            _isBoolean = true;
+        else
+            _isBoolean = false;
+    }
 
     _varId = 0;
 }
@@ -107,6 +110,9 @@ void Token::deleteThis()
         _isName = _next->_isName;
         _isNumber = _next->_isNumber;
         _isBoolean = _next->_isBoolean;
+        _isUnsigned = _next->_isUnsigned;
+        _isSigned = _next->_isSigned;
+        _isLong = _next->_isLong;
         _isUnused = _next->_isUnused;
         _varId = _next->_varId;
         _fileIndex = _next->_fileIndex;
@@ -197,8 +203,52 @@ std::string Token::strAt(int index) const
     return tok ? tok->_str.c_str() : "";
 }
 
+static bool strisop(const char str[])
+{
+    if (str[1] == 0)
+    {
+        if (strchr("+-*/%&|^~!<>", *str))
+            return true;
+    }
+    else if (str[2] == 0)
+    {
+        if (strcmp(str, "&&")==0 ||
+            strcmp(str, "||")==0 ||
+            strcmp(str, "==")==0 ||
+            strcmp(str, "!=")==0 ||
+            strcmp(str, ">=")==0 ||
+            strcmp(str, "<=")==0 ||
+            strcmp(str, ">>")==0 ||
+            strcmp(str, "<<")==0)
+            return true;
+    }
+    return false;
+}
+
 int Token::multiCompare(const char *haystack, const char *needle)
 {
+    if (haystack[0] == '%' && haystack[1] != '|')
+    {
+        if (strncmp(haystack, "%op%|", 5) == 0)
+        {
+            haystack = haystack + 5;
+            if (strisop(needle))
+                return 1;
+        }
+        else if (strncmp(haystack, "%or%|", 5) == 0)
+        {
+            haystack = haystack + 5;
+            if (*needle == '|')
+                return 1;
+        }
+        else if (strncmp(haystack, "%oror%|", 7) == 0)
+        {
+            haystack = haystack + 7;
+            if (needle[0] == '|' && needle[1] == '|')
+                return 1;
+        }
+    }
+
     bool emptyStringFound = false;
     const char *needlePointer = needle;
     while (true)
@@ -251,6 +301,35 @@ int Token::multiCompare(const char *haystack, const char *needle)
             }
 
             ++haystack;
+
+            if (haystack[0] == '%' && haystack[1] != '|')
+            {
+                if (strncmp(haystack, "%op%", 4) == 0)
+                {
+                    if (strisop(needle))
+                        return 1;
+                    haystack = haystack + 4;
+                }
+                else if (strncmp(haystack, "%or%", 4) == 0)
+                {
+                    if (*needle == '|')
+                        return 1;
+                    haystack = haystack + 4;
+                }
+                else if (strncmp(haystack, "%oror%", 6) == 0)
+                {
+                    if (needle[0] == '|' && needle[1] == '|')
+                        return 1;
+                    haystack = haystack + 6;
+                }
+
+                if (*haystack == '|')
+                    haystack++;
+                else if (*haystack == ' ' || *haystack == '\0')
+                    return emptyStringFound ? 0 : -1;
+                else
+                    return -1;
+            }
         }
     }
 
@@ -381,21 +460,45 @@ bool Token::Match(const Token *tok, const char pattern[], unsigned int varid)
 
         // Compare the first character of the string for optimization reasons
         // before doing more detailed checks.
+        bool patternUnderstood = false;
         if (p[0] == '%')
         {
-            // TODO: %var% should match only for
-            // variables that have varId != 0, but that needs a lot of
-            // work, before that change can be made.
-            // Any symbolname..
-            if (firstWordEquals(p, "%var%") == 0)
+            switch (p[1])
             {
-                if (!tok->isName())
-                    return false;
-                p += 5;
-            }
+            case 'v':
+                // TODO: %var% should match only for
+                // variables that have varId != 0, but that needs a lot of
+                // work, before that change can be made.
+                // Any symbolname..
+                if (p[4] == '%') // %var%
+                {
+                    if (!tok->isName())
+                        return false;
+                    p += 5;
+                    patternUnderstood = true;
+                }
+                else // %varid%
+                {
+                    if (varid == 0)
+                    {
+                        std::list<ErrorLogger::ErrorMessage::FileLocation> locationList;
+                        const ErrorLogger::ErrorMessage errmsg(locationList,
+                                                               Severity::error,
+                                                               "Internal error. Token::Match called with varid 0.",
+                                                               "cppcheckError",
+                                                               false);
+                        Check::reportError(errmsg);
+                    }
 
-            // Type..
-            else if (firstWordEquals(p, "%type%") == 0)
+                    if (tok->varId() != varid)
+                        return false;
+
+                    p += 7;
+                    patternUnderstood = true;
+                }
+                break;
+            case 't':
+                // Type (%type%)
             {
                 if (!tok->isName())
                     return false;
@@ -407,73 +510,106 @@ bool Token::Match(const Token *tok, const char pattern[], unsigned int varid)
                     return false;
 
                 p += 6;
+                patternUnderstood = true;
             }
-
-            // Accept any token
-            else if (firstWordEquals(p, "%any%") == 0)
+            break;
+            case 'a':
+                // Accept any token (%any%)
             {
                 p += 5;
+                patternUnderstood = true;
             }
-
-            else if (firstWordEquals(p, "%varid%") == 0)
-            {
-                if (varid == 0)
-                {
-                    std::list<ErrorLogger::ErrorMessage::FileLocation> locationList;
-                    const ErrorLogger::ErrorMessage errmsg(locationList,
-                                                           Severity::error,
-                                                           "Internal error. Token::Match called with varid 0.",
-                                                           "cppcheckError");
-                    Check::reportError(errmsg);
-                }
-
-                if (tok->varId() != varid)
-                    return false;
-
-                p += 7;
-            }
-
-            else if (firstWordEquals(p, "%num%") == 0)
+            break;
+            case 'n':
+                // Number (%num)
             {
                 if (!tok->isNumber())
                     return false;
                 p += 5;
+                patternUnderstood = true;
             }
-
-            else if (firstWordEquals(p, "%bool%") == 0)
-            {
-                if (!tok->isBoolean())
-                    return false;
-                p += 6;
-            }
-
-            else if (firstWordEquals(p, "%str%") == 0)
+            break;
+            case 's':
+                // String (%str%)
             {
                 if (tok->_str[0] != '\"')
                     return false;
                 p += 5;
+                patternUnderstood = true;
             }
-
-            else if (firstWordEquals(p, "%or%") == 0)
+            break;
+            case 'b':
+                // Bool (%bool%)
             {
-                if (tok->str() != "|")
-                    return false;
-                p += 4;
-            }
-
-            else if (firstWordEquals(p, "%oror%") == 0)
-            {
-                if (tok->str() != "||")
+                if (!tok->isBoolean())
                     return false;
                 p += 6;
+                patternUnderstood = true;
+            }
+            break;
+            case 'o':
+                // Or (%or%) and Op (%op%)
+                if (p[3] == '%')
+                {
+                    patternUnderstood = true;
+
+                    // multicompare..
+                    if (p[4] == '|')
+                    {
+                        int result = multiCompare(p, tok->str().c_str());
+                        if (result == -1)
+                            return false;   // No match
+                    }
+
+                    // single compare..
+                    else if (p[2] == 'r')
+                    {
+                        if (tok->str() != "|")
+                            return false;
+                    }
+                    else if (p[3] == 'p')
+                    {
+                        if (!tok->isOp())
+                            return false;
+                    }
+                    else
+                        patternUnderstood = false;
+                }
+
+                // Oror (%oror%)
+                else
+                {
+                    // multicompare..
+                    if (p[5] == '|')
+                    {
+                        int result = multiCompare(p, tok->str().c_str());
+                        if (result == -1)
+                            return false;   // No match
+                    }
+
+                    // single compare..
+                    if (tok->str() != "||")
+                        return false;
+
+                    patternUnderstood = true;
+                }
+
+                if (patternUnderstood)
+                {
+                    while (*p && *p != ' ')
+                        p++;
+                }
+                break;
+            default:
+                if (firstWordEquals(p, tok->_str.c_str()))
+                {
+                    p += tok->_str.length();
+                    patternUnderstood = true;
+                }
+                break;
             }
 
-            else if (firstWordEquals(p, tok->_str.c_str()))
-            {
-                p += tok->_str.length();
-            }
-
-            else
+            if (!patternUnderstood)
             {
                 return false;
             }
