@@ -24,7 +24,9 @@
 
 #include <string>
 #include <map>
+#include <list>
 #include <vector>
+#include <set>
 
 class Token;
 class ErrorLogger;
@@ -112,6 +114,11 @@ public:
      */
     static void deleteTokens(Token *tok);
 
+    /**
+     * Simplify '* & %any% =' to '%any% ='
+     */
+    void simplifyMulAnd(void);
+
     /**
      * Get parameter name of function
      * @param ftok The token for the function name in a function
@@ -251,7 +258,8 @@ public:
 
     /**
      * simplify if-not NULL
-     * - "if(0!=x);" => "if(x);"
+     * Example: "if(0!=x);" => "if(x);"
+     * Special case: 'x = (0 != x);' is removed.
      */
     void simplifyIfNotNull();
 
@@ -276,8 +284,9 @@ public:
     void simplifyComma();
 
     /** Add braces to an if-block
+     * @return true if no syntax errors
      */
-    void simplifyIfAddBraces();
+    bool simplifyIfAddBraces();
 
     /**
      * Add braces to an do-while block
@@ -308,6 +317,18 @@ public:
      */
     bool simplifyKnownVariables();
 
+    /**
+     * Utility function for simplifyKnownVariables. Get data about an
+     * assigned variable.
+     */
+    bool simplifyKnownVariablesGetData(unsigned int varid, Token **_tok2, Token **_tok3, std::string &value, unsigned int &valueVarId, bool &valueIsPointer, bool floatvar);
+
+    /**
+     * utility function for simplifyKnownVariables. Perform simplification
+     * of a given variable
+     */
+    bool simplifyKnownVariablesSimplify(Token **tok2, Token *tok3, unsigned int varid, const std::string &structname, std::string &value, unsigned int valueVarId, bool valueIsPointer, const Token * const valueToken, int indentlevel);
+
     /** Replace a "goto" with the statements */
     void simplifyGoto();
 
@@ -367,7 +388,7 @@ public:
      * @return true if modifications to token-list are done.
      *         false if no modifications are done.
      */
-    bool simplifyRedundantParanthesis();
+    bool simplifyRedundantParenthesis();
 
     /** Simplify references */
     void simplifyReference();
@@ -383,6 +404,43 @@ public:
      */
     void simplifyTemplates();
 
+    /**
+     * Expand specialized templates : "template<>.."
+     * @return names of expanded templates
+     */
+    std::set<std::string> simplifyTemplatesExpandSpecialized();
+
+    /**
+     * Get template declarations
+     * @return list of template declarations
+     */
+    std::list<Token *> simplifyTemplatesGetTemplateDeclarations();
+
+    /**
+     * Get template instantiations
+     * @return list of template instantiations
+     */
+    std::list<Token *> simplifyTemplatesGetTemplateInstantiations();
+
+    /**
+     * simplify template instantiations (use default argument values)
+     * @param templates list of template declarations
+     * @param instantiations list of template instantiations
+     */
+    void simplifyTemplatesUseDefaultArgumentValues(const std::list<Token *> &templates,
+            const std::list<Token *> &instantiations);
+
+    /**
+     * Simplify templates : expand all instantiatiations for a template
+     * @todo It seems that inner templates should be instantiated recursively
+     * @param tok token where the template declaration begins
+     * @param used a list of template usages (not necessarily just for this template)
+     * @param expandedtemplates all templates that has been expanded so far. The full names are stored.
+     */
+    void simplifyTemplatesInstantiate(const Token *tok,
+                                      std::list<Token *> &used,
+                                      std::set<std::string> &expandedtemplates);
+
     /**
      * Used after simplifyTemplates to perform a little cleanup.
      * Sometimes the simplifyTemplates isn't fully successful and then
@@ -450,6 +508,15 @@ public:
 
     void insertTokens(Token *dest, const Token *src, unsigned int n);
 
+    /**
+     * Copy tokens.
+     * @param dest destination token where copied tokens will be inserted after
+     * @param first first token to copy
+     * @param last last token to copy
+     * @return new location of last token copied
+     */
+    Token *copyTokens(Token *dest, const Token *first, const Token *last);
+
     /**
      * Send error message to error logger about internal bug.
      * @param tok the token that this bug concerns.
@@ -565,7 +632,7 @@ public:
      */
     void duplicateEnumError(const Token *tok1, const Token *tok2, const std::string & type);
 
-    bool duplicateTypedef(Token **tokPtr, const Token *name);
+    bool duplicateTypedef(Token **tokPtr, const Token *name, const Token *typeDef);
     void duplicateTypedefError(const Token *tok1, const Token *tok2, const std::string & type);
 
     /**
@@ -590,6 +657,15 @@ public:
 
     Token *deleteInvalidTypedef(Token *typeDef);
 
+    /**
+     * Get variable count.
+     * @return number of variables
+     */
+    unsigned int varIdCount() const
+    {
+        return _varId;
+    }
+
 private:
     /** Disable copy constructor, no implementation */
     Tokenizer(const Tokenizer &);
@@ -624,6 +700,9 @@ private:
 
     /** Symbol database that all checks etc can use */
     mutable SymbolDatabase *_symbolDatabase;
+
+    /** variable count */
+    unsigned int _varId;
 };
 
 /// @}
