@@ -36,13 +36,13 @@ private:
 
 
 
-    void check(const char code[], bool inconclusive = true)
+    void check(const char code[], bool experimental = true)
     {
         // Clear the error buffer..
         errout.str("");
 
         Settings settings;
-        settings.inconclusive = inconclusive;
+        settings.experimental = experimental;
         settings._checkCodingStyle = true;
 
         // Tokenize..
@@ -84,7 +84,6 @@ private:
         TEST_CASE(array_index_7);
         TEST_CASE(array_index_8);
         TEST_CASE(array_index_9);
-        TEST_CASE(array_index_10);
         TEST_CASE(array_index_11);
         TEST_CASE(array_index_12);
         TEST_CASE(array_index_13);
@@ -109,6 +108,7 @@ private:
         TEST_CASE(array_index_32);
         TEST_CASE(array_index_multidim);
         TEST_CASE(array_index_switch_in_for);
+        TEST_CASE(array_index_for_in_for);   // FP: #2634
         TEST_CASE(array_index_calculation);
         TEST_CASE(array_index_negative);
         TEST_CASE(array_index_for_decr);
@@ -116,6 +116,8 @@ private:
         TEST_CASE(array_index_for_break);  // FP: for,break
         TEST_CASE(array_index_for);        // FN: for,if
         TEST_CASE(array_index_for_neq);    // #2211: Using != in condition
+        TEST_CASE(array_index_for_question);	// #2561: for, ?:
+        TEST_CASE(array_index_extern);      // FP when using 'extern'. #1684
 
         TEST_CASE(buffer_overrun_1);
         TEST_CASE(buffer_overrun_2);
@@ -133,6 +135,9 @@ private:
         TEST_CASE(buffer_overrun_14);
         TEST_CASE(buffer_overrun_15); // ticket #1787
         TEST_CASE(buffer_overrun_16);
+        TEST_CASE(buffer_overrun_17); // ticket #2548
+        TEST_CASE(buffer_overrun_18); // ticket #2576 - for, calculation with loop variable
+        TEST_CASE(buffer_overrun_19); // #2597 - class member with unknown type
         TEST_CASE(buffer_overrun_bailoutIfSwitch);  // ticket #2378 : bailoutIfSwitch
 
         // It is undefined behaviour to point out of bounds of an array
@@ -194,7 +199,8 @@ private:
         TEST_CASE(terminateStrncpy3);
         TEST_CASE(recursive_long_time);
 
-        TEST_CASE(crash);	// Ticket #1587 - crash
+        TEST_CASE(crash1);	// Ticket #1587 - crash
+        TEST_CASE(crash2);  // Ticket #2607 - crash
 
         TEST_CASE(executionPaths1);
         TEST_CASE(executionPaths2);
@@ -206,6 +212,8 @@ private:
         TEST_CASE(scope);   // handling different scopes
 
         TEST_CASE(getErrorMessages);
+
+        TEST_CASE(unknownMacroNoDecl);    // #2638 - not variable declaration: 'AAA a[0] = 0;'
     }
 
 
@@ -595,27 +603,6 @@ private:
     }
 
 
-    void array_index_10()
-    {
-        check("struct ABC\n"
-              "{\n"
-              "    char str[10];\n"
-              "};\n"
-              "\n"
-              "static void memclr( char *data )\n"
-              "{\n"
-              "    data[10] = 0;\n"
-              "}\n"
-              "\n"
-              "static void f(struct ABC *abc)\n"
-              "{\n"
-              "    memclr(abc->str);\n"
-              "}\n");
-        TODO_ASSERT_EQUALS("[test.cpp:13] -> [test.cpp:8]: (possible error) Array index out of bounds\n",
-                           "", errout.str());
-    }
-
-
     void array_index_11()
     {
         check("class ABC\n"
@@ -868,27 +855,17 @@ private:
     void array_index_24()
     {
         // ticket #1492 and #1539
-        if (CHAR_MAX == SCHAR_MAX) // plain char is signed
-        {
-            check("void f(char n) {\n"
-                  "    int a[n];\n"     // n <= CHAR_MAX
-                  "    a[-1] = 0;\n"    // negative index
-                  "    a[128] = 0;\n"   // 128 > CHAR_MAX
-                  "}\n");
-            ASSERT_EQUALS("[test.cpp:4]: (error) Array 'a[128]' index 128 out of bounds\n"
-                          "[test.cpp:3]: (error) Array index -1 is out of bounds\n", errout.str());
-
-        }
-        else // plain char is unsigned
-        {
-            check("void f(char n) {\n"
-                  "    int a[n];\n"     // n <= CHAR_MAX
-                  "    a[-1] = 0;\n"    // negative index
-                  "    a[256] = 0;\n"   // 256 > CHAR_MAX
-                  "}\n");
-            ASSERT_EQUALS("[test.cpp:3]: (error) Array 'a[256]' index -1 out of bounds\n"
-                          "[test.cpp:4]: (error) Array 'a[256]' index 256 out of bounds\n", errout.str());
-        }
+        // CHAR_MAX can be equal to SCHAR_MAX or UCHAR_MAX depending on the environment.
+        // This test should work for both environments.
+        std::ostringstream charMaxPlusOne;
+        charMaxPlusOne << (CHAR_MAX+1);
+        check(("void f(char n) {\n"
+               "    int a[n];\n"     // n <= CHAR_MAX
+               "    a[-1] = 0;\n"    // negative index
+               "    a[" + charMaxPlusOne.str() + "] = 0;\n"   // 128/256 > CHAR_MAX
+               "}\n").c_str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Array 'a["+charMaxPlusOne.str()+"]' index "+charMaxPlusOne.str()+" out of bounds\n"
+                      "[test.cpp:3]: (error) Array index -1 is out of bounds\n", errout.str());
 
         check("void f(signed char n) {\n"
               "    int a[n];\n"     // n <= SCHAR_MAX
@@ -1217,6 +1194,19 @@ private:
         TODO_ASSERT_EQUALS("[test.cpp:12]: (error) Array index out of bounds\n", "", errout.str());
     }
 
+    void array_index_for_in_for()
+    {
+        check("void f() {\n"
+              "    int a[5];\n"
+              "    for (int i = 0; i < 10; ++i) {\n"
+              "        for (int j = i; j < 5; ++j) {\n"
+              "            a[i] = 0;\n"
+              "        }\n"
+              "    }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void array_index_calculation()
     {
         // #1193 - false negative: array out of bounds in loop when there is calculation
@@ -1380,6 +1370,26 @@ private:
         ASSERT_EQUALS("[test.cpp:4]: (error) Buffer access out-of-bounds: a\n", errout.str());
     }
 
+    void array_index_for_question()
+    {
+        // Ticket #2561 - using ?: inside for loop
+        check("void f() {\n"
+              "    int a[10];\n"
+              "    for (int i = 0; i != 10; ++i) {\n"
+              "        i == 0 ? 0 : a[i-1];\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void array_index_extern()
+    {
+        // Ticket #1684. FP when using 'extern'.
+        check("extern char arr[15];\n"
+              "char arr[15] = \"abc\";");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void buffer_overrun_1()
     {
         check("void f()\n"
@@ -1860,6 +1870,58 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void buffer_overrun_17() // ticket #2548
+    {
+        check("void f() {\n"
+              "    char t[8];\n"
+              "    sprintf(t, \"%s\", \"foo     bar\");\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Buffer access out-of-bounds\n", errout.str());
+    }
+
+    void buffer_overrun_18() // ticket #2576
+    {
+        check("class A {\n"
+              "    void foo();\n"
+              "    bool b[7];\n"
+              "};\n"
+              "\n"
+              "void A::foo() {\n"
+              "    for (int i=0; i<6; i++) {\n"
+              "        b[i] = b[i+1];\n"
+              "    }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("class A {\n"
+              "    void foo();\n"
+              "    bool b[7];\n"
+              "};\n"
+              "\n"
+              "void A::foo() {\n"
+              "    for (int i=0; i<7; i++) {\n"
+              "        b[i] = b[i+1];\n"
+              "    }\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("error",    // wanted result
+                           "",         // current result
+                           errout.str());
+    }
+
+    void buffer_overrun_19() // #2597 - class member with unknown type
+    {
+        check("class A {\n"
+              "public:\n"
+              "    u8 buf[10];\n"
+              "    A();"
+              "};\n"
+              "\n"
+              "A::A() {\n"
+              "    memset(buf, 0, 10);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void buffer_overrun_bailoutIfSwitch()
     {
         // No false positive
@@ -2659,7 +2721,7 @@ private:
 
 
     // Ticket #1587 - crash
-    void crash()
+    void crash1()
     {
         check("struct struct A\n"
               "{\n"
@@ -2674,6 +2736,10 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void crash2()
+    {
+        check("struct C {} {} x");
+    }
 
 
     void epcheck(const char code[])
@@ -2886,6 +2952,16 @@ private:
         CheckBufferOverrun c;
         c.getErrorMessages(this, 0);
     }
+
+    void unknownMacroNoDecl()
+    {
+        check("void f() {\n"
+              "    int a[10];\n"
+              "    AAA a[0] = 0;\n"   // <- not a valid array declaration
+              "    a[1] = 1;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestBufferOverrun)
