@@ -77,6 +77,8 @@ private:
         TEST_CASE(suppressionsOld); // TODO: Create and test real suppression file
         TEST_CASE(suppressions)
         TEST_CASE(suppressionsNoFile)
+        TEST_CASE(suppressionSingle)
+        TEST_CASE(suppressionSingleFile)
         TEST_CASE(templates);
         TEST_CASE(templatesGcc);
         TEST_CASE(templatesVs);
@@ -97,6 +99,7 @@ private:
         TEST_CASE(ignorepaths4)
         TEST_CASE(ignorefilepaths1)
         TEST_CASE(ignorefilepaths2)
+        TEST_CASE(checkconfig)
         TEST_CASE(unknownParam);
     }
 
@@ -259,6 +262,7 @@ private:
         const char *argv[] = {"cppcheck", "-D"};
         Settings settings;
         CmdLineParser parser(&settings);
+        // Fails since -D has no param
         ASSERT_EQUALS(false, parser.ParseFromArgs(2, argv));
     }
 
@@ -268,6 +272,7 @@ private:
         const char *argv[] = {"cppcheck", "-D", "-v", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
+        // Fails since -D has no param
         ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
@@ -277,6 +282,7 @@ private:
         const char *argv[] = {"cppcheck", "-D", "--quiet", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
+        // Fails since -D has no param
         ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
@@ -316,6 +322,7 @@ private:
         const char *argv[] = {"cppcheck", "-I", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
+        // Fails since -I has no param
         ASSERT_EQUALS(false, parser.ParseFromArgs(3, argv));
     }
 
@@ -429,7 +436,8 @@ private:
         const char *argv[] = {"cppcheck", "--error-exitcode=", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        // Fails since exit code not given
+        ASSERT_EQUALS(false, parser.ParseFromArgs(3, argv));
     }
 
     void errorExitcodeStr()
@@ -438,7 +446,8 @@ private:
         const char *argv[] = {"cppcheck", "--error-exitcode=foo", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        // Fails since invalid exit code
+        ASSERT_EQUALS(false, parser.ParseFromArgs(3, argv));
     }
 
     void exitcodeSuppressionsOld()
@@ -448,34 +457,37 @@ private:
         const char *argv[] = {"cppcheck", "--exitcode-suppressions", "suppr.txt", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(4, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(4, argv));
     }
 
     void exitcodeSuppressions()
     {
+        // TODO: Fails since cannot open the file
         REDIRECT;
         const char *argv[] = {"cppcheck", "--exitcode-suppressions=suppr.txt", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
     }
 
     void exitcodeSuppressionsNoFile()
     {
+        // TODO: Fails since cannot open the file
         REDIRECT;
         const char *argv[] = {"cppcheck", "--exitcode-suppressions", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
     }
 
     void fileList()
     {
+        // TODO: Fails since cannot open the file
         REDIRECT;
         const char *argv[] = {"cppcheck", "--file-list", "files.txt", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(4, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(4, argv));
     }
 
     void inlineSuppr()
@@ -503,7 +515,8 @@ private:
         const char *argv[] = {"cppcheck", "-j", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        // Fails since -j is missing thread count
+        ASSERT_EQUALS(false, parser.ParseFromArgs(3, argv));
     }
 
     void jobsInvalid()
@@ -512,7 +525,8 @@ private:
         const char *argv[] = {"cppcheck", "-j", "e", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(4, argv));
+        // Fails since invalid count given for -j
+        ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
     void reportProgress()
@@ -542,16 +556,37 @@ private:
         const char *argv[] = {"cppcheck", "--suppressions-list=suppr.txt", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
     }
 
     void suppressionsNoFile()
     {
+        // TODO: Fails because there is no suppr.txt file!
         REDIRECT;
         const char *argv[] = {"cppcheck", "--suppressions-list=", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(3, argv));
+        TODO_ASSERT_EQUALS(true, false, parser.ParseFromArgs(3, argv));
+    }
+
+    void suppressionSingle()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--suppress=uninitvar", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT_EQUALS(true, settings.nomsg.isSuppressed("uninitvar", "file.cpp", 1U));
+    }
+
+    void suppressionSingleFile()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--suppress=uninitvar:file.cpp", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT_EQUALS(true, settings.nomsg.isSuppressed("uninitvar", "file.cpp", 1U));
     }
 
     void templates()
@@ -645,7 +680,8 @@ private:
         const char *argv[] = {"cppcheck", "--xml", "--xml-version=3", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(4, argv));
+        // FAils since unknown XML format version
+        ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
     void xmlverinvalid()
@@ -654,7 +690,8 @@ private:
         const char *argv[] = {"cppcheck", "--xml", "--xml-version=a", "file.cpp"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(4, argv));
+        // FAils since unknown XML format version
+        ASSERT_EQUALS(false, parser.ParseFromArgs(4, argv));
     }
 
     void errorlist1()
@@ -692,7 +729,8 @@ private:
         const char *argv[] = {"cppcheck", "-i"};
         Settings settings;
         CmdLineParser parser(&settings);
-        ASSERT(!parser.ParseFromArgs(2, argv));
+        // Fails since no ignored path given
+        ASSERT_EQUALS(false, parser.ParseFromArgs(2, argv));
         ASSERT_EQUALS(0, parser.GetIgnoredPaths().size());
     }
 
@@ -764,6 +802,16 @@ private:
         ASSERT_EQUALS("src/foo.cpp", parser.GetIgnoredPaths()[0]);
     }
 
+    void checkconfig()
+    {
+        REDIRECT;
+        const char *argv[] = {"cppcheck", "--check-config", "file.cpp"};
+        Settings settings;
+        CmdLineParser parser(&settings);
+        ASSERT(parser.ParseFromArgs(3, argv));
+        ASSERT_EQUALS(true, settings.checkConfiguration);
+    }
+
     void unknownParam()
     {
         REDIRECT;
