@@ -60,6 +60,7 @@ private:
         TEST_CASE(simple2);
         TEST_CASE(simple3);
         TEST_CASE(simple4);
+        TEST_CASE(simple5); // ticket #2560
 
         TEST_CASE(initvar_with_this);       // BUG 2190300
         TEST_CASE(initvar_if);              // BUG 2190290
@@ -72,6 +73,7 @@ private:
         TEST_CASE(initvar_2constructors);       // BUG 2270353
         TEST_CASE(initvar_constvar);
         TEST_CASE(initvar_staticvar);
+        TEST_CASE(initvar_union);
 
         TEST_CASE(initvar_private_constructor);     // BUG 2354171 - private constructor
         TEST_CASE(initvar_copy_constructor); // ticket #1611
@@ -140,7 +142,7 @@ private:
               "    Fred() { }\n"
               "    int i;\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:4]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
 
         check("struct Fred\n"
               "{\n"
@@ -161,7 +163,7 @@ private:
               "    Fred() { }\n"
               "    int i;\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:3]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
     }
 
 
@@ -195,7 +197,7 @@ private:
               "};\n"
               "Fred::Fred()\n"
               "{ }\n");
-        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
 
         check("struct Fred\n"
               "{\n"
@@ -222,7 +224,7 @@ private:
               "};\n"
               "Fred::Fred()\n"
               "{ }\n");
-        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
     }
 
 
@@ -241,7 +243,7 @@ private:
               "{\n"
               "    i = _i;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:8]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:8]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
 
         check("struct Fred\n"
               "{\n"
@@ -255,9 +257,26 @@ private:
               "{\n"
               "    i = _i;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::i' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::i' is not initialized in the constructor.\n", errout.str());
     }
 
+    void simple5() // ticket #2560
+    {
+        check("namespace Nsp\n"
+              "{\n"
+              "    class B { };\n"
+              "}\n"
+              "class Altren : public Nsp::B\n"
+              "{\n"
+              "public:\n"
+              "    Altren () : Nsp::B(), mValue(0)\n"
+              "    {\n"
+              "    }\n"
+              "private:\n"
+              "    int mValue;\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
 
     void initvar_with_this()
     {
@@ -600,8 +619,8 @@ private:
               "    }\n"
               "};\n");
 
-        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::a' is not initialised in the constructor.\n"
-                      "[test.cpp:16]: (warning) Member variable 'Fred::b' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::a' is not initialized in the constructor.\n"
+                      "[test.cpp:16]: (warning) Member variable 'Fred::b' is not initialized in the constructor.\n", errout.str());
     }
 
     void initvar_chained_assign()
@@ -734,7 +753,7 @@ private:
               "};\n"
               "Fred::Fred()\n"
               "{ }");
-        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::s' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::s' is not initialized in the constructor.\n", errout.str());
 
         check("struct Fred\n"
               "{\n"
@@ -761,7 +780,7 @@ private:
               "};\n"
               "Fred::Fred()\n"
               "{ }");
-        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'Fred::s' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'Fred::s' is not initialized in the constructor.\n", errout.str());
     }
 
 
@@ -777,6 +796,38 @@ private:
     }
 
 
+    void initvar_union()
+    {
+        check("class Fred\n"
+              "{\n"
+              "    union\n"
+              "    {\n"
+              "        int a;\n"
+              "        char b[4];\n"
+              "    } U;\n"
+              "public:\n"
+              "    Fred()\n"
+              "    {\n"
+              "        U.a = 0;\n"
+              "    }\n"
+              "};\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("class Fred\n"
+              "{\n"
+              "    union\n"
+              "    {\n"
+              "        int a;\n"
+              "        char b[4];\n"
+              "    } U;\n"
+              "public:\n"
+              "    Fred()\n"
+              "    {\n"
+              "    }\n"
+              "};\n");
+        ASSERT_EQUALS("[test.cpp:9]: (warning) Member variable 'Fred::U' is not initialized in the constructor.\n", errout.str());
+    }
+
 
     void initvar_private_constructor()
     {
@@ -801,7 +852,7 @@ private:
               "    Fred() { };\n"
               "    Fred(const Fred &) { };\n"
               "};");
-        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::var' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (warning) Member variable 'Fred::var' is not initialized in the constructor.\n", errout.str());
 
         check("class Fred\n"
               "{\n"
@@ -813,7 +864,7 @@ private:
               "};\n"
               "Fred::Fred() { };\n"
               "Fred::Fred(const Fred &) { };\n");
-        ASSERT_EQUALS("[test.cpp:10]: (warning) Member variable 'Fred::var' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:10]: (warning) Member variable 'Fred::var' is not initialized in the constructor.\n", errout.str());
     }
 
     void initvar_nested_constructor() // ticket #1375
@@ -841,11 +892,11 @@ private:
               "A::B::B(int x){}\n"
               "A::B::C::C(int y){}\n"
               "A::B::C::D::D(int z){}\n");
-        ASSERT_EQUALS("[test.cpp:20]: (warning) Member variable 'A::a' is not initialised in the constructor.\n"
-                      "[test.cpp:20]: (warning) Member variable 'A::b' is not initialised in the constructor.\n"
-                      "[test.cpp:21]: (warning) Member variable 'B::b' is not initialised in the constructor.\n"
-                      "[test.cpp:22]: (warning) Member variable 'C::c' is not initialised in the constructor.\n"
-                      "[test.cpp:23]: (warning) Member variable 'D::d' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:20]: (warning) Member variable 'A::a' is not initialized in the constructor.\n"
+                      "[test.cpp:20]: (warning) Member variable 'A::b' is not initialized in the constructor.\n"
+                      "[test.cpp:21]: (warning) Member variable 'B::b' is not initialized in the constructor.\n"
+                      "[test.cpp:22]: (warning) Member variable 'C::c' is not initialized in the constructor.\n"
+                      "[test.cpp:23]: (warning) Member variable 'D::d' is not initialized in the constructor.\n", errout.str());
 
         check("class A {\n"
               "public:\n"
@@ -870,11 +921,11 @@ private:
               "A::B::B(int x){}\n"
               "A::B::C::C(int y){}\n"
               "A::B::C::D::D(const A::B::C::D & d){}\n");
-        ASSERT_EQUALS("[test.cpp:20]: (warning) Member variable 'A::a' is not initialised in the constructor.\n"
-                      "[test.cpp:20]: (warning) Member variable 'A::b' is not initialised in the constructor.\n"
-                      "[test.cpp:21]: (warning) Member variable 'B::b' is not initialised in the constructor.\n"
-                      "[test.cpp:22]: (warning) Member variable 'C::c' is not initialised in the constructor.\n"
-                      "[test.cpp:23]: (warning) Member variable 'D::d' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:20]: (warning) Member variable 'A::a' is not initialized in the constructor.\n"
+                      "[test.cpp:20]: (warning) Member variable 'A::b' is not initialized in the constructor.\n"
+                      "[test.cpp:21]: (warning) Member variable 'B::b' is not initialized in the constructor.\n"
+                      "[test.cpp:22]: (warning) Member variable 'C::c' is not initialized in the constructor.\n"
+                      "[test.cpp:23]: (warning) Member variable 'D::d' is not initialized in the constructor.\n", errout.str());
 
         check("class A {\n"
               "public:\n"
@@ -900,11 +951,11 @@ private:
               "A::B::B(int x){}\n"
               "A::B::C::C(int y){}\n"
               "A::B::C::D::D(const A::B::C::D::E & e){}\n");
-        ASSERT_EQUALS("[test.cpp:21]: (warning) Member variable 'A::a' is not initialised in the constructor.\n"
-                      "[test.cpp:21]: (warning) Member variable 'A::b' is not initialised in the constructor.\n"
-                      "[test.cpp:22]: (warning) Member variable 'B::b' is not initialised in the constructor.\n"
-                      "[test.cpp:23]: (warning) Member variable 'C::c' is not initialised in the constructor.\n"
-                      "[test.cpp:24]: (warning) Member variable 'D::d' is not initialised in the constructor.\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:21]: (warning) Member variable 'A::a' is not initialized in the constructor.\n"
+                      "[test.cpp:21]: (warning) Member variable 'A::b' is not initialized in the constructor.\n"
+                      "[test.cpp:22]: (warning) Member variable 'B::b' is not initialized in the constructor.\n"
+                      "[test.cpp:23]: (warning) Member variable 'C::c' is not initialized in the constructor.\n"
+                      "[test.cpp:24]: (warning) Member variable 'D::d' is not initialized in the constructor.\n", errout.str());
     }
 
     void initvar_nocopy1() // ticket #2474
@@ -938,7 +989,7 @@ private:
               "    A(const A&){}\n"
               "    const A& operator=(const A&){return *this;}\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:12]: (warning) Member variable 'A::m_SemVar' is not initialised in the constructor.\n"
+        ASSERT_EQUALS("[test.cpp:12]: (warning) Member variable 'A::m_SemVar' is not initialized in the constructor.\n"
                       "[test.cpp:13]: (warning) Member variable 'A::m_SemVar' is not assigned a value in 'A::operator='\n", errout.str());
 
         check("class A\n"
@@ -949,7 +1000,7 @@ private:
               "    A(const A&){}\n"
               "    const A& operator=(const A&){return *this;}\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'A::m_SemVar' is not initialised in the constructor.\n"
+        ASSERT_EQUALS("[test.cpp:6]: (warning) Member variable 'A::m_SemVar' is not initialized in the constructor.\n"
                       "[test.cpp:7]: (warning) Member variable 'A::m_SemVar' is not assigned a value in 'A::operator='\n", errout.str());
     }
 
@@ -984,7 +1035,7 @@ private:
               "    A(const A&){}\n"
               "    const A& operator=(const A&){return *this;}\n"
               "};\n");
-        ASSERT_EQUALS("[test.cpp:12]: (warning) Member variable 'A::m_SemVar' is not initialised in the constructor.\n"
+        ASSERT_EQUALS("[test.cpp:12]: (warning) Member variable 'A::m_SemVar' is not initialized in the constructor.\n"
                       "[test.cpp:13]: (warning) Member variable 'A::m_SemVar' is not assigned a value in 'A::operator='\n", errout.str());
     }
 
