@@ -32,7 +32,7 @@
 #include <stdexcept>
 
 // use tinyxml with STL
-#include "tinyxml/tinyxml.h"
+#include <tinyxml.h>
 
 extern std::ostringstream errout;
 extern std::ostringstream output;
@@ -59,7 +59,7 @@ private:
             id.push_back(msg._id);
         }
 
-        void reportStatus(unsigned int /*index*/, unsigned int /*max*/)
+        void reportStatus(unsigned int /*fileindex*/, unsigned int /*filecount*/, long /*sizedone*/, long /*sizetotal*/)
         {
         }
     };
@@ -86,7 +86,7 @@ private:
     void getErrorMessages()
     {
         ErrorLogger2 errorLogger;
-        CppCheck cppCheck(errorLogger);
+        CppCheck cppCheck(errorLogger, true);
         cppCheck.getErrorMessages();
         ASSERT(!errorLogger.id.empty());
 
