@@ -44,8 +44,11 @@ private:
         TEST_CASE(nullpointer7);
         TEST_CASE(nullpointer8);
         TEST_CASE(nullpointer9);
+        TEST_CASE(nullpointer10);
+        TEST_CASE(nullpointer11); // ticket #2812
         TEST_CASE(pointerCheckAndDeRef);	// check if pointer is null and then dereference it
         TEST_CASE(nullConstantDereference);		// Dereference NULL constant
+        TEST_CASE(gcc_statement_expression);    // Don't crash
     }
 
     void check(const char code[])
@@ -77,7 +80,18 @@ private:
               "    while (tok);\n"
               "    tok = tok->next();\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: tok\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: tok - otherwise it is redundant to check if tok is null at line 3\n", errout.str());
+
+        // #2681
+        check("void foo(const Token *tok)\n"
+              "{\n"
+              "    while (tok && tok->str() == \"=\")\n"
+              "        tok = tok->tokAt(-2);\n"
+              "\n"
+              "    if (tok->str() != \";\")\n"
+              "        ;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:6]: (error) Possible null pointer dereference: tok - otherwise it is redundant to check if tok is null at line 3\n", "", errout.str());
 
         check("void foo()\n"
               "{\n"
@@ -193,13 +207,42 @@ private:
               "}\n");
         ASSERT_EQUALS("[test.cpp:3]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 4\n", errout.str());
 
-        check("void foo(struct ABC *abc)\n"
-              "{\n"
+        check("void foo(struct ABC *abc) {\n"
               "    bar(abc->a);\n"
               "    if (!abc)\n"
               "        ;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 4\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 3\n", errout.str());
+
+        check("void foo(ABC *abc) {\n"
+              "    abc->do_something();\n"
+              "    if (abc)\n"
+              "        ;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 3\n", errout.str());
+
+        check("void foo(ABC *abc) {\n"
+              "    if (abc->a == 3) {\n"
+              "        return;\n"
+              "    }\n"
+              "    if (abc) {}\n"
+              "}");
+        TODO_ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 5\n", "", errout.str());
+
+        // TODO: False negative if member of member is dereferenced
+        check("void foo(ABC *abc) {\n"
+              "    abc->next->a = 0;\n"
+              "    if (abc->next)\n"
+              "        ;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 3\n", "", errout.str());
+
+        check("void foo(ABC *abc) {\n"
+              "    abc->a = 0;\n"
+              "    if (abc && abc->b == 0)\n"
+              "        ;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 3\n", errout.str());
 
         // ok dereferencing in a condition
         check("void foo(struct ABC *abc)\n"
@@ -297,6 +340,52 @@ private:
               "        ;\n"
               "}\n");
         ASSERT_EQUALS("", errout.str());
+
+        // #2641 - global pointer, function call
+        check("ABC *abc;\n"
+              "void f() {\n"
+              "    abc->a = 0;\n"
+              "    do_stuff();\n"
+              "    if (abc) { }\n"
+              "}");
+        ASSERT_EQUALS("",errout.str());
+
+        check("Fred *fred;\n"
+              "void f() {\n"
+              "    fred->foo();\n"
+              "    if (fred) { }\n"
+              "}");
+        ASSERT_EQUALS("",errout.str());
+
+        // #2641 - local pointer, function call
+        check("void f() {\n"
+              "    ABC *abc;\n"
+              "    abc->a = 0;\n"
+              "    do_stuff();\n"
+              "    if (abc) { }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 5\n",errout.str());
+
+        // #2641 - local pointer, function call
+        check("void f(ABC *abc) {\n"
+              "    abc->a = 0;\n"
+              "    do_stuff();\n"
+              "    if (abc) { }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (error) Possible null pointer dereference: abc - otherwise it is redundant to check if abc is null at line 4\n",errout.str());
+
+        // #2691 - switch/break
+        check("void f(ABC *abc) {\n"
+              "    switch ( x ) {\n"
+              "        case 14:\n"
+              "            sprintf(buf, \"%d\", abc->a);\n"
+              "            break;\n"
+              "        case 15:\n"
+              "            if ( abc ) {}\n"
+              "            break;\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     // Dereferencing a pointer and then checking if it is null
@@ -406,6 +495,19 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        check("int f(Item *item) {\n"
+              "    x = item ? ab(item->x) : 0;\n"
+              "    if (item) { }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("int f(Item *item) {\n"
+              "    item->x = 0;\n"
+              "    a = b ? c : d;\n"
+              "    if (item) { }\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("error", "", errout.str());
+
         check("BOOL GotoFlyAnchor()\n"  // #2243
               "{\n"
               "    const SwFrm* pFrm = GetCurrFrm();\n"
@@ -718,6 +820,21 @@ private:
               "}\n");
         TODO_ASSERT_EQUALS("error",
                            "", errout.str());
+
+        // #2231 - error if assignment in loop is not used
+        check("void f() {\n"
+              "    char *p = 0;\n"
+              "\n"
+              "    for (int x = 0; x < 3; ++x) {\n"
+              "        if (y[x] == 0) {\n"
+              "            p = malloc(10);\n"
+              "            break;\n"
+              "        }\n"
+              "    }\n"
+              "\n"
+              "    *p = 0;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:11]: (error) Possible null pointer dereference: p\n", errout.str());
     }
 
     void nullpointer7()
@@ -753,7 +870,58 @@ private:
               "  std::string * x = 0;\n"
               "  *x = \"test\";\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: x\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Null pointer dereference\n", errout.str());
+    }
+
+    void nullpointer10()
+    {
+        check("void foo()\n"
+              "{\n"
+              "  struct my_type* p = 0;\n"
+              "  p->x = 0;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", errout.str());
+
+        check("void foo()\n"
+              "{\n"
+              "  struct my_type* p;\n"
+              "  p = 0; \n"
+              "  p->x = 0;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (error) Possible null pointer dereference: p\n", errout.str());
+    }
+
+    void nullpointer11() // ticket #2812
+    {
+        check("int foo()\n"
+              "{\n"
+              "  my_type* p = 0;\n"
+              "  return p->x;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", "", errout.str());
+
+        check("int foo()\n"
+              "{\n"
+              "  struct my_type* p = 0;\n"
+              "  return p->x;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", "", errout.str());
+
+        check("int foo()\n"
+              "{\n"
+              "  my_type* p;\n"
+              "  p = 0; \n"
+              "  return p->x;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:5]: (error) Possible null pointer dereference: p\n", "", errout.str());
+
+        check("int foo()\n"
+              "{\n"
+              "  struct my_type* p;\n"
+              "  p = 0; \n"
+              "  return p->x;\n"
+              "}\n");
+        TODO_ASSERT_EQUALS("[test.cpp:5]: (error) Possible null pointer dereference: p\n", "", errout.str());
     }
 
     // Check if pointer is null and the dereference it
@@ -764,28 +932,41 @@ private:
               "    }\n"
               "    *p = 0;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
 
         check("void foo(char *p) {\n"
               "    if (NULL == p) {\n"
               "    }\n"
               "    *p = 0;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
 
         check("void foo(char *p) {\n"
               "    if (p == NULL) {\n"
               "    }\n"
               "    *p = 0;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
 
         check("void foo(char *p) {\n"
               "    if (p == NULL) {\n"
               "    }\n"
               "    printf(\"%c\", *p);\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
+
+        check("void foo(char *p) {\n"
+              "    if (p && *p == 0) {\n"
+              "    }\n"
+              "    printf(\"%c\", *p);\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
+
+        check("void foo(char *p) {\n"
+              "    if (p && *p == 0) {\n"
+              "    } else { *p = 0; }\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
 
         check("void foo(abc *p) {\n"
               "    if (!p) {\n"
@@ -867,7 +1048,7 @@ private:
               "    }\n"
               "    *p = 0;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:5]: (error) Possible null pointer dereference: p\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:5]: (error) Possible null pointer dereference: p - otherwise it is redundant to check if p is null at line 2\n", errout.str());
 
         // #2467 - unknown macro may terminate the application
         check("void f(Fred *fred) {\n"
@@ -890,6 +1071,74 @@ private:
               "    };\n"
               "}");
         ASSERT_EQUALS("", errout.str());
+
+        // #2582 - segmentation fault
+        check("if()");
+
+        // #2674 - different functions
+        check("class Fred {\n"
+              "public:\n"
+              "    Wilma *wilma;\n"
+              "    void a();\n"
+              "    void b();\n"
+              "};\n"
+              "\n"
+              "void Fred::a() {\n"
+              "    if ( wilma ) { }\n"
+              "}\n"
+              "\n"
+              "void Fred::b() {\n"
+              "    wilma->Reload();\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void test(int *i) {\n"
+              "  if(i == NULL) {\n"
+              "    int b = 1;\n"
+              "  } else {\n"
+              "    int b = *i;\n"
+              "  }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // #2696 - false positives nr 1
+        check("void f()\n"
+              "{\n"
+              "   struct foo *pFoo = NULL;\n"
+              "   size_t len;\n"
+              "\n"
+              "   len = sizeof(*pFoo) - sizeof(pFoo->data);\n"
+              "\n"
+              "   if (pFoo)\n"
+              "      bar();\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // #2696 - false positives nr 2
+        check("void f()\n"
+              "{\n"
+              "   struct foo *pFoo = NULL;\n"
+              "   size_t len;\n"
+              "\n"
+              "   while (pFoo)\n"
+              "      pFoo = pFoo->next;\n"
+              "\n"
+              "   len = sizeof(pFoo->data);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // #2696 - false positives nr 3
+        check("void f()\n"
+              "{\n"
+              "   struct foo *pFoo = NULL;\n"
+              "   size_t len;\n"
+              "\n"
+              "   while (pFoo)\n"
+              "      pFoo = pFoo->next;\n"
+              "\n"
+              "   len = decltype(*pFoo);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     // Test CheckNullPointer::nullConstantDereference
@@ -910,6 +1159,14 @@ private:
 
     }
 
+    void gcc_statement_expression()
+    {
+        // Ticket #2621
+        check("void f(struct ABC *abc) {\n"
+              "    ({ if (abc) dbg(); })\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestNullPointer)
