@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "preprocessor.h"
 #include "tokenize.h"
 #include "checkother.h"
 #include "testsuite.h"
@@ -59,6 +60,7 @@ private:
         TEST_CASE(varScope9);		// classes may have extra side-effects
         TEST_CASE(varScope10);      // Undefined macro FOR
         TEST_CASE(varScope11);		// #2475 - struct initialization is not inner scope
+        TEST_CASE(varScope12);		// variable usage in inner loop
 
         TEST_CASE(oldStylePointerCast);
 
@@ -74,13 +76,15 @@ private:
         TEST_CASE(sizeofCalculation);
 
         TEST_CASE(switchRedundantAssignmentTest);
+        TEST_CASE(switchFallThroughCase);
 
         TEST_CASE(selfAssignment);
         TEST_CASE(testScanf1);
         TEST_CASE(testScanf2);
 
         TEST_CASE(trac1132);
-        TEST_CASE(testMisusedScopeObjectDoesNotPickFunction);
+        TEST_CASE(testMisusedScopeObjectDoesNotPickFunction1);
+        TEST_CASE(testMisusedScopeObjectDoesNotPickFunction2);
         TEST_CASE(testMisusedScopeObjectPicksClass);
         TEST_CASE(testMisusedScopeObjectPicksStruct);
         TEST_CASE(testMisusedScopeObjectDoesNotPickIf);
@@ -100,8 +104,23 @@ private:
         TEST_CASE(memsetZeroBytes);
 
         TEST_CASE(sizeofForArrayParameter);
+        TEST_CASE(sizeofForNumericParameter);
 
         TEST_CASE(clarifyCalculation);
+
+        TEST_CASE(clarifyCondition);     // if (a = b() < 0)
+
+        TEST_CASE(incorrectStringCompare);
+
+        TEST_CASE(incrementBoolean);
+        TEST_CASE(comparisonOfBoolWithInt);
+
+        TEST_CASE(duplicateIf);
+        TEST_CASE(duplicateBranch);
+        TEST_CASE(duplicateExpression1);
+        TEST_CASE(duplicateExpression2); // ticket #2730
+
+        TEST_CASE(alwaysTrueFalseStringCompare);
     }
 
     void check(const char code[], const char *filename = NULL)
@@ -111,6 +130,7 @@ private:
 
         Settings settings;
         settings._checkCodingStyle = true;
+        settings.inconclusive = true;
 
         // Tokenize..
         Tokenizer tokenizer(&settings, this);
@@ -124,6 +144,11 @@ private:
         checkOther.checkRedundantAssignmentInSwitch();
         checkOther.checkAssignmentInAssert();
         checkOther.checkSizeofForArrayParameter();
+        checkOther.checkSizeofForNumericParameter();
+        checkOther.clarifyCondition();
+        checkOther.checkDuplicateIf();
+        checkOther.checkDuplicateBranch();
+        checkOther.checkDuplicateExpression();
 
         // Simplify token list..
         tokenizer.simplifyTokenList();
@@ -138,6 +163,64 @@ private:
         checkOther.checkCatchExceptionByValue();
         checkOther.checkMemsetZeroBytes();
         checkOther.clarifyCalculation();
+        checkOther.checkIncorrectStringCompare();
+        checkOther.checkIncrementBoolean();
+        checkOther.checkComparisonOfBoolWithInt();
+    }
+
+    class SimpleSuppressor: public ErrorLogger
+    {
+    public:
+        SimpleSuppressor(Settings &settings, ErrorLogger *next)
+            : _settings(settings), _next(next)
+        { }
+        virtual void reportOut(const std::string &outmsg)
+        {
+            _next->reportOut(outmsg);
+        }
+        virtual void reportErr(const ErrorLogger::ErrorMessage &msg)
+        {
+            if (!msg._callStack.empty() && !_settings.nomsg.isSuppressed(msg._id, msg._callStack.begin()->getfile(), msg._callStack.begin()->line))
+                _next->reportErr(msg);
+        }
+    private:
+        Settings &_settings;
+        ErrorLogger *_next;
+    };
+
+    void check_preprocess_suppress(const char precode[], const char *filename = NULL)
+    {
+        // Clear the error buffer..
+        errout.str("");
+
+        if (filename == NULL)
+            filename = "test.cpp";
+
+        Settings settings;
+        settings._checkCodingStyle = true;
+        settings.experimental = true;
+
+        // Preprocess file..
+        Preprocessor preprocessor(&settings, this);
+        std::list<std::string> configurations;
+        std::string filedata = "";
+        std::istringstream fin(precode);
+        preprocessor.preprocess(fin, filedata, configurations, filename, settings._includePaths);
+        SimpleSuppressor logger(settings, this);
+        const std::string code = Preprocessor::getcode(filedata, "", filename, &settings, &logger);
+
+        // Tokenize..
+        Tokenizer tokenizer(&settings, &logger);
+        std::istringstream istr(code);
+        tokenizer.tokenize(istr, filename);
+        tokenizer.simplifyGoto();
+
+        // Check..
+        CheckOther checkOther(&tokenizer, &settings, &logger);
+        checkOther.checkSwitchCaseFallThrough();
+        checkOther.checkAlwaysTrueOrFalseStringCompare();
+
+        logger.reportUnmatchedSuppressions(settings.nomsg.getUnmatchedLocalSuppressions(filename));
     }
 
 
@@ -476,7 +559,7 @@ private:
                  "        for ( ; i < 10; ++i) ;\n"
                  "    }\n"
                  "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (information) The scope of the variable i can be reduced\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (information) The scope of the variable 'i' can be reduced\n", errout.str());
 
         varScope("void f(int x)\n"
                  "{\n"
@@ -486,7 +569,7 @@ private:
                  "        for ( ; i < 10; ++i) ;\n"
                  "    }\n"
                  "}\n");
-        ASSERT_EQUALS("[test.cpp:3]: (information) The scope of the variable i can be reduced\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (information) The scope of the variable 'i' can be reduced\n", errout.str());
     }
 
     void varScope6()
@@ -552,7 +635,7 @@ private:
                  "        edgeResistance = (edge+1) / 2.0;\n"
                  "    }\n"
                  "}\n");
-        ASSERT_EQUALS("[test.cpp:2]: (information) The scope of the variable edgeResistance can be reduced\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (information) The scope of the variable 'edgeResistance' can be reduced\n", errout.str());
     }
 
     void varScope9()
@@ -607,6 +690,17 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void varScope12()
+    {
+        // #2770
+        varScope("void f() {\n"
+                 "    int i = 0;\n"
+                 "    forever {\n"
+                 "        if (i++ == 42) { break; }\n"
+                 "    }\n"
+                 "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 
     void checkOldStylePointerCast(const char code[])
     {
@@ -757,6 +851,10 @@ private:
 
         testPassedByValue("void f(const std::map<std::string,int> v) {}");
         ASSERT_EQUALS("[test.cpp:1]: (performance) Function parameter 'v' should be passed by reference.\n", errout.str());
+
+        testPassedByValue("void f(const std::streamoff pos) {}");
+        ASSERT_EQUALS("", errout.str());
+
     }
 
     void mathfunctionCall1()
@@ -1109,6 +1207,22 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        check("void foo()\n"
+              "{\n"
+              "    int y = 1;\n"
+              "    while(xyz()) {\n"
+              "        switch (x)\n"
+              "        {\n"
+              "        case 2:\n"
+              "            y = 2;\n"
+              "            throw e;\n"
+              "        case 3:\n"
+              "            y = 3;\n"
+              "        }\n"
+              "    }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         check("void foo()\n"
               "{\n"
               "        int y = 1;\n"
@@ -1138,6 +1252,312 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void switchFallThroughCase()
+    {
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            break;\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            break;\n"
+            "        case 2:\n"
+            "            continue;\n"
+            "        case 3:\n"
+            "            return;\n"
+            "        case 4:\n"
+            "            exit(1);\n"
+            "        case 5:\n"
+            "            goto end;\n"
+            "        case 6:\n"
+            "            throw e;\n"
+            "        case 7:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 0:\n"
+            "        case 1:\n"
+            "            break;\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            g();\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            g();\n"
+            "        default:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            g();\n"
+            "            // fall through\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            g();\n"
+            "            /* FALLTHRU */\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            g();\n"
+            "            break;\n"
+            "            // fall through\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:7]: (information) Unmatched suppression: switchCaseFallThrough\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            {\n"
+            "                break;\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            for (;;) {\n"
+            "                break;\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:7]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            if (b) {\n"
+            "                break;\n"
+            "            } else {\n"
+            "                break;\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            if (b) {\n"
+            "                break;\n"
+            "            } else {\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:8]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            if (b) {\n"
+            "                break;\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:7]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            if (b) {\n"
+            "            } else {\n"
+            "                break;\n"
+            "            }\n"
+            "        case 2:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:8]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "        case 1:\n"
+            "            if (b) {\n"
+            "        case 2:\n"
+            "            } else {\n"
+            "                break;\n"
+            "            }\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "            int x;\n"
+            "        case 1:\n"
+            "            break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "    case 1:\n"
+            "        g();\n"
+            "        switch (b) {\n"
+            "            case 1:\n"
+            "                return;\n"
+            "            default:\n"
+            "                return;\n"
+            "        }\n"
+            "    case 2:\n"
+            "        break;\n"
+            "    }\n"
+            "}\n");
+        // This fails because the switch parsing code currently doesn't understand
+        // that all paths after g() actually return. It's a pretty unusual case
+        // (no pun intended).
+        TODO_ASSERT_EQUALS("",
+                           "[test.cpp:11]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "    case 1:\n"
+            "#ifndef A\n"
+            "        g();\n"
+            "        // fall through\n"
+            "#endif\n"
+            "    case 2:\n"
+            "        break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "    case 1:\n"
+            "        goto leave;\n"
+            "    case 2:\n"
+            "        break;\n"
+            "    }\n"
+            "leave:\n"
+            "    if (x) {\n"
+            "        g();\n"
+            "        return;\n"
+            "    }\n"
+            "}\n");
+        // This fails because Tokenizer::simplifyGoto() copies the "leave:" block
+        // into where the goto is, but because it contains a "return", it omits
+        // copying a final return after the block.
+        TODO_ASSERT_EQUALS("",
+                           "[test.cpp:5]: (style) Switch falls through case without comment\n", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    switch (a) {\n"
+            "    case 1:\n"
+            "        g();\n"
+            "        // fall through\n"
+            "    case 2:\n"
+            "        g();\n"
+            "        // falls through\n"
+            "    case 3:\n"
+            "        g();\n"
+            "        // fall-through\n"
+            "    case 4:\n"
+            "        g();\n"
+            "        // drop through\n"
+            "    case 5:\n"
+            "        g();\n"
+            "        // pass through\n"
+            "    case 5:\n"
+            "        g();\n"
+            "        // no break\n"
+            "    case 5:\n"
+            "        g();\n"
+            "        // fallthru\n"
+            "    case 6:\n"
+            "        g();\n"
+            "        /* fall */\n"
+            "    default:\n"
+            "        break;\n"
+            "    }\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check_preprocess_suppress(
+            "void foo() {\n"
+            "    // unrelated comment saying 'fall through'\n"
+            "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void selfAssignment()
     {
         check("void foo()\n"
@@ -1151,14 +1571,12 @@ private:
         check("void foo()\n"
               "{\n"
               "        int x = x;\n"
-              "        return 0;\n"
               "}\n");
         ASSERT_EQUALS("[test.cpp:3]: (warning) Redundant assignment of \"x\" to itself\n", errout.str());
 
         check("void foo()\n"
               "{\n"
               "        std::string var = var = \"test\";\n"
-              "        return 0;\n"
               "}\n");
         TODO_ASSERT_EQUALS("[test.cpp:3]: (warning) Redundant assignment of \"var\" to itself\n", "", errout.str());
 
@@ -1176,6 +1594,25 @@ private:
               "        *x = x;\n"
               "}\n");
         ASSERT_EQUALS("", errout.str());
+
+        // non-primitive type -> there might be some side effects
+        check("void foo()\n"
+              "{\n"
+              "        Fred fred; fred = fred;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int x) {\n"
+              "    x = (x == 0);"
+              "    func(x);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int x) {\n"
+              "    x = (x != 0);"
+              "    func(x);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void testScanf1()
@@ -1249,7 +1686,7 @@ private:
         ASSERT_EQUALS("[trac1132.cpp:16]: (error) instance of \"Lock\" object destroyed immediately\n", errout.str());
     }
 
-    void testMisusedScopeObjectDoesNotPickFunction()
+    void testMisusedScopeObjectDoesNotPickFunction1()
     {
         check("int main ( )\n"
               "{\n"
@@ -1260,6 +1697,24 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void testMisusedScopeObjectDoesNotPickFunction2()
+    {
+        check("struct error {\n"
+              "    error() {}\n"
+              "};\n"
+              "\n"
+              "class parser {\n"
+              "public:\n"
+              "    void error() const {}\n"
+              "\n"
+              "    void foo() const {\n"
+              "        error();\n"
+              "    }\n"
+              "};\n"
+             );
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void testMisusedScopeObjectPicksClass()
     {
         check("class NotAFunction ;\n"
@@ -1376,6 +1831,15 @@ private:
 
         check(code, "test.c");
         ASSERT_EQUALS("", errout.str());
+
+        // Ticket #2639
+        check("struct stat { int a; int b; };\n"
+              "void stat(const char *fn, struct stat *);\n"
+              "\n"
+              "void foo() {\n"
+              "    stat(\"file.txt\", &st);\n"
+              "}\n");
+        ASSERT_EQUALS("",errout.str());
     }
 
     void testMisusedScopeObjectDoesNotPickNestedClass()
@@ -1396,7 +1860,7 @@ private:
                             "}\n";
 
         check(code, "test.cpp");
-        TODO_ASSERT_EQUALS("", "[test.cpp:13]: (error) instance of \"Init\" object destroyed immediately\n", errout.str());
+        ASSERT_EQUALS("", errout.str());
     }
 
     void trac2084()
@@ -1839,6 +2303,33 @@ private:
              );
         ASSERT_EQUALS("", errout.str());
 
+    }
+
+    void sizeofForNumericParameter()
+    {
+        check("void f() {\n"
+              "    std::cout << sizeof(10) << std::endl;\n"
+              "}\n"
+             );
+        ASSERT_EQUALS("[test.cpp:2]: (error) Using sizeof with a numeric constant as function argument might not be what you intended.\n", errout.str());
+
+        check("void f() {\n"
+              "    std::cout << sizeof(-10) << std::endl;\n"
+              "}\n"
+             );
+        ASSERT_EQUALS("[test.cpp:2]: (error) Using sizeof with a numeric constant as function argument might not be what you intended.\n", errout.str());
+
+        check("void f() {\n"
+              "    std::cout << sizeof 10  << std::endl;\n"
+              "}\n"
+             );
+        ASSERT_EQUALS("[test.cpp:2]: (error) Using sizeof with a numeric constant as function argument might not be what you intended.\n", errout.str());
+
+        check("void f() {\n"
+              "    std::cout << sizeof -10  << std::endl;\n"
+              "}\n"
+             );
+        ASSERT_EQUALS("[test.cpp:2]: (error) Using sizeof with a numeric constant as function argument might not be what you intended.\n", errout.str());
 
 
     }
@@ -1848,14 +2339,302 @@ private:
         check("int f(char c) {\n"
               "    return 10 * (c == 0) ? 1 : 2;\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (information) Please clarify precedence: 'a*b?..'\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (style) Clarify calculation precedence for * and ?\n", errout.str());
 
         check("void f(char c) {\n"
               "    printf(\"%i\", 10 * (c == 0) ? 1 : 2);\n"
               "}");
-        ASSERT_EQUALS("[test.cpp:2]: (information) Please clarify precedence: 'a*b?..'\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:2]: (style) Clarify calculation precedence for * and ?\n", errout.str());
+
+        // Ticket #2585 - segmentation fault for invalid code
+        check("abcdef?" "?<"
+              "123456?" "?>"
+              "+?" "?=");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(char c) {\n"
+              "    printf(\"%i\", 1 + 1 ? 1 : 2);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) Clarify calculation precedence for + and ?\n", errout.str());
+
+        check("void f() {\n"
+              "    std::cout << x << 1 ? 2 : 3;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) Clarify calculation precedence for << and ?\n", errout.str());
+
+        check("void f() {\n"
+              "    int ab = a - b ? 2 : 3;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) Clarify calculation precedence for - and ?\n", errout.str());
     }
 
+    // clarify conditions with = and comparison
+    void clarifyCondition()
+    {
+        check("void f() {\n"
+              "    if (x = b() < 0) {}\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) Suspicious condition (assignment+comparison), it can be clarified with parentheses\n", errout.str());
+    }
+
+    void incorrectStringCompare()
+    {
+        check("int f() {\n"
+              "    return test.substr( 0 , 4 ) == \"Hello\" ? : 0 : 1 ;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal \"Hello\" doesn't match length argument for substr(4).\n", errout.str());
+
+        check("int f() {\n"
+              "    return test.substr( 0 , 5 ) == \"Hello\" ? : 0 : 1 ;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("int f() {\n"
+              " return \"Hello\" == test.substr( 0 , 4 ) ? : 0 : 1 ;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) String literal \"Hello\" doesn't match length argument for substr(4).\n", errout.str());
+
+        check("int f() {\n"
+              " return \"Hello\" == test.substr( 0 , 5 ) ? : 0 : 1 ;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+
+    void incrementBoolean()
+    {
+        check("bool bValue = true;\n"
+              "bValue++;\n");
+        ASSERT_EQUALS("[test.cpp:2]: (style) The use of a variable of type bool with the ++ postfix operator is always true and deprecated by the C++ Standard.\n", errout.str());
+
+        check("void f(bool test){\n"
+              "    test++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) The use of a variable of type bool with the ++ postfix operator is always true and deprecated by the C++ Standard.\n", errout.str());
+
+        check("void f(int test){\n"
+              "    test++;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void comparisonOfBoolWithInt()
+    {
+        check("void f(int x) {\n"
+              "    if (!x == 10) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) Comparison of a boolean with a non-zero integer\n", errout.str());
+
+        check("void f(int x) {\n"
+              "    if (!x != 10) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) Comparison of a boolean with a non-zero integer\n", errout.str());
+
+        check("void f(int x) {\n"
+              "    if (x != 10) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int x) {\n"
+              "    if (10 == !x) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) Comparison of a boolean with a non-zero integer\n", errout.str());
+
+        check("void f(int x) {\n"
+              "    if (10 != !x) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) Comparison of a boolean with a non-zero integer\n", errout.str());
+
+        check("void f(int x) {\n"
+              "    if (10 != x) {\n"
+              "        printf(\"x not equal to 10\");\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void duplicateIf()
+    {
+        check("void f(int a, int &b) {\n"
+              "    if (a) { b = 1; }\n"
+              "    else if (a) { b = 2; }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3] -> [test.cpp:2]: (style) Found duplicate if expressions.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a == 1) { b = 1; }\n"
+              "    else if (a == 2) { b = 2; }\n"
+              "    else if (a == 1) { b = 3; }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4] -> [test.cpp:2]: (style) Found duplicate if expressions.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a == 1) { b = 1; }\n"
+              "    else if (a == 2) { b = 2; }\n"
+              "    else if (a == 2) { b = 3; }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4] -> [test.cpp:3]: (style) Found duplicate if expressions.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a == 1) {\n"
+              "        b = 1;\n"
+              "        if (b == 1) { }\n"
+              "        else if (b == 1) { }\n"
+              "    } else if (a == 2) { b = 2; }\n"
+              "    else if (a == 2) { b = 3; }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:7] -> [test.cpp:6]: (style) Found duplicate if expressions.\n"
+                      "[test.cpp:5] -> [test.cpp:4]: (style) Found duplicate if expressions.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a++) { b = 1; }\n"
+              "    else if (a++) { b = 2; }\n"
+              "    else if (a++) { b = 3; }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (!strtok(NULL," ")) { b = 1; }\n"
+              "    else if (!strtok(NULL," ")) { b = 2; }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "   if ((x = x / 2) < 100) { b = 1; }\n"
+              "   else if ((x = x / 2) < 100) { b = 2; }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void duplicateBranch()
+    {
+        check("void f(int a, int &b) {\n"
+              "    if (a)\n"
+              "        b = 1;\n"
+              "    else\n"
+              "        b = 1;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4] -> [test.cpp:2]: (style) Found duplicate branches for if and else.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a) {\n"
+              "        if (a == 1)\n"
+              "            b = 2;\n"
+              "        else\n"
+              "            b = 2;\n"
+              "    } else\n"
+              "        b = 1;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:5] -> [test.cpp:3]: (style) Found duplicate branches for if and else.\n", errout.str());
+
+        check("int f(int signed, unsigned char value) {\n"
+              "    int ret;\n"
+              "    if (signed)\n"
+              "        ret = (signed char)value;\n"
+              "    else\n"
+              "        ret = (unsigned char)value;\n"
+              "    return ret;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void duplicateExpression1()
+    {
+        check("voif foo() {\n"
+              "    if (a == a) { }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2] -> [test.cpp:2]: (style) Same expression on both sides of '=='.\n", errout.str());
+
+        check("void fun() {\n"
+              "    return (a && a ||\n"
+              "            b == b &&\n"
+              "            c - c &&\n"
+              "            d > d &&\n"
+              "            e < e &&\n"
+              "            f);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2] -> [test.cpp:2]: (style) Same expression on both sides of '&&'.\n"
+                      "[test.cpp:3] -> [test.cpp:3]: (style) Same expression on both sides of '=='.\n"
+                      "[test.cpp:4] -> [test.cpp:4]: (style) Same expression on both sides of '-'.\n"
+                      "[test.cpp:5] -> [test.cpp:5]: (style) Same expression on both sides of '>'.\n"
+                      "[test.cpp:6] -> [test.cpp:6]: (style) Same expression on both sides of '<'.\n", errout.str());
+    }
+
+    void duplicateExpression2() // ticket #2730
+    {
+        check("int main()\n"
+              "{\n"
+              "    long double ldbl;\n"
+              "    double dbl, in;\n"
+              "    float  flt;\n"
+              "    int have_nan = 0;\n"
+              "    ldbl = sqrtl(-1.0);\n"
+              "    dbl = sqrt(-1.0);\n"
+              "    flt = sqrtf(-1.0);\n"
+              "    if (ldbl != ldbl) have_nan = 1;\n"
+              "    if (!(dbl == dbl)) have_nan = 1;\n"
+              "    if (flt != flt) have_nan = 1;\n"
+              "    return have_nan;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:7]: (error) Passing value -1.0 to sqrtl() leads to undefined result\n"
+                      "[test.cpp:8]: (error) Passing value -1.0 to sqrt() leads to undefined result\n"
+                      "[test.cpp:9]: (error) Passing value -1.0 to sqrtf() leads to undefined result\n", errout.str());
+    }
+
+    void alwaysTrueFalseStringCompare()
+    {
+        check_preprocess_suppress(
+            "#define MACRO \"00FF00\"\n"
+            "int main()\n"
+            "{\n"
+            "  if (strcmp(MACRO,\"00FF00\") == 0)"
+            "  {"
+            "    std::cout << \"Equal\n\""
+            "  }"
+            "}");
+        ASSERT_EQUALS("[test.cpp:4]: (warning) Comparison of always identical static strings.\n", errout.str());
+
+        check_preprocess_suppress(
+            "int main()\n"
+            "{\n"
+            "  if (stricmp(\"hotdog\",\"HOTdog\") == 0)"
+            "  {"
+            "    std::cout << \"Equal\n\""
+            "  }"
+            "}");
+        ASSERT_EQUALS("[test.cpp:3]: (performance) Unnecessary comparison of static strings.\n", errout.str());
+
+        check_preprocess_suppress(
+            "#define MACRO \"Hotdog\"\n"
+            "int main()\n"
+            "{\n"
+            "  if (QString::compare(\"Hamburger\", MACRO) == 0)"
+            "  {"
+            "    std::cout << \"Equal\n\""
+            "  }"
+            "}");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Unnecessary comparison of static strings.\n", errout.str());
+
+        check_preprocess_suppress(
+            "int main()\n"
+            "{\n"
+            "  if (QString::compare(argv[2], \"hotdog\") == 0)"
+            "  {"
+            "    std::cout << \"Equal\n\""
+            "  }"
+            "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestOther)
