@@ -78,6 +78,11 @@ private:
         TEST_CASE(test5);
         TEST_CASE(test6);
         TEST_CASE(test7);
+        TEST_CASE(test7a);
+        TEST_CASE(test7b);
+        TEST_CASE(test7c);
+        TEST_CASE(test7d);
+        TEST_CASE(test7e);
 
         // #error => don't extract any code
         TEST_CASE(error1);
@@ -87,6 +92,15 @@ private:
 
         TEST_CASE(error3);
 
+        TEST_CASE(if0_exclude);
+        TEST_CASE(if0_whitespace);
+        TEST_CASE(if0_else);
+        TEST_CASE(if0_elif);
+
+        // Don't handle include in a #if 0 block
+        TEST_CASE(if0_include_1);
+        TEST_CASE(if0_include_2);
+
         // Handling include guards (don't create extra configuration for it)
         TEST_CASE(includeguard1);
         TEST_CASE(includeguard2);
@@ -109,11 +123,11 @@ private:
         TEST_CASE(if_cond4);
         TEST_CASE(if_cond5);
         TEST_CASE(if_cond6);
-        TEST_CASE(if_cond7);
         TEST_CASE(if_cond8);
         TEST_CASE(if_cond9);
         TEST_CASE(if_cond10);
         TEST_CASE(if_cond11);
+        TEST_CASE(if_cond12);
 
         TEST_CASE(if_or_1);
         TEST_CASE(if_or_2);
@@ -143,7 +157,10 @@ private:
         TEST_CASE(macro_simple11);
         TEST_CASE(macro_simple12);
         TEST_CASE(macro_simple13);
-        TEST_CASE(macroInMacro);
+        TEST_CASE(macro_simple14);
+        TEST_CASE(macro_simple15);
+        TEST_CASE(macroInMacro1);
+        TEST_CASE(macroInMacro2);
         TEST_CASE(macro_mismatch);
         TEST_CASE(macro_linenumbers);
         TEST_CASE(macro_nopar);
@@ -187,12 +204,23 @@ private:
         TEST_CASE(ifdef_ifdefined);
 
         // define and then ifdef
+        TEST_CASE(define_if);
         TEST_CASE(define_ifdef);
         TEST_CASE(define_ifndef1);
         TEST_CASE(define_ifndef2);
         TEST_CASE(endfile);
 
         TEST_CASE(redundant_config);
+
+        TEST_CASE(testPreprocessorRead1);
+        TEST_CASE(testPreprocessorRead2);
+        TEST_CASE(testPreprocessorRead3);
+        TEST_CASE(testPreprocessorRead4);
+
+        TEST_CASE(invalid_define);	// #2605 - hang for: '#define ='
+
+        // inline suppression, missingInclude
+        TEST_CASE(inline_suppression_for_missing_include);
     }
 
 
@@ -204,7 +232,7 @@ private:
         Preprocessor preprocessor(&settings, this);
         std::istringstream istr(code);
         std::string codestr(preprocessor.read(istr,"test.c",0));
-        ASSERT_EQUALS("a \n#aa b \n", codestr);
+        ASSERT_EQUALS("a\n#aa b\n", codestr);
     }
 
     void readCode2()
@@ -318,7 +346,7 @@ private:
         preprocessor.preprocess(istr, actual, "file.c");
 
         // Compare results..
-        ASSERT_EQUALS("\n\" #ifdef WIN32\"\n\n\n\n", actual[""]);
+        ASSERT_EQUALS("\n\" # ifdef WIN32\"\n\n\n\n", actual[""]);
         ASSERT_EQUALS("\n\n\nqwerty\n\n", actual["WIN32"]);
         ASSERT_EQUALS(2, static_cast<unsigned int>(actual.size()));
     }
@@ -429,8 +457,9 @@ private:
         preprocessor.preprocess(istr, actual, "file.c");
 
         // Make sure an error message is written..
-        ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
-                      errout.str());
+        TODO_ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
+                           "",
+                           errout.str());
 
         // Compare results..
         ASSERT_EQUALS("\n\n\n\n\n\n", actual[""]);
@@ -511,8 +540,9 @@ private:
         preprocessor.preprocess(istr, actual, "file.c");
 
         // Make sure an error message is written..
-        ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
-                      errout.str());
+        TODO_ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
+                           "",
+                           errout.str());
 
         // Compare results..
         ASSERT_EQUALS(2, static_cast<unsigned int>(actual.size()));
@@ -536,7 +566,36 @@ private:
         preprocessor.preprocess(istr, actual, "file.c");
 
         // Make sure an error message is written..
-        ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
+        TODO_ASSERT_EQUALS("[file.c:3]: (error) ABC is already guaranteed to be defined\n",
+                           "",
+                           errout.str());
+
+        // Compare results..
+        ASSERT_EQUALS(2, static_cast<unsigned int>(actual.size()));
+    }
+
+    void test7e()
+    {
+        const char filedata[] = "#ifdef ABC\n"
+                                "#file \"test.h\"\n"
+                                "#ifndef test_h\n"
+                                "#define test_h\n"
+                                "#ifdef ABC\n"
+                                "#endif\n"
+                                "#endif\n"
+                                "#endfile\n"
+                                "#endif\n";
+
+        // Preprocess => actual result..
+        std::istringstream istr(filedata);
+        std::map<std::string, std::string> actual;
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+        errout.str("");
+        preprocessor.preprocess(istr, actual, "file.c");
+
+        // Make sure an error message is written..
+        ASSERT_EQUALS("",
                       errout.str());
 
         // Compare results..
@@ -591,6 +650,100 @@ private:
         ASSERT_EQUALS("[test.c:1]: (error) #error hello world!\n", errout.str());
     }
 
+    void if0_exclude()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code("#if 0\n"
+                                "A\n"
+                                "#endif\n"
+                                "B\n");
+        ASSERT_EQUALS("#if 0\n\n#endif\nB\n", preprocessor.read(code,"",NULL));
+
+        std::istringstream code2("#if (0)\n"
+                                 "A\n"
+                                 "#endif\n"
+                                 "B\n");
+        ASSERT_EQUALS("#if 0\n\n#endif\nB\n", preprocessor.read(code2,"",NULL));
+    }
+
+    void if0_whitespace()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code(" # if  0 \n"
+                                "A\n"
+                                " # endif \n"
+                                "B\n");
+        ASSERT_EQUALS("#if 0\n\n#endif\nB\n", preprocessor.read(code,"",NULL));
+    }
+
+    void if0_else()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code("#if 0\n"
+                                "A\n"
+                                "#else\n"
+                                "B\n"
+                                "#endif\n"
+                                "C\n");
+        ASSERT_EQUALS("#if 0\n\n#else\nB\n#endif\nC\n", preprocessor.read(code,"",NULL));
+
+        std::istringstream code2("#if 1\n"
+                                 "A\n"
+                                 "#else\n"
+                                 "B\n"
+                                 "#endif\n"
+                                 "C\n");
+        TODO_ASSERT_EQUALS("#if 1\nA\n#else\n\n#endif\nC\n",
+                           "#if 1\nA\n#else\nB\n#endif\nC\n", preprocessor.read(code2,"",NULL));
+    }
+
+    void if0_elif()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code("#if 0\n"
+                                "A\n"
+                                "#elif 1\n"
+                                "B\n"
+                                "#endif\n"
+                                "C\n");
+        TODO_ASSERT_EQUALS("#if 0\n\n#elif 1\nB\n#endif\nC\n",
+                           "#if 0\n\n\n\n#endif\nC\n", preprocessor.read(code,"",NULL));
+    }
+
+    void if0_include_1()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code("#if 0\n"
+                                "#include \"a.h\"\n"
+                                "#endif\n"
+                                "AB\n");
+        ASSERT_EQUALS("#if 0\n\n#endif\nAB\n", preprocessor.read(code,"",NULL));
+    }
+
+    void if0_include_2()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream code("#if 0\n"
+                                "#include \"a.h\"\n"
+                                "#ifdef WIN32\n"
+                                "#else\n"
+                                "#endif\n"
+                                "#endif\n"
+                                "AB\n");
+        ASSERT_EQUALS("#if 0\n\n#ifdef WIN32\n#else\n#endif\n#endif\nAB\n", preprocessor.read(code,"",NULL));
+    }
 
     void includeguard1()
     {
@@ -1188,26 +1341,6 @@ private:
         ASSERT_EQUALS("[file.c:2]: (error) mismatching number of '(' and ')' in this line: defined(A)&&defined(B))\n", errout.str());
     }
 
-    void if_cond7()
-    {
-        const char filedata[] = "#define A 1\n"
-                                "#if A==1\n"
-                                "a1;\n"
-                                "#endif\n";
-
-        // Preprocess => actual result..
-        std::istringstream istr(filedata);
-        std::map<std::string, std::string> actual;
-        Settings settings;
-        Preprocessor preprocessor(&settings, this);
-        preprocessor.preprocess(istr, actual, "file.c");
-
-        // Compare results..
-        ASSERT_EQUALS(1, (int)actual.size());
-        ASSERT_EQUALS("\n\na1;\n\n", actual[""]);
-    }
-
-
     void if_cond8()
     {
         const char filedata[] = "#if defined(A) + defined(B) + defined(C) != 1\n"
@@ -1275,6 +1408,15 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void if_cond12()
+    {
+        const char filedata[] = "#define A (1)\n"
+                                "#if A == 1\n"
+                                ";\n"
+                                "#endif\n";
+        ASSERT_EQUALS("\n\n;\n\n", Preprocessor::getcode(filedata,"","",NULL,NULL));
+    }
+
 
 
     void if_or_1()
@@ -1327,7 +1469,7 @@ private:
         std::istringstream istr(filedata);
         Settings settings;
         Preprocessor preprocessor(&settings, this);
-        ASSERT_EQUALS("#define str \"abc\" \"def\" \n\nabcdef = str;\n", preprocessor.read(istr, "test.c", 0));
+        ASSERT_EQUALS("#define str \"abc\" \"def\"\n\nabcdef = str;\n", preprocessor.read(istr, "test.c", 0));
     }
 
     void multiline2()
@@ -1411,6 +1553,14 @@ private:
         std::string str2("\nasm __volatile(\"\nlw iScale, 0x00(pScale)\n\", ());");
         Preprocessor::removeAsm(str2);
         ASSERT_EQUALS("\n\n\n;", str2);
+
+        std::string str3("#asm\nmov ax,bx\n#endasm");
+        Preprocessor::removeAsm(str3);
+        ASSERT_EQUALS(";asm();\n\n", str3);
+
+        std::string str4("\n#asm\nmov ax,bx\n#endasm\n");
+        Preprocessor::removeAsm(str4);
+        ASSERT_EQUALS("\n;asm();\n\n\n", str4);
     }
 
     void if_defined()
@@ -1540,7 +1690,21 @@ private:
         ASSERT_EQUALS("\n\n", OurPreprocessor::expandMacros(filedata));
     }
 
-    void macroInMacro()
+    void macro_simple14()
+    {
+        const char filedata[] = "#define A \"  a  \"\n"
+                                "printf(A);\n";
+        ASSERT_EQUALS("\nprintf(\"  a  \");\n", OurPreprocessor::expandMacros(filedata));
+    }
+
+    void macro_simple15()
+    {
+        const char filedata[] = "#define FOO\"foo\"\n"
+                                "FOO\n";
+        ASSERT_EQUALS("\n\"foo\"\n", OurPreprocessor::expandMacros(filedata));
+    }
+
+    void macroInMacro1()
     {
         {
             const char filedata[] = "#define A(m) long n = m; n++;\n"
@@ -1641,6 +1805,14 @@ private:
         }
     }
 
+    void macroInMacro2()
+    {
+        const char filedata[] = "#define A(x) a##x\n"
+                                "#define B 0\n"
+                                "A(B)\n";
+        ASSERT_EQUALS("\n\naB\n", OurPreprocessor::expandMacros(filedata));
+    }
+
     void macro_mismatch()
     {
         const char filedata[] = "#define AAA(aa,bb) f(aa)\n"
@@ -2351,6 +2523,24 @@ private:
         ASSERT_EQUALS(2, static_cast<unsigned int>(actual.size()));
     }
 
+    void define_if()
+    {
+        {
+            const char filedata[] = "#define A 0\n"
+                                    "#if A\n"
+                                    "FOO\n"
+                                    "#endif";
+            ASSERT_EQUALS("\n\n\n\n", Preprocessor::getcode(filedata,"","",NULL,NULL));
+        }
+        {
+            const char filedata[] = "#define A 1\n"
+                                    "#if A==1\n"
+                                    "FOO\n"
+                                    "#endif";
+            ASSERT_EQUALS("\n\nFOO\n\n", Preprocessor::getcode(filedata,"","",NULL,NULL));
+        }
+    }
+
     void define_ifdef()
     {
         {
@@ -2426,6 +2616,25 @@ private:
             ASSERT_EQUALS("\n\n1\n\n", actual[""]);
             ASSERT_EQUALS(1, (int)actual.size());
         }
+
+        {
+            const char filedata[] = "#define A 1\n"
+                                    "#if 0\n"
+                                    "#undef A\n"
+                                    "#endif\n"
+                                    "A\n";
+
+            // Preprocess => actual result..
+            std::istringstream istr(filedata);
+            std::map<std::string, std::string> actual;
+            Settings settings;
+            Preprocessor preprocessor(&settings, this);
+            preprocessor.preprocess(istr, actual, "file.c");
+
+            // Compare results..
+            ASSERT_EQUALS("\n\n\n\n1\n", actual[""]);
+            ASSERT_EQUALS(1, (int)actual.size());
+        }
     }
 
     void define_ifndef1()
@@ -2555,6 +2764,95 @@ private:
             ASSERT_EQUALS("A;A;B is NOT checked", "A;A;B is NOT checked");
         }
     }
+
+    void testPreprocessorRead1()
+    {
+        const std::string filedata("/*\n*/ # /*\n*/ defi\\\nne FO\\\nO 10\\\n20");
+        std::istringstream istr(filedata.c_str());
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+        ASSERT_EQUALS("#define FOO 1020", preprocessor.read(istr, "test.cpp", 0));
+    }
+
+    void testPreprocessorRead2()
+    {
+        const std::string filedata("\"foo\\\\\nbar\"");
+        std::istringstream istr(filedata.c_str());
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+        ASSERT_EQUALS("\"foo\\bar\"", preprocessor.read(istr, "test.cpp", 0));
+    }
+
+    void testPreprocessorRead3()
+    {
+        const std::string filedata("#define A \" a  \"\n\" b\"");
+        std::istringstream istr(filedata.c_str());
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+        ASSERT_EQUALS(filedata, preprocessor.read(istr, "test.cpp", 0));
+    }
+
+    void testPreprocessorRead4()
+    {
+        {
+            // test < \\> < > (unescaped)
+            const std::string filedata("#define A \" \\\\\"/*space*/  \" \"");
+            std::istringstream istr(filedata.c_str());
+            Settings settings;
+            Preprocessor preprocessor(&settings, this);
+            ASSERT_EQUALS("#define A \" \\\\\" \" \"", preprocessor.read(istr, "test.cpp", 0));
+        }
+
+        {
+            // test <" \\\"  "> (unescaped)
+            const std::string filedata("#define A \" \\\\\\\"  \"");
+            std::istringstream istr(filedata.c_str());
+            Settings settings;
+            Preprocessor preprocessor(&settings, this);
+            ASSERT_EQUALS("#define A \" \\\\\\\"  \"", preprocessor.read(istr, "test.cpp", 0));
+        }
+
+        {
+            // test <" \\\\">  <" "> (unescaped)
+            const std::string filedata("#define A \" \\\\\\\\\"/*space*/  \" \"");
+            std::istringstream istr(filedata.c_str());
+            Settings settings;
+            Preprocessor preprocessor(&settings, this);
+            ASSERT_EQUALS("#define A \" \\\\\\\\\" \" \"", preprocessor.read(istr, "test.cpp", 0));
+        }
+    }
+
+    void invalid_define()
+    {
+        Settings settings;
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream src("#define =\n");
+        std::string processedFile;
+        std::list<std::string> cfg;
+        std::list<std::string> paths;
+        preprocessor.preprocess(src, processedFile, cfg, "", paths);		// don't hang
+    }
+
+    void inline_suppression_for_missing_include()
+    {
+        Settings settings;
+        settings._inlineSuppressions = true;
+        settings.addEnabled("all");
+        Preprocessor preprocessor(&settings, this);
+
+        std::istringstream src("// cppcheck-suppress missingInclude\n"
+                               "#include \"missing.h\"\n"
+                               "int x;");
+        std::string processedFile;
+        std::list<std::string> cfg;
+        std::list<std::string> paths;
+
+        // Don't report that the include is missing
+        errout.str("");
+        preprocessor.preprocess(src, processedFile, cfg, "test.c", paths);
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestPreprocessor)
