@@ -75,6 +75,7 @@ private:
         TEST_CASE(pushback8);
         TEST_CASE(pushback9);
         TEST_CASE(pushback10);
+        TEST_CASE(pushback11);
 
         TEST_CASE(insert1);
         TEST_CASE(insert2);
@@ -90,6 +91,7 @@ private:
         TEST_CASE(if_str_find);
 
         TEST_CASE(size1);
+        TEST_CASE(size2);
 
         // Redundant conditions..
         // if (ints.find(123) != ints.end()) ints.remove(123);
@@ -102,6 +104,7 @@ private:
         TEST_CASE(missingInnerComparison3);     // no FP when there is iterator shadowing
         TEST_CASE(missingInnerComparison4);     // no FP when "break;" is used
         TEST_CASE(missingInnerComparison5);     // Ticket #2154 - FP
+        TEST_CASE(missingInnerComparison6);     // #2643 - 'it=foo.insert(++it,0);'
 
         // catch common problems when using the string::c_str() function
         TEST_CASE(cstr);
@@ -113,7 +116,6 @@ private:
         errout.str("");
 
         Settings settings;
-        settings.inconclusive = true;
         settings._checkCodingStyle = true;
 
         // Tokenize..
@@ -889,6 +891,20 @@ private:
         ASSERT_EQUALS("[test.cpp:8]: (error) After reserve, the iterator 'it' may be invalid\n", errout.str());
     }
 
+    void pushback11()
+    {
+        // #2798
+        check("void f() {\n"
+              "    std::vector<int> ints;\n"
+              "    std::vector<int>::iterator it = ints.begin();\n"
+              "    if (it == ints.begin()) {\n"
+              "        ints.push_back(0);\n"
+              "    } else {\n"
+              "        ints.insert(it,0);\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 
     void insert1()
     {
@@ -1064,6 +1080,23 @@ private:
 
     void size1()
     {
+        check("struct Fred {\n"
+              "    void foo();\n"
+              "    std::list<int> x;\n"
+              "};\n"
+              "void Fred::foo()\n"
+              "{\n"
+              "    if (x.size() == 0) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:7]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
+        check("std::list<int> x;\n"
+              "void f()\n"
+              "{\n"
+              "    if (x.size() == 0) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
         check("void f()\n"
               "{\n"
               "    std::list<int> x;\n"
@@ -1071,6 +1104,13 @@ private:
               "}\n");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
 
+        check("void f()\n"
+              "{\n"
+              "    std::list<int> x;\n"
+              "    if (0 == x.size()) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
         check("void f()\n"
               "{\n"
               "    std::list<int> x;\n"
@@ -1078,6 +1118,13 @@ private:
               "}\n");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
 
+        check("void f()\n"
+              "{\n"
+              "    std::list<int> x;\n"
+              "    if (0 != x.size()) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
         check("void f()\n"
               "{\n"
               "    std::list<int> x;\n"
@@ -1085,6 +1132,13 @@ private:
               "}\n");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
 
+        check("void f()\n"
+              "{\n"
+              "    std::list<int> x;\n"
+              "    if (0 < x.size()) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
         check("void f()\n"
               "{\n"
               "    std::list<int> x;\n"
@@ -1092,12 +1146,26 @@ private:
               "}\n");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
 
+        check("void f()\n"
+              "{\n"
+              "    std::list<int> x;\n"
+              "    if (!x.size()) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+
         check("void f()\n"
               "{\n"
               "    std::list<int> x;\n"
               "    fun(x.size());\n"
               "}\n");
         ASSERT_EQUALS("", errout.str());
+
+        check("void f()\n"
+              "{\n"
+              "    std::list<int> x;\n"
+              "    fun(!x.size());\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void redundantCondition1()
@@ -1110,6 +1178,22 @@ private:
         ASSERT_EQUALS("[test.cpp:3]: (style) Redundant checking of STL container element.\n", errout.str());
     }
 
+    void size2()
+    {
+        check("struct Fred {\n"
+              "    std::list<int> x;\n"
+              "};\n"
+              "struct Wilma {\n"
+              "    Fred f;\n"
+              "    void foo();\n"
+              "};\n"
+              "void Wilma::foo()\n"
+              "{\n"
+              "    if (f.x.size() == 0) {}\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:10]: (performance) Possible inefficient checking for 'x' emptiness.\n", errout.str());
+    }
+
     void redundantCondition2()
     {
         check("void f()\n"
@@ -1199,6 +1283,16 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void missingInnerComparison6()
+    {
+        check("void f(std::string &s) {\n"
+              "    for(string::iterator it = s.begin(); it != s.end(); it++) {\n"
+              "        it = s.insert(++it, 0);\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void cstr()
     {
         check("void f() {\n"
