@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2010 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2011 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,9 @@
 
 #include <sstream>
 #include "errorlogger.h"
+#include "redirect.h"
+
+class options;
 
 class Token;
 
@@ -36,43 +39,45 @@ private:
 protected:
     std::string classname;
     std::string testToRun;
+    bool gcc_style_errors;
+    bool quiet_tests;
 
     virtual void run() = 0;
 
     bool runTest(const char testname[]);
 
-    void assert(const char *filename, int linenr, bool condition);
+    void assert_(const char *filename, int linenr, bool condition);
 
     void assertEquals(const char *filename, int linenr, const std::string &expected, const std::string &actual, const std::string &msg = "");
+    void assertEquals(const char *filename, int linenr, long long expected, long long actual, const std::string &msg="");
+    void assertEqualsDouble(const char *filename, int linenr, double expected, double actual, const std::string &msg="");
 
-    // the vars expected and actual need to be of type double, in order to avoid overflow of unsigned int
-    // e.g: ASSERT_EQUALS(-100.0, MathLib::toDoubleNumber("-1.0E+2")); whould not work without this.
-    void assertEquals(const char *filename, int linenr, double expected, double actual, const std::string &msg="");
-
-    void todoAssertEquals(const char *filename, int linenr, const std::string &expected, const std::string &actual);
-    void todoAssertEquals(const char *filename, int linenr, unsigned int expected, unsigned int actual);
+    void todoAssertEquals(const char *filename, int linenr, const std::string &wanted,
+                          const std::string &current, const std::string &actual);
+    void todoAssertEquals(const char *filename, int linenr, unsigned int wanted,
+                          unsigned int current, unsigned int actual);
     void assertThrowFail(const char *filename, int linenr);
-
+    void processOptions(const options& args);
 public:
     virtual void reportOut(const std::string &outmsg);
     virtual void reportErr(const ErrorLogger::ErrorMessage &msg);
-    virtual void reportStatus(unsigned int /*index*/, unsigned int /*max*/) {}
+    virtual void reportStatus(unsigned int /*fileindex*/, unsigned int /*filecount*/, long /*sizedone*/, long /*sizetotal*/) {}
     void run(const std::string &str);
 
     TestFixture(const std::string &_name);
     virtual ~TestFixture() { }
 
     static void printTests();
-    static size_t runTests(const char cmd[]);
+    static size_t runTests(const options& args);
 };
 
-
-#define TEST_CASE( NAME )  if ( runTest(#NAME) ) NAME ();
-#define ASSERT( CONDITION )  assert(__FILE__, __LINE__, CONDITION)
+#define TEST_CASE( NAME )  if ( runTest(#NAME) ) { if (quiet_tests) { REDIRECT; NAME(); } else { NAME ();} }
+#define ASSERT( CONDITION )  assert_(__FILE__, __LINE__, CONDITION)
 #define ASSERT_EQUALS( EXPECTED , ACTUAL )  assertEquals(__FILE__, __LINE__, EXPECTED, ACTUAL)
+#define ASSERT_EQUALS_DOUBLE( EXPECTED , ACTUAL )  assertEqualsDouble(__FILE__, __LINE__, EXPECTED, ACTUAL)
 #define ASSERT_EQUALS_MSG( EXPECTED , ACTUAL, MSG )  assertEquals(__FILE__, __LINE__, EXPECTED, ACTUAL, MSG)
 #define ASSERT_THROW( CMD, EXCEPTION ) try { CMD ; assertThrowFail(__FILE__, __LINE__); } catch (EXCEPTION &) { } catch (...) { assertThrowFail(__FILE__, __LINE__); }
-#define TODO_ASSERT_EQUALS( EXPECTED , ACTUAL ) todoAssertEquals(__FILE__, __LINE__, EXPECTED, ACTUAL)
+#define TODO_ASSERT_EQUALS( WANTED , CURRENT , ACTUAL ) todoAssertEquals(__FILE__, __LINE__, WANTED, CURRENT, ACTUAL)
 #define REGISTER_TEST( CLASSNAME ) namespace { CLASSNAME instance; }
 
 #endif
