@@ -38,6 +38,7 @@ public:
         ,typetok(NULL)
         ,t(NULL)
         ,found(false)
+        ,isArray(false)
     {}
 
 private:
@@ -46,6 +47,7 @@ private:
     const Token* typetok;
     const Token* t;
     bool found;
+    bool isArray;
 
     void reset()
     {
@@ -53,6 +55,7 @@ private:
         typetok = NULL;
         t = NULL;
         found = false;
+        isArray = false;
     }
 
     void run()
@@ -93,213 +96,258 @@ private:
         TEST_CASE(hasInlineClassFunctionReturningFunctionPointer);
         TEST_CASE(hasMissingInlineClassFunctionReturningFunctionPointer);
         TEST_CASE(hasClassFunctionReturningFunctionPointer);
+
+        TEST_CASE(hasGlobalVariables1);
+        TEST_CASE(hasGlobalVariables2);
+        TEST_CASE(hasGlobalVariables3);
+
+        TEST_CASE(functionArgs1);
+
+        TEST_CASE(symboldatabase1);
+        TEST_CASE(symboldatabase2);
+        TEST_CASE(symboldatabase3); // ticket #2000
+        TEST_CASE(symboldatabase4);
+        TEST_CASE(symboldatabase5); // ticket #2178
+        TEST_CASE(symboldatabase6); // ticket #2221
+        TEST_CASE(symboldatabase7); // ticket #2230
+        TEST_CASE(symboldatabase8); // ticket #2252
+        TEST_CASE(symboldatabase9); // ticket #2525
+        TEST_CASE(symboldatabase10); // ticket #2537
+        TEST_CASE(symboldatabase11); // ticket #2539
+        TEST_CASE(symboldatabase12); // ticket #2547
+        TEST_CASE(symboldatabase13); // ticket #2577
+        TEST_CASE(symboldatabase14); // ticket #2589
+        TEST_CASE(symboldatabase15); // ticket #2591
+        TEST_CASE(symboldatabase16); // ticket #2637
+        TEST_CASE(symboldatabase17); // ticket #2657
     }
 
     void test_isVariableDeclarationCanHandleNull()
     {
         reset();
-        bool result = si.isVariableDeclaration(NULL, vartok, typetok);
+        bool result = si.isVariableDeclaration(NULL, vartok, typetok, isArray);
         ASSERT_EQUALS(false, result);
         ASSERT(NULL == vartok);
         ASSERT(NULL == typetok);
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesSimpleDeclaration()
     {
         reset();
         givenACodeSampleToTokenize simpleDeclaration("int x;");
-        bool result = si.isVariableDeclaration(simpleDeclaration.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(simpleDeclaration.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("x", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesScopedDeclaration()
     {
         reset();
         givenACodeSampleToTokenize ScopedDeclaration("::int x;");
-        bool result = si.isVariableDeclaration(ScopedDeclaration.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(ScopedDeclaration.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("x", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesStdDeclaration()
     {
         reset();
         givenACodeSampleToTokenize StdDeclaration("std::string x;");
-        bool result = si.isVariableDeclaration(StdDeclaration.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(StdDeclaration.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("x", vartok->str());
         ASSERT_EQUALS("string", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesScopedStdDeclaration()
     {
         reset();
         givenACodeSampleToTokenize StdDeclaration("::std::string x;");
-        bool result = si.isVariableDeclaration(StdDeclaration.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(StdDeclaration.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("x", vartok->str());
         ASSERT_EQUALS("string", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesManyScopes()
     {
         reset();
         givenACodeSampleToTokenize manyScopes("AA::BB::CC::DD::EE x;");
-        bool result = si.isVariableDeclaration(manyScopes.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(manyScopes.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("x", vartok->str());
         ASSERT_EQUALS("EE", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesPointers()
     {
         reset();
         givenACodeSampleToTokenize pointer("int* p;");
-        bool result = si.isVariableDeclaration(pointer.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(pointer.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("p", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationDoesNotIdentifyConstness()
     {
         reset();
         givenACodeSampleToTokenize constness("const int* cp;");
-        bool result = si.isVariableDeclaration(constness.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(constness.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(false, result);
         ASSERT(NULL == vartok);
         ASSERT(NULL == typetok);
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesFirstOfManyVariables()
     {
         reset();
         givenACodeSampleToTokenize multipleDeclaration("int first, second;");
-        bool result = si.isVariableDeclaration(multipleDeclaration.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(multipleDeclaration.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("first", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesScopedPointerDeclaration()
     {
         reset();
         givenACodeSampleToTokenize manyScopes("AA::BB::CC::DD::EE* p;");
-        bool result = si.isVariableDeclaration(manyScopes.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(manyScopes.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("p", vartok->str());
         ASSERT_EQUALS("EE", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesDeclarationWithIndirection()
     {
         reset();
         givenACodeSampleToTokenize pointerToPointer("int** pp;");
-        bool result = si.isVariableDeclaration(pointerToPointer.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(pointerToPointer.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("pp", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesDeclarationWithMultipleIndirection()
     {
         reset();
         givenACodeSampleToTokenize pointerToPointer("int***** p;");
-        bool result = si.isVariableDeclaration(pointerToPointer.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(pointerToPointer.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("p", vartok->str());
         ASSERT_EQUALS("int", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesArray()
     {
         reset();
         givenACodeSampleToTokenize array("::std::string v[3];");
-        bool result = si.isVariableDeclaration(array.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(array.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("v", vartok->str());
         ASSERT_EQUALS("string", typetok->str());
+        ASSERT(true == isArray);
     }
 
     void test_isVariableDeclarationIdentifiesOfArrayPointers()
     {
         reset();
         givenACodeSampleToTokenize array("A *a[5];");
-        bool result = si.isVariableDeclaration(array.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(array.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("a", vartok->str());
         ASSERT_EQUALS("A", typetok->str());
+        ASSERT(true == isArray);
     }
 
     void isVariableDeclarationIdentifiesTemplatedPointerVariable()
     {
         reset();
         givenACodeSampleToTokenize var("std::set<char>* chars;");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("chars", vartok->str());
         ASSERT_EQUALS("set", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void isVariableDeclarationIdentifiesTemplatedPointerToPointerVariable()
     {
         reset();
         givenACodeSampleToTokenize var("std::deque<int>*** ints;");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("ints", vartok->str());
         ASSERT_EQUALS("deque", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void isVariableDeclarationIdentifiesTemplatedArrayVariable()
     {
         reset();
         givenACodeSampleToTokenize var("std::deque<int> ints[3];");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("ints", vartok->str());
         ASSERT_EQUALS("deque", typetok->str());
+        ASSERT(true == isArray);
     }
 
     void isVariableDeclarationIdentifiesTemplatedVariable()
     {
         reset();
         givenACodeSampleToTokenize var("std::vector<int> ints;");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("ints", vartok->str());
         ASSERT_EQUALS("vector", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void isVariableDeclarationIdentifiesTemplatedVariableIterator()
     {
         reset();
         givenACodeSampleToTokenize var("std::list<int>::const_iterator floats;");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("floats", vartok->str());
         ASSERT_EQUALS("const_iterator", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void isVariableDeclarationIdentifiesNestedTemplateVariable()
     {
         reset();
         givenACodeSampleToTokenize var("std::deque<std::set<int> > intsets;");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(true, result);
         ASSERT_EQUALS("intsets", vartok->str());
         ASSERT_EQUALS("deque", typetok->str());
+        ASSERT(false == isArray);
     }
 
     void isVariableDeclarationDoesNotIdentifyTemplateClass()
     {
         reset();
         givenACodeSampleToTokenize var("template <class T> class SomeClass{};");
-        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok);
+        bool result = si.isVariableDeclaration(var.tokens(), vartok, typetok, isArray);
         ASSERT_EQUALS(false, result);
+        ASSERT(false == isArray);
     }
 
     void canFindMatchingBracketsNeedsOpen()
@@ -522,6 +570,305 @@ private:
             ASSERT(function && function->hasBody && !function->isInline && function->retFuncPtr);
         }
     }
+
+    void hasGlobalVariables1()
+    {
+        GET_SYMBOL_DB("int i;\n")
+
+        ASSERT(db && db->scopeList.size() == 1);
+        if (db && db->scopeList.size() == 1)
+        {
+            std::list<Scope>::const_iterator it = db->scopeList.begin();
+            ASSERT(it->varlist.size() == 1);
+            if (it->varlist.size() == 1)
+            {
+                std::list<Variable>::const_iterator var = it->varlist.begin();
+                ASSERT(var->name() == "i");
+                ASSERT(var->typeStartToken()->str() == "int");
+            }
+        }
+    }
+
+    void hasGlobalVariables2()
+    {
+        GET_SYMBOL_DB("int array[2][2];\n")
+
+        ASSERT(db && db->scopeList.size() == 1);
+        if (db && db->scopeList.size() == 1)
+        {
+            std::list<Scope>::const_iterator it = db->scopeList.begin();
+            ASSERT(it->varlist.size() == 1);
+            if (it->varlist.size() == 1)
+            {
+                std::list<Variable>::const_iterator var = it->varlist.begin();
+                ASSERT(var->name() == "array");
+                ASSERT(var->typeStartToken()->str() == "int");
+            }
+        }
+    }
+
+    void hasGlobalVariables3()
+    {
+        GET_SYMBOL_DB("int array[2][2] = { { 0, 0 }, { 0, 0 } };\n")
+
+        ASSERT(db && db->scopeList.size() == 1);
+        if (db && db->scopeList.size() == 1)
+        {
+            std::list<Scope>::const_iterator it = db->scopeList.begin();
+            ASSERT(it->varlist.size() == 1);
+            if (it->varlist.size() == 1)
+            {
+                std::list<Variable>::const_iterator var = it->varlist.begin();
+                ASSERT(var->name() == "array");
+                ASSERT(var->typeStartToken()->str() == "int");
+            }
+        }
+    }
+
+    void check(const char code[])
+    {
+        // Clear the error log
+        errout.str("");
+
+        // Check..
+        Settings settings;
+        settings.debugwarnings = true;
+
+        // Tokenize..
+        Tokenizer tokenizer(&settings, this);
+        std::istringstream istr(code);
+        tokenizer.tokenize(istr, "test.cpp");
+        tokenizer.simplifyTokenList();
+
+        // force symbol database creation
+        tokenizer.getSymbolDatabase();
+    }
+
+    void functionArgs1()
+    {
+        check("void f(std::vector<std::string s>, const std::vector<int> & v) { }\n");
+
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(std::map<std::string, std::vector<int> > m) { }\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase1()
+    {
+        check("namespace foo {\n"
+              "    class bar;\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+
+        check("class foo : public bar < int, int> {\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase2()
+    {
+        check("class foo {\n"
+              "public slots :\n"
+              "foo() { }\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+
+        check("class foo {\n"
+              "class bar;\n"
+              "foo() { }\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase3()
+    {
+        check("typedef void (func_type)();\n"
+              "struct A {\n"
+              "    friend func_type f : 2;\n"
+              "};\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase4()
+    {
+        check("static void function_declaration_before(void) __attribute__((__used__));\n"
+              "static void function_declaration_before(void) {}\n"
+              "static void function_declaration_after(void) {}\n"
+              "static void function_declaration_after(void) __attribute__((__used__));\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("main(int argc, char *argv[]) { }\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("namespace boost {\n"
+              "    std::locale generate_locale()\n"
+              "    {\n"
+              "        return std::locale();\n"
+              "    }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("namespace X {\n"
+              "    static void function_declaration_before(void) __attribute__((__used__));\n"
+              "    static void function_declaration_before(void) {}\n"
+              "    static void function_declaration_after(void) {}\n"
+              "    static void function_declaration_after(void) __attribute__((__used__));\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("testing::testing()\n"
+              "{\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase5()
+    {
+        // ticket #2178 - segmentation fault
+        check("int CL_INLINE_DECL(integer_decode_float) (int x) {\n"
+              "    return (sign ? cl_I() : 0);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase6()
+    {
+        // ticket #2221 - segmentation fault
+        check("template<int i> class X { };\n"
+              "X< 1>2 > x1;\n"
+              "X<(1>2)> x2;\n"
+              "template<class T> class Y { };\n"
+              "Y<X<1>> x3;\n"
+              "Y<X<6>>1>> x4;\n"
+              "Y<X<(6>>1)>> x5;\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase7()
+    {
+        // ticket #2230 - segmentation fault
+        check("template<template<class> class E,class D> class C : E<D>\n"
+              "{\n"
+              "public:\n"
+              "    int f();\n"
+              "};\n"
+              "class E : C<D,int>\n"
+              "{\n"
+              "public:\n"
+              "    int f() { return C< ::D,int>::f(); }\n"
+              "};\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase8()
+    {
+        // ticket #2252 - segmentation fault
+        check("struct PaletteColorSpaceHolder: public rtl::StaticWithInit<uno::Reference<rendering::XColorSpace>,\n"
+              "                                                           PaletteColorSpaceHolder>\n"
+              "{\n"
+              "    uno::Reference<rendering::XColorSpace> operator()()\n"
+              "    {\n"
+              "        return vcl::unotools::createStandardColorSpace();\n"
+              "    }\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase9()
+    {
+        // ticket #2425 - segmentation fault
+        check("class CHyperlink : public CString\n"
+              "{\n"
+              "public:\n"
+              "    const CHyperlink& operator=(LPCTSTR lpsz) {\n"
+              "        CString::operator=(lpsz);\n"
+              "        return *this;\n"
+              "    }\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase10()
+    {
+        // ticket #2537 - segmentation fault
+        check("class A {\n"
+              "private:\n"
+              "  void f();\n"
+              "};\n"
+              "class B {\n"
+              "  friend void A::f();\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase11()
+    {
+        // ticket #2539 - segmentation fault
+        check("int g ();\n"
+              "struct S {\n"
+              "  int i : (false ? g () : 1);\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase12()
+    {
+        // ticket #2547 - segmentation fault
+        check("class foo {\n"
+              "    void bar2 () = __null;\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase13()
+    {
+        // ticket #2577 - segmentation fault
+        check("class foo {\n"
+              "    void bar2 () = A::f;\n"
+              "};\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase14()
+    {
+        // ticket #2589 - segmentation fault
+        check("struct B : A\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase15()
+    {
+        // ticket #2591 - segmentation fault
+        check("struct A :\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase16()
+    {
+        // ticket #2637 - segmentation fault
+        check("{} const const\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase17()
+    {
+        // ticket #2657 - segmentation fault
+        check("return f(){}\n");
+
+        ASSERT_EQUALS("", errout.str());
+    }
+
 };
 
 REGISTER_TEST(TestSymbolDatabase)
