@@ -46,6 +46,8 @@ private:
         TEST_CASE(uninitvar_references); // references
         TEST_CASE(uninitvar_strncpy);   // strncpy doesn't always 0-terminate
         TEST_CASE(uninitvar_func);      // analyse functions
+        TEST_CASE(func_uninit_var);     // analyse function calls for: 'int a(int x) { return x+x; }'
+        TEST_CASE(func_uninit_pointer); // analyse function calls for: 'void a(int *p) { *p = 0; }'
         TEST_CASE(uninitvar_typeof);    // typeof
     }
 
@@ -125,6 +127,13 @@ private:
                        "}\n");
         ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: p\n", errout.str());
 
+        checkUninitVar("static void foo()\n"
+                       "{\n"
+                       "    int *p;\n"
+                       "    p[0] = 135;\n"
+                       "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: p\n", errout.str());
+
         checkUninitVar("static void foo()\n"
                        "{\n"
                        "    int *x;\n"
@@ -800,6 +809,21 @@ private:
                        "}\n");
         TODO_ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: pItem\n",
                            "", errout.str());
+
+        // #2231 - conditional initialization in loop..
+        checkUninitVar("int foo(char *a) {\n"
+                       "    int x;\n"
+                       "\n"
+                       "    for (int i = 0; i < 10; ++i) {\n"
+                       "        if (a[i] == 'x') {\n"
+                       "            x = i;\n"
+                       "            break;\n"
+                       "        }\n"
+                       "    }\n"
+                       "\n"
+                       "    return x;\n"
+                       "}");
+        ASSERT_EQUALS("[test.cpp:11]: (error) Uninitialized variable: x\n", errout.str());
     }
 
     // switch..
@@ -934,6 +958,12 @@ private:
                        "}\n");
         ASSERT_EQUALS("", errout.str());
 
+        checkUninitVar("void f() {\n"
+                       "    char a[10], *p;\n"
+                       "    p = &(a[10]);\n"
+                       "}\n");
+        ASSERT_EQUALS("", errout.str());
+
         checkUninitVar("void f()\n"
                        "{\n"
                        "    char c[50] = \"\";\n"
@@ -1420,6 +1450,49 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    // valid and invalid use of 'int a(int x) { return x + x; }'
+    void func_uninit_var()
+    {
+        const std::string funca("int a(int x) { return x + x; }\n");
+
+        checkUninitVar((funca +
+                        "void b() {\n"
+                        "    int x;\n"
+                        "    a(x);\n"
+                        "}").c_str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: x\n", errout.str());
+
+        checkUninitVar((funca +
+                        "void b() {\n"
+                        "    int *p;\n"
+                        "    a(*p);\n"
+                        "}").c_str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: p\n", errout.str());
+    }
+
+
+    // valid and invalid use of 'void a(int *p) { *p = 0; }'
+    void func_uninit_pointer()
+    {
+        const std::string funca("void a(int *p) { *p = 0; }\n");
+
+        // ok - initialized pointer
+        checkUninitVar((funca +
+                        "void b() {\n"
+                        "    int buf[10];\n"
+                        "    a(buf);\n"
+                        "}\n").c_str());
+        ASSERT_EQUALS("", errout.str());
+
+        // not ok - uninitialized pointer
+        checkUninitVar((funca +
+                        "void b() {\n"
+                        "    int *p;\n"
+                        "    a(p);\n"
+                        "}\n").c_str());
+        ASSERT_EQUALS("[test.cpp:4]: (error) Uninitialized variable: p\n", errout.str());
+    }
+
     void uninitvar_typeof()
     {
         checkUninitVar("void f() {\n"
