@@ -23,12 +23,9 @@
 #include <iostream>
 #include <string>
 #include <vector>
+#include <sstream>
 
-#if defined(_WIN32)
-#include "../cli/fileLister_win32.h"
-#else // POSIX-style system
-#include "../cli/filelister_unix.h"
-#endif
+#include "../cli/filelister.h"
 
 std::string objfile(std::string cppfile)
 {
@@ -87,7 +84,8 @@ static void compilefiles(std::ostream &fout, const std::vector<std::string> &fil
 
 static void getCppFiles(std::vector<std::string> &files, const std::string &path)
 {
-    getFileLister()->recursiveAddFiles(files, path);
+    std::map<std::string,long> filesizes;
+    FileLister::recursiveAddFiles(files, filesizes, path);
     // only get *.cpp files..
     for (std::vector<std::string>::iterator it = files.begin(); it != files.end();)
     {
@@ -107,6 +105,52 @@ static void makeConditionalVariable(std::ostream &os, const std::string &variabl
        << "\n";
 }
 
+static std::string getLibName(const std::string &path)
+{
+    // path can be e.g. "externals/foo/foo.cpp" then returned
+    // library name is "FOO".
+    std::string libName = path.substr(path.find('/')+1);
+    libName = libName.substr(0, libName.find('/'));
+    std::transform(libName.begin(), libName.end(),libName.begin(), ::toupper);
+    return libName;
+}
+
+static void makeExtObj(std::ostream &fout, const std::vector<std::string> &externalfiles)
+{
+    bool start = true;
+    std::ostringstream libNames;
+    std::string libName;
+    for (unsigned int i = 0; i < externalfiles.size(); ++i)
+    {
+        if (start)
+        {
+            libName = getLibName(externalfiles[i]);
+            fout << "ifndef " << libName << std::endl;
+            fout << "    " << libName << " = " << objfile(externalfiles[i]);
+            libNames << "EXTOBJ += $(" << libName << ")" << std::endl;
+            start = false;
+        }
+        else
+        {
+            fout << std::string(14, ' ') << objfile(externalfiles[i]);
+        }
+
+        if (i+1 >= externalfiles.size() || libName != getLibName(externalfiles[i+1]))
+        {
+            // This was the last file for this library
+            fout << std::endl << "endif" << std::endl;
+            fout << "\n\n";
+            start = true;
+        }
+        else
+        {
+            // There are more files for this library
+            fout << " \\" << std::endl;
+        }
+    }
+
+    fout << libNames.str();
+}
 
 int main(int argc, char **argv)
 {
@@ -139,7 +183,7 @@ int main(int argc, char **argv)
         {
             fout1 << "# no manual edits - this file is autogenerated by dmake\n\n";
             fout1 << "LIBS += -L../externals -lpcre\n";
-            fout1 << "INCLUDEPATH += ../externals\n";
+            fout1 << "INCLUDEPATH += ../externals ../externals/tinyxml\n";
             fout1 << "HEADERS += $${BASEPATH}check.h \\\n";
             for (unsigned int i = 0; i < libfiles.size(); ++i)
             {
@@ -174,6 +218,8 @@ int main(int argc, char **argv)
     }
 
     fout << "# This file is generated by tools/dmake, do not edit.\n\n";
+    fout << "# To compile without rules, use 'make HAVE_RULES=no'\n"
+         << "HAVE_RULES = yes\n\n";
 
     // Makefile settings..
     if (release)
@@ -185,6 +231,7 @@ int main(int argc, char **argv)
         // TODO: add more compiler warnings.
         // -Wlogical-op      : doesn't work on older GCC
         // -Wconversion      : too many warnings
+        // -Wsign-conversion : too many warnings
 
         // The _GLIBCXX_DEBUG doesn't work in cygwin
         makeConditionalVariable(fout, "CXXFLAGS",
@@ -195,12 +242,26 @@ int main(int argc, char **argv)
                                 "-Wno-long-long "
                                 "-Wfloat-equal "
                                 "-Wcast-qual "
-                                "-Wsign-conversion "
+//                                "-Wsign-conversion "
 //                                "-Wconversion "
                                 "-g");
     }
+
+    fout << "ifeq ($(HAVE_RULES),yes)\n"
+         << "    CXXFLAGS += -DHAVE_RULES\n"
+         << "    ifdef LDFLAGS\n"
+         << "        LDFLAGS += -lpcre\n"
+         << "    else\n"
+         << "        LDFLAGS=-lpcre\n"
+         << "    endif\n"
+         << "endif\n\n";
+
     makeConditionalVariable(fout, "CXX", "g++");
     makeConditionalVariable(fout, "PREFIX", "/usr");
+    makeConditionalVariable(fout, "INCLUDE_FOR_LIB", "-Ilib");
+    makeConditionalVariable(fout, "INCLUDE_FOR_CLI", "-Ilib -Iexternals -Iexternals/tinyxml");
+    makeConditionalVariable(fout, "INCLUDE_FOR_TEST", "-Ilib -Icli -Iexternals -Iexternals/tinyxml");
+
     fout << "BIN=$(DESTDIR)$(PREFIX)/bin\n\n";
     fout << "# For 'make man': sudo apt-get install xsltproc docbook-xsl docbook-xml on Linux\n";
     fout << "DB2MAN=/usr/share/sgml/docbook/stylesheet/xsl/nwalsh/manpages/docbook.xsl\n";
@@ -220,24 +281,21 @@ int main(int argc, char **argv)
     for (unsigned int i = 1; i < testfiles.size(); ++i)
         fout << " \\" << std::endl << std::string(14, ' ') << objfile(testfiles[i]);
     fout << "\n\n";
-    fout << "EXTOBJ =      " << objfile(externalfiles[0]);
-    for (unsigned int i = 1; i < externalfiles.size(); ++i)
-        fout << " \\" << std::endl << std::string(14, ' ') << objfile(externalfiles[i]);
-    fout << "\n\n";
 
+    makeExtObj(fout, externalfiles);
 
     fout << "\n###### Targets\n\n";
     fout << "cppcheck: $(LIBOBJ) $(CLIOBJ) $(EXTOBJ)\n";
-    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o cppcheck $(CLIOBJ) $(LIBOBJ) $(EXTOBJ) -lpcre $(LDFLAGS)\n\n";
+    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o cppcheck $(CLIOBJ) $(LIBOBJ) $(EXTOBJ) $(LDFLAGS)\n\n";
     fout << "all:\tcppcheck testrunner\n\n";
-    fout << "testrunner: $(TESTOBJ) $(LIBOBJ) $(EXTOBJ) cli/threadexecutor.o cli/cmdlineparser.o cli/cppcheckexecutor.o cli/filelister.o cli/filelister_unix.o cli/pathmatch.o\n";
-    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o testrunner $(TESTOBJ) $(LIBOBJ) $(EXTOBJ) -lpcre cli/threadexecutor.o cli/cmdlineparser.o cli/filelister.o cli/filelister_unix.o cli/pathmatch.o $(LDFLAGS)\n\n";
+    fout << "testrunner: $(TESTOBJ) $(LIBOBJ) $(EXTOBJ) cli/threadexecutor.o cli/cmdlineparser.o cli/cppcheckexecutor.o cli/filelister.o cli/pathmatch.o\n";
+    fout << "\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) -o testrunner $(TESTOBJ) $(LIBOBJ) $(EXTOBJ) cli/threadexecutor.o cli/cppcheckexecutor.o cli/cmdlineparser.o cli/filelister.o cli/pathmatch.o $(LDFLAGS)\n\n";
     fout << "test:\tall\n";
     fout << "\t./testrunner\n\n";
     fout << "check:\tall\n";
     fout << "\t./testrunner -g -q\n\n";
     fout << "dmake:\ttools/dmake.cpp\n";
-    fout << "\t$(CXX) -o dmake tools/dmake.cpp cli/filelister*.cpp lib/path.cpp -Ilib\n\n";
+    fout << "\t$(CXX) -o dmake tools/dmake.cpp cli/filelister.cpp lib/path.cpp -Ilib\n\n";
     fout << "clean:\n";
 #ifdef _WIN32
     fout << "\tdel lib\*.o\n\tdel cli\*.o\n\tdel test\*.o\n\tdel *.exe\n";
@@ -255,9 +313,9 @@ int main(int argc, char **argv)
 
     fout << "\n###### Build\n\n";
 
-    compilefiles(fout, libfiles, "-Ilib");
-    compilefiles(fout, clifiles, "-Ilib -Iexternals");
-    compilefiles(fout, testfiles, "-Ilib -Icli -Iexternals");
+    compilefiles(fout, libfiles, "${INCLUDE_FOR_LIB}");
+    compilefiles(fout, clifiles, "${INCLUDE_FOR_CLI}");
+    compilefiles(fout, testfiles, "${INCLUDE_FOR_TEST}");
 
     return 0;
 }
